
#==============================================================================*.

# TÍTULO DE LA SINTAXIS:							   
# Tabulados	del Registro Estadístico de Defunciones Fetales - EDF   				   
# OPERACIÓN ESTADÍSTICA:													   
# Defunciones Fetales - EDF				   
# UNIDAD TÉCNICA RESPONSABLE: 												   
# Dirección de Estadísticas Sociodemográficas (DIES)						   
# ENTIDAD EJECUTORA:														   
# Instituto Nacional de Estadística y Censos (INEC)	

#==============================================================================*.

# Fecha última modificación:   Junio - 2025.

#==============================================================================*.

# Elaborado por:													   
# Dirección de Estadísticas Sociodemográficas (DIES)						   
# Gestión de Estadísticas Sociodemográficas en Base a Registros Administrativos (GESRA)  	   						   
# Aprobado por:													   
# Dirección de Estadísticas Sociodemográficas (DIES)				       
# Gestión de Estadísticas Sociodemográficas en Base a Registros Administrativos (GESRA)								       

#==============================================================================*.

#Indicaciones.

#1- Descargue la Carpeta Base de datos periodo vigente
#2- Cree una carpeta llamada EDF 2024 en el disco local C.

# Limpiamos la consola (área de trabajo)

rm(list = ls())

# Instalamos los paquetes "rio" y "tidyverse" en caso de no tenerlos

install.packages("rio")
install.packages("tidyverse")
install.packages("expss")

# Librerias ---------------------------------------------------------------

library(rio)
library(haven)
library(tidyverse)
library(openxlsx)
library(janitor)
library(readxl)
library(expss)
library("writexl")
library("reshape2")

# Cargamos la base de datos en formato xlsx y seguimos los siguientes:
# CREAMOS LA CAPETA EDF 2024
# COLOCAMOS LA BASE DE DATOS EN FORMATO xlsx CON EL SIGUIENTE NOMBRE: EDF_2024.xlsx
# Colocamos la ruta de la dirección en donde se encuentra la carpeta con la que vamos a trabajar

EDF_2024 <- read_sav("XXXX/EDF_2024.sav")

# Cargamos la base de datos y la guardamos en el objeto bd

bd <- EDF_2024
view(bd)


#   ----------------------------Creación de variables --------------------------------------------   #


# Crear la variable reg_res para clasificar a las provincias en regiones del Ecuador

bd <- bd %>%
  mutate(reg_res = if_else(anio_fall == 2024 & (prov_res >= "01" & prov_res <= "06"), 1, 0),
         reg_res = if_else(anio_fall == 2024 & (prov_res >= "10" & prov_res <= "11"), 1, reg_res),
         reg_res = if_else(anio_fall == 2024 & (prov_res >= "17" & prov_res <= "18"), 1, reg_res),
         reg_res = if_else(anio_fall == 2024 & (prov_res == "23"), 1, reg_res),
         reg_res = if_else(anio_fall == 2024 & (prov_res >= "07" & prov_res <= "09"), 2, reg_res),
         reg_res = if_else(anio_fall == 2024 & (prov_res >= "12" & prov_res <= "13"), 2, reg_res),
         reg_res = if_else(anio_fall == 2024 & (prov_res == "24"), 2, reg_res),
         reg_res = if_else(anio_fall == 2024 & (prov_res >= "14" & prov_res <= "16"), 3, reg_res),
         reg_res = if_else(anio_fall == 2024 & (prov_res == "19"), 3, reg_res),
         reg_res = if_else(anio_fall == 2024 & (prov_res >= "21" & prov_res <= "22"), 3, reg_res),
         reg_res = if_else(anio_fall == 2024 & (prov_res == "20"), 4, reg_res),
         reg_res = if_else(anio_fall == 2024 & (prov_res == "90"), 5, reg_res),
         reg_res = if_else(anio_fall == 2024 & (prov_res == "88"), 6, reg_res))


bd<-apply_labels(bd,
                 reg_res="Regiones del Ecuador")
as.numeric(bd$reg_res)

# Crear la variable reg_fall para clasificar a las provincias en regiones del Ecuador

bd <- bd %>%
  mutate(reg_fall = if_else(anio_fall == 2024 & ((prov_fall >= "01" & prov_fall <= "06")|(prov_fall >= "10" & prov_fall <= "11")|(prov_fall >= "17" & prov_fall <= "18")|(prov_fall == "23")), 1, 0),
         reg_fall = if_else(anio_fall == 2024 & (prov_fall >= "07" & prov_fall <= "09"), 2, reg_fall),
         reg_fall = if_else(anio_fall == 2024 & (prov_fall >= "12" & prov_fall <= "13"), 2, reg_fall),
         reg_fall = if_else(anio_fall == 2024 & (prov_fall == "24"), 2, reg_fall),
         reg_fall = if_else(anio_fall == 2024 & (prov_fall >= "14" & prov_fall <= "16"), 3, reg_fall),
         reg_fall = if_else(anio_fall == 2024 & (prov_fall == "19"), 3, reg_fall),
         reg_fall = if_else(anio_fall == 2024 & (prov_fall >= "21" & prov_fall <= "22"), 3, reg_fall),
         reg_fall = if_else(anio_fall == 2024 & (prov_fall == "20"), 4, reg_fall),
         reg_fall = if_else(anio_fall == 2024 & (prov_fall == "90"), 5, reg_fall),
         reg_fall = if_else(anio_fall == 2024 & (prov_fall == "88"), 6, reg_fall))


bd<-apply_labels(bd,
                 reg_fall="Regiones del Ecuador 2")
as.numeric(bd$reg_fall)

# Creamos la variable para el denominador: proyecciones de nacimientos

bd <- bd %>% 
  mutate(proy = if_else(prov_res == "01", 15408, 0),
         proy = if_else(prov_res == "02", 4233, proy),
         proy = if_else(prov_res == "03", 5559, proy),
         proy = if_else(prov_res == "04", 3271, proy),
         proy = if_else(prov_res == "05", 10568, proy),
         proy = if_else(prov_res == "06", 9930, proy),
         proy = if_else(prov_res == "07", 12333, proy),
         proy = if_else(prov_res == "08", 12847, proy),
         proy = if_else(prov_res == "09", 80007, proy),
         proy = if_else(prov_res == "10", 9964, proy),
         proy = if_else(prov_res == "11", 9866, proy),
         proy = if_else(prov_res == "12", 19038, proy),
         proy = if_else(prov_res == "13", 29893, proy),
         proy = if_else(prov_res == "14", 4989, proy),
         proy = if_else(prov_res == "15", 3416, proy),
         proy = if_else(prov_res == "16", 2745, proy),
         proy = if_else(prov_res == "17", 52478, proy),
         proy = if_else(prov_res == "18", 10241, proy),
         proy = if_else(prov_res == "19", 2805, proy),
         proy = if_else(prov_res == "21", 4938, proy),
         proy = if_else(prov_res == "22", 3321, proy),
         proy = if_else(prov_res == "23", 11766, proy),
         proy = if_else(prov_res == "24", 9223, proy))
         
bd<-apply_labels(bd,
                 proy="Proyección de nacimientos" )   
as.numeric(bd$proy)
table(bd$proy)

# Creamos la variable para determinar el Total Nacional


bd <- bd %>%
  mutate(t = if_else(anio_fall == 2024, 1, 0))

bd<-apply_labels(bd,
                 t="Total Nacional")
as.numeric(bd$t)

table(bd$t)

# Creamos la variable tipo de asistencia 


bd <- bd %>%
  mutate(tip_asis = case_when(
          asis_por %in% 1:1 ~ 1,
          asis_por %in% 5:5 ~ 1,
          asis_por %in% 8:8 ~ 1,
          asis_por %in% 2:3 ~ 2,
          asis_por %in% 4:4 ~ 3,
          asis_por %in% 6:7 ~ 3,
          asis_por %in% 9:9 ~ 9
          ))

    bd<-apply_labels(bd,
                 tip_asis="Tipo de asistencia")     

 # Creamos la variable asistencia 
    
    bd <- bd %>% 
      mutate(asis = case_when(
            tip_asis %in% 1:2 ~ 1,
            tip_asis %in% 3:3 ~ 2))
    
        bd<-apply_labels(bd,
                         asis="Asistencia")     
        
    

##Creación de la variable semanas de gestación

bd <- bd %>%
  mutate(semgest = case_when(
    sem_gest %in% 22:27 ~ 1,
    sem_gest %in% 28:31 ~ 2,
    sem_gest %in% 32:36 ~ 3,
    sem_gest %in% 37:41 ~ 4,
    sem_gest %in% 42:200 ~ 5,
    sem_gest %in% 99 ~ 6,
    TRUE ~ NA_integer_
  ))

bd<-apply_labels(bd,
                 semgest="Grupos semanas de gestación")  

##Creación de la variable edamad para grupos de edad de la madre

bd <- bd %>%
  mutate(edadmad = case_when(
    edad_mad %in% 10:14 ~ 1,
    edad_mad %in% 15:19 ~ 2,
    edad_mad %in% 20:24 ~ 3,
    edad_mad %in% 25:29 ~ 4,
    edad_mad %in% 30:34 ~ 5,
    edad_mad %in% 35:39 ~ 6,
    edad_mad %in% 40:44 ~ 7,
    edad_mad %in% 45:49 ~ 8,
    edad_mad %in% 50:99 ~ 9,
    edad_mad %in% 99 ~ 10,
    TRUE ~ NA_integer_
  ))

as.numeric(bd$edadmad)

table(bd$edadmad)

bd<-apply_labels(bd,
                 edadmad="Grupos edad  de la madre")  


##Creación de la variable vcausa

bd <- bd %>% 
  mutate(
    vcausa = case_when( causa_fetal == "P000" ~ "0",
                        causa_fetal == "P001" ~ "1",
                        causa_fetal == "P002" ~ "2",
                        causa_fetal == "P003" ~ "3",
                        causa_fetal == "P004" ~ "4",
                        causa_fetal == "P005" ~ "5",
                        causa_fetal == "P006" ~ "6",
                        causa_fetal == "P007" ~ "7",
                        causa_fetal == "P008" ~ "8",
                        causa_fetal == "P009" ~ "9",
                        causa_fetal == "P010" ~ "10",
                        causa_fetal == "P011" ~ "11",
                        causa_fetal == "P012" ~ "12",
                        causa_fetal == "P013" ~ "13",
                        causa_fetal == "P014" ~ "14",
                        causa_fetal == "P015" ~ "15",
                        causa_fetal == "P016" ~ "16",
                        causa_fetal == "P017" ~ "17",
                        causa_fetal == "P018" ~ "18",
                        causa_fetal == "P019" ~ "19",
                        causa_fetal == "P020" ~ "20",
                        causa_fetal == "P021" ~ "21",
                        causa_fetal == "P022" ~ "22",
                        causa_fetal == "P023" ~ "23",
                        causa_fetal == "P024" ~ "24",
                        causa_fetal == "P025" ~ "25",
                        causa_fetal == "P026" ~ "26",
                        causa_fetal == "P027" ~ "27",
                        causa_fetal == "P028" ~ "28",
                        causa_fetal == "P029" ~ "29",
                        causa_fetal == "P030" ~ "30",
                        causa_fetal == "P031" ~ "31",
                        causa_fetal == "P032" ~ "32",
                        causa_fetal == "P033" ~ "33",
                        causa_fetal == "P034" ~ "34",
                        causa_fetal == "P035" ~ "35",
                        causa_fetal == "P036" ~ "36",
                        causa_fetal == "P038" ~ "37",
                        causa_fetal == "P039" ~ "38",
                        causa_fetal == "P040" ~ "39",
                        causa_fetal == "P041" ~ "40",
                        causa_fetal == "P042" ~ "41",
                        causa_fetal == "P043" ~ "42",
                        causa_fetal == "P044" ~ "43",
                        causa_fetal == "P045" ~ "44",
                        causa_fetal == "P046" ~ "45",
                        causa_fetal == "P048" ~ "46",
                        causa_fetal == "P049" ~ "47",
                        causa_fetal == "P050" ~ "48",
                        causa_fetal == "P051" ~ "49",
                        causa_fetal == "P052" ~ "50",
                        causa_fetal == "P059" ~ "51",
                        causa_fetal == "P070" ~ "52",
                        causa_fetal == "P071" ~ "53",
                        causa_fetal == "P072" ~ "54",
                        causa_fetal == "P073" ~ "55",
                        causa_fetal == "P080" ~ "56",
                        causa_fetal == "P081" ~ "57",
                        causa_fetal == "P082" ~ "58",
                        causa_fetal == "P100" ~ "59",
                        causa_fetal == "P101" ~ "60",
                        causa_fetal == "P102" ~ "61",
                        causa_fetal == "P103" ~ "62",
                        causa_fetal == "P104" ~ "63",
                        causa_fetal == "P108" ~ "64",
                        causa_fetal == "P109" ~ "65",
                        causa_fetal == "P110" ~ "66",
                        causa_fetal == "P111" ~ "67",
                        causa_fetal == "P112" ~ "68",
                        causa_fetal == "P113" ~ "69",
                        causa_fetal == "P114" ~ "70",
                        causa_fetal == "P115" ~ "71",
                        causa_fetal == "P119" ~ "72",
                        causa_fetal == "P120" ~ "73",
                        causa_fetal == "P121" ~ "74",
                        causa_fetal == "P122" ~ "75",
                        causa_fetal == "P123" ~ "76",
                        causa_fetal == "P124" ~ "77",
                        causa_fetal == "P128" ~ "78",
                        causa_fetal == "P129" ~ "79",
                        causa_fetal == "P130" ~ "80",
                        causa_fetal == "P131" ~ "81",
                        causa_fetal == "P132" ~ "82",
                        causa_fetal == "P133" ~ "83",
                        causa_fetal == "P134" ~ "84",
                        causa_fetal == "P138" ~ "85",
                        causa_fetal == "P139" ~ "86",
                        causa_fetal == "P140" ~ "87",
                        causa_fetal == "P141" ~ "88",
                        causa_fetal == "P142" ~ "89",
                        causa_fetal == "P143" ~ "90",
                        causa_fetal == "P148" ~ "91",
                        causa_fetal == "P149" ~ "92",
                        causa_fetal == "P150" ~ "93",
                        causa_fetal == "P151" ~ "94",
                        causa_fetal == "P152" ~ "95",
                        causa_fetal == "P153" ~ "96",
                        causa_fetal == "P154" ~ "97",
                        causa_fetal == "P155" ~ "98",
                        causa_fetal == "P156" ~ "99",
                        causa_fetal == "P158" ~ "100",
                        causa_fetal == "P159" ~ "101",
                        causa_fetal == "P200" ~ "102",
                        causa_fetal == "P201" ~ "103",
                        causa_fetal == "P209" ~ "104",
                        causa_fetal == "P210" ~ "105",
                        causa_fetal == "P211" ~ "106",
                        causa_fetal == "P219" ~ "107",
                        causa_fetal == "P220" ~ "108",
                        causa_fetal == "P221" ~ "109",
                        causa_fetal == "P228" ~ "110",
                        causa_fetal == "P229" ~ "111",
                        causa_fetal == "P230" ~ "112",
                        causa_fetal == "P231" ~ "113",
                        causa_fetal == "P232" ~ "114",
                        causa_fetal == "P233" ~ "115",
                        causa_fetal == "P234" ~ "116",
                        causa_fetal == "P235" ~ "117",
                        causa_fetal == "P236" ~ "118",
                        causa_fetal == "P238" ~ "119",
                        causa_fetal == "P239" ~ "120",
                        causa_fetal == "P240" ~ "121",
                        causa_fetal == "P241" ~ "122",
                        causa_fetal == "P242" ~ "123",
                        causa_fetal == "P243" ~ "124",
                        causa_fetal == "P248" ~ "125",
                        causa_fetal == "P249" ~ "126",
                        causa_fetal == "P250" ~ "127",
                        causa_fetal == "P251" ~ "128",
                        causa_fetal == "P252" ~ "129",
                        causa_fetal == "P253" ~ "130",
                        causa_fetal == "P258" ~ "131",
                        causa_fetal == "P260" ~ "132",
                        causa_fetal == "P261" ~ "133",
                        causa_fetal == "P268" ~ "134",
                        causa_fetal == "P269" ~ "135",
                        causa_fetal == "P270" ~ "136",
                        causa_fetal == "P271" ~ "137",
                        causa_fetal == "P278" ~ "138",
                        causa_fetal == "P279" ~ "139",
                        causa_fetal == "P280" ~ "140",
                        causa_fetal == "P281" ~ "141",
                        causa_fetal == "P282" ~ "142",
                        causa_fetal == "P283" ~ "143",
                        causa_fetal == "P284" ~ "144",
                        causa_fetal == "P285" ~ "145",
                        causa_fetal == "P288" ~ "146",
                        causa_fetal == "P289" ~ "147",
                        causa_fetal == "P290" ~ "148",
                        causa_fetal == "P291" ~ "149",
                        causa_fetal == "P292" ~ "150",
                        causa_fetal == "P293" ~ "151",
                        causa_fetal == "P294" ~ "152",
                        causa_fetal == "P298" ~ "153",
                        causa_fetal == "P299" ~ "154",
                        causa_fetal == "P350" ~ "155",
                        causa_fetal == "P351" ~ "156",
                        causa_fetal == "P352" ~ "157",
                        causa_fetal == "P353" ~ "158",
                        causa_fetal == "P358" ~ "159",
                        causa_fetal == "P359" ~ "160",
                        causa_fetal == "P360" ~ "161",
                        causa_fetal == "P361" ~ "162",
                        causa_fetal == "P362" ~ "163",
                        causa_fetal == "P363" ~ "164",
                        causa_fetal == "P364" ~ "165",
                        causa_fetal == "P365" ~ "166",
                        causa_fetal == "P368" ~ "167",
                        causa_fetal == "P369" ~ "168",
                        causa_fetal == "P370" ~ "169",
                        causa_fetal == "P371" ~ "170",
                        causa_fetal == "P372" ~ "171",
                        causa_fetal == "P373" ~ "172",
                        causa_fetal == "P374" ~ "173",
                        causa_fetal == "P375" ~ "174",
                        causa_fetal == "P378" ~ "175",
                        causa_fetal == "P379" ~ "176",
                        causa_fetal == "P38" ~ "177",
                        causa_fetal == "P390" ~ "178",
                        causa_fetal == "P391" ~ "179",
                        causa_fetal == "P392" ~ "180",
                        causa_fetal == "P393" ~ "181",
                        causa_fetal == "P394" ~ "182",
                        causa_fetal == "P398" ~ "183",
                        causa_fetal == "P399" ~ "184",
                        causa_fetal == "P500" ~ "185",
                        causa_fetal == "P501" ~ "186",
                        causa_fetal == "P502" ~ "187",
                        causa_fetal == "P503" ~ "188",
                        causa_fetal == "P504" ~ "189",
                        causa_fetal == "P505" ~ "190",
                        causa_fetal == "P508" ~ "191",
                        causa_fetal == "P509" ~ "192",
                        causa_fetal == "P510" ~ "193",
                        causa_fetal == "P518" ~ "194",
                        causa_fetal == "P519" ~ "195",
                        causa_fetal == "P520" ~ "196",
                        causa_fetal == "P521" ~ "197",
                        causa_fetal == "P522" ~ "198",
                        causa_fetal == "P523" ~ "199",
                        causa_fetal == "P524" ~ "200",
                        causa_fetal == "P525" ~ "201",
                        causa_fetal == "P526" ~ "202",
                        causa_fetal == "P528" ~ "203",
                        causa_fetal == "P529" ~ "204",
                        causa_fetal == "P53" ~ "205",
                        causa_fetal == "P540" ~ "206",
                        causa_fetal == "P541" ~ "207",
                        causa_fetal == "P542" ~ "208",
                        causa_fetal == "P543" ~ "209",
                        causa_fetal == "P544" ~ "210",
                        causa_fetal == "P545" ~ "211",
                        causa_fetal == "P546" ~ "212",
                        causa_fetal == "P548" ~ "213",
                        causa_fetal == "P549" ~ "214",
                        causa_fetal == "P550" ~ "215",
                        causa_fetal == "P551" ~ "216",
                        causa_fetal == "P558" ~ "217",
                        causa_fetal == "P559" ~ "218",
                        causa_fetal == "P560" ~ "219",
                        causa_fetal == "P569" ~ "220",
                        causa_fetal == "P570" ~ "221",
                        causa_fetal == "P578" ~ "222",
                        causa_fetal == "P579" ~ "223",
                        causa_fetal == "P580" ~ "224",
                        causa_fetal == "P581" ~ "225",
                        causa_fetal == "P582" ~ "226",
                        causa_fetal == "P583" ~ "227",
                        causa_fetal == "P584" ~ "228",
                        causa_fetal == "P585" ~ "229",
                        causa_fetal == "P588" ~ "230",
                        causa_fetal == "P589" ~ "231",
                        causa_fetal == "P590" ~ "232",
                        causa_fetal == "P591" ~ "233",
                        causa_fetal == "P592" ~ "234",
                        causa_fetal == "P593" ~ "235",
                        causa_fetal == "P598" ~ "236",
                        causa_fetal == "P599" ~ "237",
                        causa_fetal == "P60" ~ "238",
                        causa_fetal == "P610" ~ "239",
                        causa_fetal == "P611" ~ "240",
                        causa_fetal == "P612" ~ "241",
                        causa_fetal == "P613" ~ "242",
                        causa_fetal == "P614" ~ "243",
                        causa_fetal == "P615" ~ "244",
                        causa_fetal == "P616" ~ "245",
                        causa_fetal == "P618" ~ "246",
                        causa_fetal == "P619" ~ "247",
                        causa_fetal == "P700" ~ "248",
                        causa_fetal == "P701" ~ "249",
                        causa_fetal == "P702" ~ "250",
                        causa_fetal == "P703" ~ "251",
                        causa_fetal == "P704" ~ "252",
                        causa_fetal == "P708" ~ "253",
                        causa_fetal == "P709" ~ "254",
                        causa_fetal == "P710" ~ "255",
                        causa_fetal == "P711" ~ "256",
                        causa_fetal == "P712" ~ "257",
                        causa_fetal == "P713" ~ "258",
                        causa_fetal == "P714" ~ "259",
                        causa_fetal == "P718" ~ "260",
                        causa_fetal == "P719" ~ "261",
                        causa_fetal == "P720" ~ "262",
                        causa_fetal == "P721" ~ "263",
                        causa_fetal == "P722" ~ "264",
                        causa_fetal == "P728" ~ "265",
                        causa_fetal == "P729" ~ "266",
                        causa_fetal == "P740" ~ "267",
                        causa_fetal == "P741" ~ "268",
                        causa_fetal == "P742" ~ "269",
                        causa_fetal == "P743" ~ "270",
                        causa_fetal == "P744" ~ "271",
                        causa_fetal == "P745" ~ "272",
                        causa_fetal == "P748" ~ "273",
                        causa_fetal == "P749" ~ "274",
                        causa_fetal == "P75*" ~ "275",
                        causa_fetal == "P760" ~ "276",
                        causa_fetal == "P761" ~ "277",
                        causa_fetal == "P762" ~ "278",
                        causa_fetal == "P768" ~ "279",
                        causa_fetal == "P769" ~ "280",
                        causa_fetal == "P77" ~ "281",
                        causa_fetal == "P780" ~ "282",
                        causa_fetal == "P781" ~ "283",
                        causa_fetal == "P782" ~ "284",
                        causa_fetal == "P783" ~ "285",
                        causa_fetal == "P788" ~ "286",
                        causa_fetal == "P789" ~ "287",
                        causa_fetal == "P800" ~ "288",
                        causa_fetal == "P808" ~ "289",
                        causa_fetal == "P809" ~ "290",
                        causa_fetal == "P810" ~ "291",
                        causa_fetal == "P818" ~ "292",
                        causa_fetal == "P819" ~ "293",
                        causa_fetal == "P830" ~ "294",
                        causa_fetal == "P831" ~ "295",
                        causa_fetal == "P832" ~ "296",
                        causa_fetal == "P833" ~ "297",
                        causa_fetal == "P834" ~ "298",
                        causa_fetal == "P835" ~ "299",
                        causa_fetal == "P836" ~ "300",
                        causa_fetal == "P838" ~ "301",
                        causa_fetal == "P839" ~ "302",
                        causa_fetal == "P90" ~ "303",
                        causa_fetal == "P910" ~ "304",
                        causa_fetal == "P911" ~ "305",
                        causa_fetal == "P912" ~ "306",
                        causa_fetal == "P913" ~ "307",
                        causa_fetal == "P914" ~ "308",
                        causa_fetal == "P915" ~ "309",
                        causa_fetal == "P918" ~ "310",
                        causa_fetal == "P919" ~ "311",
                        causa_fetal == "P920" ~ "312",
                        causa_fetal == "P921" ~ "313",
                        causa_fetal == "P922" ~ "314",
                        causa_fetal == "P923" ~ "315",
                        causa_fetal == "P924" ~ "316",
                        causa_fetal == "P925" ~ "317",
                        causa_fetal == "P928" ~ "318",
                        causa_fetal == "P929" ~ "319",
                        causa_fetal == "P93" ~ "320",
                        causa_fetal == "P940" ~ "321",
                        causa_fetal == "P941" ~ "322",
                        causa_fetal == "P942" ~ "323",
                        causa_fetal == "P948" ~ "324",
                        causa_fetal == "P949" ~ "325",
                        causa_fetal == "P95" ~ "326",
                        causa_fetal == "P960" ~ "327",
                        causa_fetal == "P961" ~ "328",
                        causa_fetal == "P962" ~ "329",
                        causa_fetal == "P963" ~ "330",
                        causa_fetal == "P964" ~ "331",
                        causa_fetal == "P965" ~ "332",
                        causa_fetal == "P968" ~ "333",
                        causa_fetal == "P969" ~ "334",
                        causa_fetal == "Q000" ~ "335",
                        causa_fetal == "Q001" ~ "336",
                        causa_fetal == "Q002" ~ "337",
                        causa_fetal == "Q010" ~ "338",
                        causa_fetal == "Q011" ~ "339",
                        causa_fetal == "Q012" ~ "340",
                        causa_fetal == "Q018" ~ "341",
                        causa_fetal == "Q019" ~ "342",
                        causa_fetal == "Q02" ~ "343",
                        causa_fetal == "Q030" ~ "344",
                        causa_fetal == "Q031" ~ "345",
                        causa_fetal == "Q038" ~ "346",
                        causa_fetal == "Q039" ~ "347",
                        causa_fetal == "Q040" ~ "348",
                        causa_fetal == "Q041" ~ "349",
                        causa_fetal == "Q042" ~ "350",
                        causa_fetal == "Q043" ~ "351",
                        causa_fetal == "Q044" ~ "352",
                        causa_fetal == "Q045" ~ "353",
                        causa_fetal == "Q046" ~ "354",
                        causa_fetal == "Q048" ~ "355",
                        causa_fetal == "Q049" ~ "356",
                        causa_fetal == "Q050" ~ "357",
                        causa_fetal == "Q051" ~ "358",
                        causa_fetal == "Q052" ~ "359",
                        causa_fetal == "Q053" ~ "360",
                        causa_fetal == "Q054" ~ "361",
                        causa_fetal == "Q055" ~ "362",
                        causa_fetal == "Q056" ~ "363",
                        causa_fetal == "Q057" ~ "364",
                        causa_fetal == "Q058" ~ "365",
                        causa_fetal == "Q059" ~ "366",
                        causa_fetal == "Q060" ~ "367",
                        causa_fetal == "Q061" ~ "368",
                        causa_fetal == "Q062" ~ "369",
                        causa_fetal == "Q063" ~ "370",
                        causa_fetal == "Q064" ~ "371",
                        causa_fetal == "Q068" ~ "372",
                        causa_fetal == "Q069" ~ "373",
                        causa_fetal == "Q070" ~ "374",
                        causa_fetal == "Q078" ~ "375",
                        causa_fetal == "Q079" ~ "376",
                        causa_fetal == "Q100" ~ "377",
                        causa_fetal == "Q101" ~ "378",
                        causa_fetal == "Q102" ~ "379",
                        causa_fetal == "Q103" ~ "380",
                        causa_fetal == "Q104" ~ "381",
                        causa_fetal == "Q105" ~ "382",
                        causa_fetal == "Q106" ~ "383",
                        causa_fetal == "Q107" ~ "384",
                        causa_fetal == "Q110" ~ "385",
                        causa_fetal == "Q111" ~ "386",
                        causa_fetal == "Q112" ~ "387",
                        causa_fetal == "Q113" ~ "388",
                        causa_fetal == "Q120" ~ "389",
                        causa_fetal == "Q121" ~ "390",
                        causa_fetal == "Q122" ~ "391",
                        causa_fetal == "Q123" ~ "392",
                        causa_fetal == "Q124" ~ "393",
                        causa_fetal == "Q128" ~ "394",
                        causa_fetal == "Q129" ~ "395",
                        causa_fetal == "Q130" ~ "396",
                        causa_fetal == "Q131" ~ "397",
                        causa_fetal == "Q132" ~ "398",
                        causa_fetal == "Q133" ~ "399",
                        causa_fetal == "Q134" ~ "400",
                        causa_fetal == "Q135" ~ "401",
                        causa_fetal == "Q138" ~ "402",
                        causa_fetal == "Q139" ~ "403",
                        causa_fetal == "Q140" ~ "404",
                        causa_fetal == "Q141" ~ "405",
                        causa_fetal == "Q142" ~ "406",
                        causa_fetal == "Q143" ~ "407",
                        causa_fetal == "Q148" ~ "408",
                        causa_fetal == "Q149" ~ "409",
                        causa_fetal == "Q150" ~ "410",
                        causa_fetal == "Q158" ~ "411",
                        causa_fetal == "Q159" ~ "412",
                        causa_fetal == "Q160" ~ "413",
                        causa_fetal == "Q161" ~ "414",
                        causa_fetal == "Q162" ~ "415",
                        causa_fetal == "Q163" ~ "416",
                        causa_fetal == "Q164" ~ "417",
                        causa_fetal == "Q165" ~ "418",
                        causa_fetal == "Q169" ~ "419",
                        causa_fetal == "Q170" ~ "420",
                        causa_fetal == "Q171" ~ "421",
                        causa_fetal == "Q172" ~ "422",
                        causa_fetal == "Q173" ~ "423",
                        causa_fetal == "Q174" ~ "424",
                        causa_fetal == "Q175" ~ "425",
                        causa_fetal == "Q178" ~ "426",
                        causa_fetal == "Q179" ~ "427",
                        causa_fetal == "Q180" ~ "428",
                        causa_fetal == "Q181" ~ "429",
                        causa_fetal == "Q182" ~ "430",
                        causa_fetal == "Q183" ~ "431",
                        causa_fetal == "Q184" ~ "432",
                        causa_fetal == "Q185" ~ "433",
                        causa_fetal == "Q186" ~ "434",
                        causa_fetal == "Q187" ~ "435",
                        causa_fetal == "Q188" ~ "436",
                        causa_fetal == "Q189" ~ "437",
                        causa_fetal == "Q200" ~ "438",
                        causa_fetal == "Q201" ~ "439",
                        causa_fetal == "Q202" ~ "440",
                        causa_fetal == "Q203" ~ "441",
                        causa_fetal == "Q204" ~ "442",
                        causa_fetal == "Q205" ~ "443",
                        causa_fetal == "Q206" ~ "444",
                        causa_fetal == "Q208" ~ "445",
                        causa_fetal == "Q209" ~ "446",
                        causa_fetal == "Q210" ~ "447",
                        causa_fetal == "Q211" ~ "448",
                        causa_fetal == "Q212" ~ "449",
                        causa_fetal == "Q213" ~ "450",
                        causa_fetal == "Q214" ~ "451",
                        causa_fetal == "Q218" ~ "452",
                        causa_fetal == "Q219" ~ "453",
                        causa_fetal == "Q220" ~ "454",
                        causa_fetal == "Q221" ~ "455",
                        causa_fetal == "Q222" ~ "456",
                        causa_fetal == "Q223" ~ "457",
                        causa_fetal == "Q224" ~ "458",
                        causa_fetal == "Q225" ~ "459",
                        causa_fetal == "Q226" ~ "460",
                        causa_fetal == "Q228" ~ "461",
                        causa_fetal == "Q229" ~ "462",
                        causa_fetal == "Q230" ~ "463",
                        causa_fetal == "Q231" ~ "464",
                        causa_fetal == "Q232" ~ "465",
                        causa_fetal == "Q233" ~ "466",
                        causa_fetal == "Q234" ~ "467",
                        causa_fetal == "Q238" ~ "468",
                        causa_fetal == "Q239" ~ "469",
                        causa_fetal == "Q240" ~ "470",
                        causa_fetal == "Q241" ~ "471",
                        causa_fetal == "Q242" ~ "472",
                        causa_fetal == "Q243" ~ "473",
                        causa_fetal == "Q244" ~ "474",
                        causa_fetal == "Q245" ~ "475",
                        causa_fetal == "Q246" ~ "476",
                        causa_fetal == "Q248" ~ "477",
                        causa_fetal == "Q249" ~ "478",
                        causa_fetal == "Q250" ~ "479",
                        causa_fetal == "Q251" ~ "480",
                        causa_fetal == "Q252" ~ "481",
                        causa_fetal == "Q253" ~ "482",
                        causa_fetal == "Q254" ~ "483",
                        causa_fetal == "Q255" ~ "484",
                        causa_fetal == "Q256" ~ "485",
                        causa_fetal == "Q257" ~ "486",
                        causa_fetal == "Q258" ~ "487",
                        causa_fetal == "Q259" ~ "488",
                        causa_fetal == "Q260" ~ "489",
                        causa_fetal == "Q261" ~ "490",
                        causa_fetal == "Q262" ~ "491",
                        causa_fetal == "Q263" ~ "492",
                        causa_fetal == "Q264" ~ "493",
                        causa_fetal == "Q265" ~ "494",
                        causa_fetal == "Q266" ~ "495",
                        causa_fetal == "Q268" ~ "496",
                        causa_fetal == "Q269" ~ "497",
                        causa_fetal == "Q270" ~ "498",
                        causa_fetal == "Q271" ~ "499",
                        causa_fetal == "Q272" ~ "500",
                        causa_fetal == "Q273" ~ "501",
                        causa_fetal == "Q274" ~ "502",
                        causa_fetal == "Q278" ~ "503",
                        causa_fetal == "Q279" ~ "504",
                        causa_fetal == "Q280" ~ "505",
                        causa_fetal == "Q281" ~ "506",
                        causa_fetal == "Q282" ~ "507",
                        causa_fetal == "Q283" ~ "508",
                        causa_fetal == "Q288" ~ "509",
                        causa_fetal == "Q289" ~ "510",
                        causa_fetal == "Q300" ~ "511",
                        causa_fetal == "Q301" ~ "512",
                        causa_fetal == "Q302" ~ "513",
                        causa_fetal == "Q303" ~ "514",
                        causa_fetal == "Q308" ~ "515",
                        causa_fetal == "Q309" ~ "516",
                        causa_fetal == "Q310" ~ "517",
                        causa_fetal == "Q311" ~ "518",
                        causa_fetal == "Q312" ~ "519",
                        causa_fetal == "Q313" ~ "520",
                        causa_fetal == "Q314" ~ "521",
                        causa_fetal == "Q318" ~ "522",
                        causa_fetal == "Q319" ~ "523",
                        causa_fetal == "Q320" ~ "524",
                        causa_fetal == "Q321" ~ "525",
                        causa_fetal == "Q322" ~ "526",
                        causa_fetal == "Q323" ~ "527",
                        causa_fetal == "Q324" ~ "528",
                        causa_fetal == "Q330" ~ "529",
                        causa_fetal == "Q331" ~ "530",
                        causa_fetal == "Q332" ~ "531",
                        causa_fetal == "Q333" ~ "532",
                        causa_fetal == "Q334" ~ "533",
                        causa_fetal == "Q335" ~ "534",
                        causa_fetal == "Q336" ~ "535",
                        causa_fetal == "Q338" ~ "536",
                        causa_fetal == "Q339" ~ "537",
                        causa_fetal == "Q340" ~ "538",
                        causa_fetal == "Q341" ~ "539",
                        causa_fetal == "Q348" ~ "540",
                        causa_fetal == "Q349" ~ "541",
                        causa_fetal == "Q351" ~ "543",
                        causa_fetal == "Q352" ~ "544",
                        causa_fetal == "Q353" ~ "545",
                        causa_fetal == "Q355" ~ "547",
                        causa_fetal == "Q357" ~ "549",
                        causa_fetal == "Q359" ~ "551",
                        causa_fetal == "Q360" ~ "552",
                        causa_fetal == "Q361" ~ "553",
                        causa_fetal == "Q369" ~ "554",
                        causa_fetal == "Q370" ~ "555",
                        causa_fetal == "Q371" ~ "556",
                        causa_fetal == "Q372" ~ "557",
                        causa_fetal == "Q373" ~ "558",
                        causa_fetal == "Q374" ~ "559",
                        causa_fetal == "Q375" ~ "560",
                        causa_fetal == "Q378" ~ "561",
                        causa_fetal == "Q379" ~ "562",
                        causa_fetal == "Q380" ~ "563",
                        causa_fetal == "Q381" ~ "564",
                        causa_fetal == "Q382" ~ "565",
                        causa_fetal == "Q383" ~ "566",
                        causa_fetal == "Q384" ~ "567",
                        causa_fetal == "Q385" ~ "568",
                        causa_fetal == "Q386" ~ "569",
                        causa_fetal == "Q387" ~ "570",
                        causa_fetal == "Q388" ~ "571",
                        causa_fetal == "Q390" ~ "572",
                        causa_fetal == "Q391" ~ "573",
                        causa_fetal == "Q392" ~ "574",
                        causa_fetal == "Q393" ~ "575",
                        causa_fetal == "Q394" ~ "576",
                        causa_fetal == "Q395" ~ "577",
                        causa_fetal == "Q396" ~ "578",
                        causa_fetal == "Q398" ~ "579",
                        causa_fetal == "Q399" ~ "580",
                        causa_fetal == "Q400" ~ "581",
                        causa_fetal == "Q401" ~ "582",
                        causa_fetal == "Q402" ~ "583",
                        causa_fetal == "Q403" ~ "584",
                        causa_fetal == "Q408" ~ "585",
                        causa_fetal == "Q409" ~ "586",
                        causa_fetal == "Q410" ~ "587",
                        causa_fetal == "Q411" ~ "588",
                        causa_fetal == "Q412" ~ "589",
                        causa_fetal == "Q418" ~ "590",
                        causa_fetal == "Q419" ~ "591",
                        causa_fetal == "Q420" ~ "592",
                        causa_fetal == "Q421" ~ "593",
                        causa_fetal == "Q422" ~ "594",
                        causa_fetal == "Q423" ~ "595",
                        causa_fetal == "Q428" ~ "596",
                        causa_fetal == "Q429" ~ "597",
                        causa_fetal == "Q430" ~ "598",
                        causa_fetal == "Q431" ~ "599",
                        causa_fetal == "Q432" ~ "600",
                        causa_fetal == "Q433" ~ "601",
                        causa_fetal == "Q434" ~ "602",
                        causa_fetal == "Q435" ~ "603",
                        causa_fetal == "Q436" ~ "604",
                        causa_fetal == "Q437" ~ "605",
                        causa_fetal == "Q438" ~ "606",
                        causa_fetal == "Q439" ~ "607",
                        causa_fetal == "Q440" ~ "608",
                        causa_fetal == "Q441" ~ "609",
                        causa_fetal == "Q442" ~ "610",
                        causa_fetal == "Q443" ~ "611",
                        causa_fetal == "Q444" ~ "612",
                        causa_fetal == "Q445" ~ "613",
                        causa_fetal == "Q446" ~ "614",
                        causa_fetal == "Q447" ~ "615",
                        causa_fetal == "Q450" ~ "616",
                        causa_fetal == "Q451" ~ "617",
                        causa_fetal == "Q452" ~ "618",
                        causa_fetal == "Q453" ~ "619",
                        causa_fetal == "Q458" ~ "620",
                        causa_fetal == "Q459" ~ "621",
                        causa_fetal == "Q500" ~ "622",
                        causa_fetal == "Q501" ~ "623",
                        causa_fetal == "Q502" ~ "624",
                        causa_fetal == "Q503" ~ "625",
                        causa_fetal == "Q504" ~ "626",
                        causa_fetal == "Q505" ~ "627",
                        causa_fetal == "Q506" ~ "628",
                        causa_fetal == "Q510" ~ "629",
                        causa_fetal == "Q511" ~ "630",
                        causa_fetal == "Q512" ~ "631",
                        causa_fetal == "Q513" ~ "632",
                        causa_fetal == "Q514" ~ "633",
                        causa_fetal == "Q515" ~ "634",
                        causa_fetal == "Q516" ~ "635",
                        causa_fetal == "Q517" ~ "636",
                        causa_fetal == "Q518" ~ "637",
                        causa_fetal == "Q519" ~ "638",
                        causa_fetal == "Q520" ~ "639",
                        causa_fetal == "Q521" ~ "640",
                        causa_fetal == "Q522" ~ "641",
                        causa_fetal == "Q523" ~ "642",
                        causa_fetal == "Q524" ~ "643",
                        causa_fetal == "Q525" ~ "644",
                        causa_fetal == "Q526" ~ "645",
                        causa_fetal == "Q527" ~ "646",
                        causa_fetal == "Q528" ~ "647",
                        causa_fetal == "Q529" ~ "648",
                        causa_fetal == "Q530" ~ "649",
                        causa_fetal == "Q531" ~ "650",
                        causa_fetal == "Q532" ~ "651",
                        causa_fetal == "Q539" ~ "652",
                        causa_fetal == "Q540" ~ "653",
                        causa_fetal == "Q541" ~ "654",
                        causa_fetal == "Q542" ~ "655",
                        causa_fetal == "Q543" ~ "656",
                        causa_fetal == "Q544" ~ "657",
                        causa_fetal == "Q548" ~ "658",
                        causa_fetal == "Q549" ~ "659",
                        causa_fetal == "Q550" ~ "660",
                        causa_fetal == "Q551" ~ "661",
                        causa_fetal == "Q552" ~ "662",
                        causa_fetal == "Q553" ~ "663",
                        causa_fetal == "Q554" ~ "664",
                        causa_fetal == "Q555" ~ "665",
                        causa_fetal == "Q556" ~ "666",
                        causa_fetal == "Q558" ~ "667",
                        causa_fetal == "Q559" ~ "668",
                        causa_fetal == "Q560" ~ "669",
                        causa_fetal == "Q561" ~ "670",
                        causa_fetal == "Q562" ~ "671",
                        causa_fetal == "Q563" ~ "672",
                        causa_fetal == "Q564" ~ "673",
                        causa_fetal == "Q600" ~ "674",
                        causa_fetal == "Q601" ~ "675",
                        causa_fetal == "Q602" ~ "676",
                        causa_fetal == "Q603" ~ "677",
                        causa_fetal == "Q604" ~ "678",
                        causa_fetal == "Q605" ~ "679",
                        causa_fetal == "Q606" ~ "680",
                        causa_fetal == "Q610" ~ "681",
                        causa_fetal == "Q611" ~ "682",
                        causa_fetal == "Q612" ~ "683",
                        causa_fetal == "Q613" ~ "684",
                        causa_fetal == "Q614" ~ "685",
                        causa_fetal == "Q615" ~ "686",
                        causa_fetal == "Q618" ~ "687",
                        causa_fetal == "Q619" ~ "688",
                        causa_fetal == "Q620" ~ "689",
                        causa_fetal == "Q621" ~ "690",
                        causa_fetal == "Q622" ~ "691",
                        causa_fetal == "Q623" ~ "692",
                        causa_fetal == "Q624" ~ "693",
                        causa_fetal == "Q625" ~ "694",
                        causa_fetal == "Q626" ~ "695",
                        causa_fetal == "Q627" ~ "696",
                        causa_fetal == "Q628" ~ "697",
                        causa_fetal == "Q630" ~ "698",
                        causa_fetal == "Q631" ~ "699",
                        causa_fetal == "Q632" ~ "700",
                        causa_fetal == "Q633" ~ "701",
                        causa_fetal == "Q638" ~ "702",
                        causa_fetal == "Q639" ~ "703",
                        causa_fetal == "Q640" ~ "704",
                        causa_fetal == "Q641" ~ "705",
                        causa_fetal == "Q642" ~ "706",
                        causa_fetal == "Q643" ~ "707",
                        causa_fetal == "Q644" ~ "708",
                        causa_fetal == "Q645" ~ "709",
                        causa_fetal == "Q646" ~ "710",
                        causa_fetal == "Q647" ~ "711",
                        causa_fetal == "Q648" ~ "712",
                        causa_fetal == "Q649" ~ "713",
                        causa_fetal == "Q650" ~ "714",
                        causa_fetal == "Q651" ~ "715",
                        causa_fetal == "Q652" ~ "716",
                        causa_fetal == "Q653" ~ "717",
                        causa_fetal == "Q654" ~ "718",
                        causa_fetal == "Q655" ~ "719",
                        causa_fetal == "Q656" ~ "720",
                        causa_fetal == "Q658" ~ "721",
                        causa_fetal == "Q659" ~ "722",
                        causa_fetal == "Q660" ~ "723",
                        causa_fetal == "Q661" ~ "724",
                        causa_fetal == "Q662" ~ "725",
                        causa_fetal == "Q663" ~ "726",
                        causa_fetal == "Q664" ~ "727",
                        causa_fetal == "Q665" ~ "728",
                        causa_fetal == "Q666" ~ "729",
                        causa_fetal == "Q667" ~ "730",
                        causa_fetal == "Q668" ~ "731",
                        causa_fetal == "Q669" ~ "732",
                        causa_fetal == "Q670" ~ "733",
                        causa_fetal == "Q671" ~ "734",
                        causa_fetal == "Q672" ~ "735",
                        causa_fetal == "Q673" ~ "736",
                        causa_fetal == "Q674" ~ "737",
                        causa_fetal == "Q675" ~ "738",
                        causa_fetal == "Q676" ~ "739",
                        causa_fetal == "Q677" ~ "740",
                        causa_fetal == "Q678" ~ "741",
                        causa_fetal == "Q680" ~ "742",
                        causa_fetal == "Q681" ~ "743",
                        causa_fetal == "Q682" ~ "744",
                        causa_fetal == "Q683" ~ "745",
                        causa_fetal == "Q684" ~ "746",
                        causa_fetal == "Q685" ~ "747",
                        causa_fetal == "Q688" ~ "748",
                        causa_fetal == "Q690" ~ "749",
                        causa_fetal == "Q691" ~ "750",
                        causa_fetal == "Q692" ~ "751",
                        causa_fetal == "Q699" ~ "752",
                        causa_fetal == "Q700" ~ "753",
                        causa_fetal == "Q701" ~ "754",
                        causa_fetal == "Q702" ~ "755",
                        causa_fetal == "Q703" ~ "756",
                        causa_fetal == "Q704" ~ "757",
                        causa_fetal == "Q709" ~ "758",
                        causa_fetal == "Q710" ~ "759",
                        causa_fetal == "Q711" ~ "760",
                        causa_fetal == "Q712" ~ "761",
                        causa_fetal == "Q713" ~ "762",
                        causa_fetal == "Q714" ~ "763",
                        causa_fetal == "Q715" ~ "764",
                        causa_fetal == "Q716" ~ "765",
                        causa_fetal == "Q718" ~ "766",
                        causa_fetal == "Q719" ~ "767",
                        causa_fetal == "Q720" ~ "768",
                        causa_fetal == "Q721" ~ "769",
                        causa_fetal == "Q722" ~ "770",
                        causa_fetal == "Q723" ~ "771",
                        causa_fetal == "Q724" ~ "772",
                        causa_fetal == "Q725" ~ "773",
                        causa_fetal == "Q726" ~ "774",
                        causa_fetal == "Q727" ~ "775",
                        causa_fetal == "Q728" ~ "776",
                        causa_fetal == "Q729" ~ "777",
                        causa_fetal == "Q730" ~ "778",
                        causa_fetal == "Q731" ~ "779",
                        causa_fetal == "Q738" ~ "780",
                        causa_fetal == "Q740" ~ "781",
                        causa_fetal == "Q741" ~ "782",
                        causa_fetal == "Q742" ~ "783",
                        causa_fetal == "Q743" ~ "784",
                        causa_fetal == "Q748" ~ "785",
                        causa_fetal == "Q749" ~ "786",
                        causa_fetal == "Q750" ~ "787",
                        causa_fetal == "Q751" ~ "788",
                        causa_fetal == "Q752" ~ "789",
                        causa_fetal == "Q753" ~ "790",
                        causa_fetal == "Q754" ~ "791",
                        causa_fetal == "Q755" ~ "792",
                        causa_fetal == "Q758" ~ "793",
                        causa_fetal == "Q759" ~ "794",
                        causa_fetal == "Q760" ~ "795",
                        causa_fetal == "Q761" ~ "796",
                        causa_fetal == "Q762" ~ "797",
                        causa_fetal == "Q763" ~ "798",
                        causa_fetal == "Q764" ~ "799",
                        causa_fetal == "Q765" ~ "800",
                        causa_fetal == "Q766" ~ "801",
                        causa_fetal == "Q767" ~ "802",
                        causa_fetal == "Q768" ~ "803",
                        causa_fetal == "Q769" ~ "804",
                        causa_fetal == "Q770" ~ "805",
                        causa_fetal == "Q771" ~ "806",
                        causa_fetal == "Q772" ~ "807",
                        causa_fetal == "Q773" ~ "808",
                        causa_fetal == "Q774" ~ "809",
                        causa_fetal == "Q775" ~ "810",
                        causa_fetal == "Q776" ~ "811",
                        causa_fetal == "Q777" ~ "812",
                        causa_fetal == "Q778" ~ "813",
                        causa_fetal == "Q779" ~ "814",
                        causa_fetal == "Q780" ~ "815",
                        causa_fetal == "Q781" ~ "816",
                        causa_fetal == "Q782" ~ "817",
                        causa_fetal == "Q783" ~ "818",
                        causa_fetal == "Q784" ~ "819",
                        causa_fetal == "Q785" ~ "820",
                        causa_fetal == "Q786" ~ "821",
                        causa_fetal == "Q788" ~ "822",
                        causa_fetal == "Q789" ~ "823",
                        causa_fetal == "Q790" ~ "824",
                        causa_fetal == "Q791" ~ "825",
                        causa_fetal == "Q792" ~ "826",
                        causa_fetal == "Q793" ~ "827",
                        causa_fetal == "Q794" ~ "828",
                        causa_fetal == "Q795" ~ "829",
                        causa_fetal == "Q796" ~ "830",
                        causa_fetal == "Q798" ~ "831",
                        causa_fetal == "Q799" ~ "832",
                        causa_fetal == "Q800" ~ "833",
                        causa_fetal == "Q801" ~ "834",
                        causa_fetal == "Q802" ~ "835",
                        causa_fetal == "Q803" ~ "836",
                        causa_fetal == "Q804" ~ "837",
                        causa_fetal == "Q808" ~ "838",
                        causa_fetal == "Q809" ~ "839",
                        causa_fetal == "Q810" ~ "840",
                        causa_fetal == "Q811" ~ "841",
                        causa_fetal == "Q812" ~ "842",
                        causa_fetal == "Q818" ~ "843",
                        causa_fetal == "Q819" ~ "844",
                        causa_fetal == "Q820" ~ "845",
                        causa_fetal == "Q821" ~ "846",
                        causa_fetal == "Q822" ~ "847",
                        causa_fetal == "Q823" ~ "848",
                        causa_fetal == "Q824" ~ "849",
                        causa_fetal == "Q825" ~ "850",
                        causa_fetal == "Q828" ~ "851",
                        causa_fetal == "Q829" ~ "852",
                        causa_fetal == "Q830" ~ "853",
                        causa_fetal == "Q831" ~ "854",
                        causa_fetal == "Q832" ~ "855",
                        causa_fetal == "Q833" ~ "856",
                        causa_fetal == "Q838" ~ "857",
                        causa_fetal == "Q839" ~ "858",
                        causa_fetal == "Q840" ~ "859",
                        causa_fetal == "Q841" ~ "860",
                        causa_fetal == "Q842" ~ "861",
                        causa_fetal == "Q843" ~ "862",
                        causa_fetal == "Q844" ~ "863",
                        causa_fetal == "Q845" ~ "864",
                        causa_fetal == "Q846" ~ "865",
                        causa_fetal == "Q848" ~ "866",
                        causa_fetal == "Q849" ~ "867",
                        causa_fetal == "Q850" ~ "868",
                        causa_fetal == "Q851" ~ "869",
                        causa_fetal == "Q858" ~ "870",
                        causa_fetal == "Q859" ~ "871",
                        causa_fetal == "Q860" ~ "872",
                        causa_fetal == "Q861" ~ "873",
                        causa_fetal == "Q862" ~ "874",
                        causa_fetal == "Q868" ~ "875",
                        causa_fetal == "Q870" ~ "876",
                        causa_fetal == "Q871" ~ "877",
                        causa_fetal == "Q872" ~ "878",
                        causa_fetal == "Q873" ~ "879",
                        causa_fetal == "Q874" ~ "880",
                        causa_fetal == "Q875" ~ "881",
                        causa_fetal == "Q878" ~ "882",
                        causa_fetal == "Q890" ~ "883",
                        causa_fetal == "Q891" ~ "884",
                        causa_fetal == "Q892" ~ "885",
                        causa_fetal == "Q893" ~ "886",
                        causa_fetal == "Q894" ~ "887",
                        causa_fetal == "Q897" ~ "888",
                        causa_fetal == "Q898" ~ "889",
                        causa_fetal == "Q899" ~ "890",
                        causa_fetal == "Q900" ~ "891",
                        causa_fetal == "Q901" ~ "892",
                        causa_fetal == "Q902" ~ "893",
                        causa_fetal == "Q909" ~ "894",
                        causa_fetal == "Q910" ~ "895",
                        causa_fetal == "Q911" ~ "896",
                        causa_fetal == "Q912" ~ "897",
                        causa_fetal == "Q913" ~ "898",
                        causa_fetal == "Q914" ~ "899",
                        causa_fetal == "Q915" ~ "900",
                        causa_fetal == "Q916" ~ "901",
                        causa_fetal == "Q917" ~ "902",
                        causa_fetal == "Q920" ~ "903",
                        causa_fetal == "Q921" ~ "904",
                        causa_fetal == "Q922" ~ "905",
                        causa_fetal == "Q923" ~ "906",
                        causa_fetal == "Q924" ~ "907",
                        causa_fetal == "Q925" ~ "908",
                        causa_fetal == "Q926" ~ "909",
                        causa_fetal == "Q927" ~ "910",
                        causa_fetal == "Q928" ~ "911",
                        causa_fetal == "Q929" ~ "912",
                        causa_fetal == "Q930" ~ "913",
                        causa_fetal == "Q931" ~ "914",
                        causa_fetal == "Q932" ~ "915",
                        causa_fetal == "Q933" ~ "916",
                        causa_fetal == "Q934" ~ "917",
                        causa_fetal == "Q935" ~ "918",
                        causa_fetal == "Q936" ~ "919",
                        causa_fetal == "Q937" ~ "920",
                        causa_fetal == "Q938" ~ "921",
                        causa_fetal == "Q939" ~ "922",
                        causa_fetal == "Q950" ~ "923",
                        causa_fetal == "Q951" ~ "924",
                        causa_fetal == "Q952" ~ "925",
                        causa_fetal == "Q953" ~ "926",
                        causa_fetal == "Q954" ~ "927",
                        causa_fetal == "Q955" ~ "928",
                        causa_fetal == "Q958" ~ "929",
                        causa_fetal == "Q959" ~ "930",
                        causa_fetal == "Q960" ~ "931",
                        causa_fetal == "Q961" ~ "932",
                        causa_fetal == "Q962" ~ "933",
                        causa_fetal == "Q963" ~ "934",
                        causa_fetal == "Q964" ~ "935",
                        causa_fetal == "Q968" ~ "936",
                        causa_fetal == "Q969" ~ "937",
                        causa_fetal == "Q970" ~ "938",
                        causa_fetal == "Q971" ~ "939",
                        causa_fetal == "Q972" ~ "940",
                        causa_fetal == "Q973" ~ "941",
                        causa_fetal == "Q978" ~ "942",
                        causa_fetal == "Q979" ~ "943",
                        causa_fetal == "Q980" ~ "944",
                        causa_fetal == "Q981" ~ "945",
                        causa_fetal == "Q982" ~ "946",
                        causa_fetal == "Q983" ~ "947",
                        causa_fetal == "Q984" ~ "948",
                        causa_fetal == "Q985" ~ "949",
                        causa_fetal == "Q986" ~ "950",
                        causa_fetal == "Q987" ~ "951",
                        causa_fetal == "Q988" ~ "952",
                        causa_fetal == "Q989" ~ "953",
                        causa_fetal == "Q99" ~ "954",
                        causa_fetal == "Q990" ~ "955",
                        causa_fetal == "Q991" ~ "956",
                        causa_fetal == "Q992" ~ "957",
                        causa_fetal == "Q998" ~ "958",
                        causa_fetal == "Q999" ~ "959" ))

as.numeric(bd$vcausa)

table(bd$vcausa)

##Creación de la variable gcausa

bd <- bd %>%
  mutate(gcausa = case_when(
    vcausa %in% 0:9 ~ 1,
    vcausa %in% 10:19 ~ 2,
    vcausa %in% 20:29 ~ 3,
    vcausa %in% 30:39 ~ 4,
    vcausa %in% 40:47 ~ 5,
    vcausa %in% 48:51 ~ 6,
    vcausa %in% 52:55 ~ 7,
    vcausa %in% 56:58 ~ 8,
    vcausa %in% 59:65 ~ 9,
    vcausa %in% 66:72 ~ 10,
    vcausa %in% 73:79 ~ 11,
    vcausa %in% 80:86 ~ 12,
    vcausa %in% 87:92 ~ 13,
    vcausa %in% 93:101 ~ 14,
    vcausa %in% 102:104 ~ 15,
    vcausa %in% 105:107 ~ 16,
    vcausa %in% 108:111 ~ 17,
    vcausa %in% 112:120 ~ 18,
    vcausa %in% 121:126 ~ 19,
    vcausa %in% 127:131 ~ 20,
    vcausa %in% 132:135 ~ 21,
    vcausa %in% 136:139 ~ 22,
    vcausa %in% 140:147 ~ 23,
    vcausa %in% 148:154 ~ 24,
    vcausa %in% 155:160 ~ 25,
    vcausa %in% 161:168 ~ 26,
    vcausa %in% 169:176 ~ 27,
    vcausa %in% 177:177 ~ 28,
    vcausa %in% 178:184 ~ 29,
    vcausa %in% 185:192 ~ 30,
    vcausa %in% 193:195 ~ 31,
    vcausa %in% 196:204 ~ 32,
    vcausa %in% 205:205 ~ 33,
    vcausa %in% 206:214 ~ 34,
    vcausa %in% 215:218 ~ 35,
    vcausa %in% 219:220 ~ 36,
    vcausa %in% 221:223 ~ 37,
    vcausa %in% 224:231 ~ 38,
    vcausa %in% 232:237 ~ 39,
    vcausa %in% 238:238 ~ 40,
    vcausa %in% 239:247 ~ 41,
    vcausa %in% 248:254 ~ 42,
    vcausa %in% 255:261 ~ 43,
    vcausa %in% 262:266 ~ 44,
    vcausa %in% 267:274 ~ 45,
    vcausa %in% 275:275 ~ 46,
    vcausa %in% 276:280 ~ 47,
    vcausa %in% 281:281 ~ 48,
    vcausa %in% 282:287 ~ 49,
    vcausa %in% 288:290 ~ 50,
    vcausa %in% 291:293 ~ 51,
    vcausa %in% 294:302 ~ 52,
    vcausa %in% 303:303 ~ 53,
    vcausa %in% 304:311 ~ 54,
    vcausa %in% 312:319 ~ 55,
    vcausa %in% 320:320 ~ 56,
    vcausa %in% 321:325 ~ 57,
    vcausa %in% 326:326 ~ 58,
    vcausa %in% 327:334 ~ 59,
    vcausa %in% 335:337 ~ 60,
    vcausa %in% 338:342 ~ 61,
    vcausa %in% 343:343 ~ 62,
    vcausa %in% 344:347 ~ 63,
    vcausa %in% 348:356 ~ 64,
    vcausa %in% 357:366 ~ 65,
    vcausa %in% 367:373 ~ 66,
    vcausa %in% 374:376 ~ 67,
    vcausa %in% 377:384 ~ 68,
    vcausa %in% 385:388 ~ 69,
    vcausa %in% 389:395 ~ 70,
    vcausa %in% 396:403 ~ 71,
    vcausa %in% 404:409 ~ 72,
    vcausa %in% 410:412 ~ 73,
    vcausa %in% 413:419 ~ 74,
    vcausa %in% 420:427 ~ 75,
    vcausa %in% 428:437 ~ 76,
    vcausa %in% 438:446 ~ 77,
    vcausa %in% 447:453 ~ 78,
    vcausa %in% 454:462 ~ 79,
    vcausa %in% 463:469 ~ 80,
    vcausa %in% 470:478 ~ 81,
    vcausa %in% 479:488 ~ 82,
    vcausa %in% 489:497 ~ 83,
    vcausa %in% 498:504 ~ 84,
    vcausa %in% 505:510 ~ 85,
    vcausa %in% 511:516 ~ 86,
    vcausa %in% 517:523 ~ 87,
    vcausa %in% 524:528 ~ 88,
    vcausa %in% 529:537 ~ 89,
    vcausa %in% 538:541 ~ 90,
    vcausa %in% 543:551 ~ 91,
    vcausa %in% 552:554 ~ 92,
    vcausa %in% 555:562 ~ 93,
    vcausa %in% 563:571 ~ 94,
    vcausa %in% 572:580 ~ 95,
    vcausa %in% 581:586 ~ 96,
    vcausa %in% 587:591 ~ 97,
    vcausa %in% 592:597 ~ 98,
    vcausa %in% 598:607 ~ 99,
    vcausa %in% 608:615 ~ 100,
    vcausa %in% 616:621 ~ 101,
    vcausa %in% 622:628 ~ 102,
    vcausa %in% 629:638 ~ 103,
    vcausa %in% 639:648 ~ 104,
    vcausa %in% 649:652 ~ 105,
    vcausa %in% 653:659 ~ 106,
    vcausa %in% 660:668 ~ 107,
    vcausa %in% 669:673 ~ 108,
    vcausa %in% 674:680 ~ 109,
    vcausa %in% 681:688 ~ 110,
    vcausa %in% 689:697 ~ 111,
    vcausa %in% 698:703 ~ 112,
    vcausa %in% 704:713 ~ 113,
    vcausa %in% 714:722 ~ 114,
    vcausa %in% 723:732 ~ 115,
    vcausa %in% 733:741 ~ 116,
    vcausa %in% 742:748 ~ 117,
    vcausa %in% 749:752 ~ 118,
    vcausa %in% 753:758 ~ 119,
    vcausa %in% 759:767 ~ 120,
    vcausa %in% 768:777 ~ 121,
    vcausa %in% 778:780 ~ 122,
    vcausa %in% 781:786 ~ 123,
    vcausa %in% 787:794 ~ 124,
    vcausa %in% 795:804 ~ 125,
    vcausa %in% 805:814 ~ 126,
    vcausa %in% 815:823 ~ 127,
    vcausa %in% 824:832 ~ 128,
    vcausa %in% 833:839 ~ 129,
    vcausa %in% 840:844 ~ 130,
    vcausa %in% 845:852 ~ 131,
    vcausa %in% 853:858 ~ 132,
    vcausa %in% 859:867 ~ 133,
    vcausa %in% 868:871 ~ 134,
    vcausa %in% 872:875 ~ 135,
    vcausa %in% 876:882 ~ 136,
    vcausa %in% 883:890 ~ 137,
    vcausa %in% 891:894 ~ 138,
    vcausa %in% 895:902 ~ 139,
    vcausa %in% 903:912 ~ 140,
    vcausa %in% 913:922 ~ 141,
    vcausa %in% 923:930 ~ 142,
    vcausa %in% 931:937 ~ 143,
    vcausa %in% 938:943 ~ 144,
    vcausa %in% 944:953 ~ 145,
    vcausa %in% 954:959 ~ 146))


# --------------------------------- Etiquetas de cada una de las variables        --------------------------------  #


# Asignar categorías de valor a la variable reg_fall

bd$reg_fall = factor(bd$reg_fall,
                     levels = c(1, 2,
                                3, 4,
                                5, 6),
                     labels = c("Región Sierra:", "Región Costa:",
                                "Región Amazónica:", "Región Insular:",
                                 "Exterior:"),
                     ordered = FALSE)

table(bd$reg_fall)

# Asignar categorías de valor a la variable reg_res

bd$reg_res = factor(bd$reg_res,
                    levels = c(1, 2,
                               3, 4,
                               5, 6),
                    labels = c("Región Sierra", "Región Costa",
                               "Región Amazónica", "Región Insular",
                                "Exterior"),
                    ordered = FALSE)
table(bd$reg_res)

# Categorías de la División Político Administrativa Provincial

# Provincia de inscripción

bd$prov_insc = factor(bd$prov_insc,
                      levels = c("01", "02", "03", "04", "05", "06", "07", "08", "09",
                                 "10", "11", "12", "13", "14", "15", "16", "17", "18",
                                 "19", "20", "21", "22", "23", "24", "90"),
                      labels = c("AZUAY", "BOLÍVAR", "CAÑAR", "CARCHI",
                                 "COTOPAXI", "CHIMBORAZO", "EL ORO",
                                 "ESMERALDAS", "GUAYAS", "IMBABURA",
                                 "LOJA", "LOS RÍOS", "MANABÍ", "MORONA SANTIAGO",
                                 "NAPO", "PASTAZA", "PICHINCHA", "TUNGURAHUA",
                                 "ZAMORA CHINCHIPE", "GALÁPAGOS", "SUCUMBÍOS",
                                 "ORELLANA", "SANTO DOMINGO DE LOS TSÁCHILAS",
                                 "SANTA ELENA", "ZONA NO DELIMITADA"),
                      ordered = FALSE)

# Provincia de residencia habitual de la madre

bd$prov_res = factor(bd$prov_res,
                     levels = c("01", "02", "03", "04", "05", "06", "07", "08", "09",
                                "10", "11", "12", "13", "14", "15", "16", "17", "18",
                                "19", "20", "21", "22", "23", "24", "90"),
                     labels = c("AZUAY", "BOLÍVAR", "CAÑAR", "CARCHI",
                                "COTOPAXI", "CHIMBORAZO", "EL ORO",
                                "ESMERALDAS", "GUAYAS", "IMBABURA",
                                "LOJA", "LOS RÍOS", "MANABÍ", "MORONA SANTIAGO",
                                "NAPO", "PASTAZA", "PICHINCHA", "TUNGURAHUA",
                                "ZAMORA CHINCHIPE", "GALÁPAGOS", "SUCUMBÍOS",
                                "ORELLANA", "SANTO DOMINGO DE LOS TSÁCHILAS",
                                "SANTA ELENA", "ZONA NO DELIMITADA"),
                     ordered = FALSE)


# Provincia de residencia habitual de la madre

bd$cant_res = factor(bd$cant_res,
                     levels = c("0101" , "0102", "0103", "0104", "0105", "0106", "0107", "0108", "0109", "0110", "0111",
                                "0112", "0113", "0114", "0115", "0201", "0202", "0203", "0204", "0205", "0206",
                                "0207", "0301", "0302", "0303", "0304", "0305", "0306", "0307", "0401", "0402", "0403",
                                "0404", "0405", "0406", "0501", "0502", "0503", "0504", "0505", "0506", "0507", "0601", "0602",
                                "0603", "0604", "0605", "0606", "0607", "0608", "0609", "0610", "0701", "0702", "0703", "0704",
                                "0705", "0706", "0707", "0708", "0709", "0710", "0711", "0712", "0713", "0714", "0801", "0802",
                                "0803", "0804", "0805", "0806", "0807", "0901", "0902", "0903", "0904", "0905", "0906", "0907",
                                "0908", "0909", "0910", "0911", "0912", "0913", "0914", "0916", "0918", "0919", "0920", "0921",
                                "0922", "0923", "0924", "0925", "0927", "0928", "1001", "1002", "1003", "1004", "1005", "1006",
                                "1101", "1102", "1103", "1104", "1105", "1106", "1107", "1108", "1109", "1110", "1111", "1112",
                                "1113", "1114", "1115", "1116", "1201", "1202", "1203", "1204", "1205", "1206", "1207", "1208",
                                "1209", "1210", "1211", "1212", "1213", "1301", "1302", "1303", "1304", "1305", "1306", "1307",
                                "1308", "1309", "1310", "1311", "1312", "1313", "1314", "1315", "1316", "1317", "1318", "1319",
                                "1320", "1321", "1322", "1401", "1402", "1403", "1404", "1405", "1406", "1407", "1408", "1409",
                                "1410", "1411", "1412", "1501", "1503", "1504", "1507", "1509", "1601", "1602", "1603", "1604",
                                "1701", "1702", "1703", "1704", "1705", "1707", "1708", "1709", "1801", "1802", "1803", "1804",
                                "1805", "1806", "1807", "1808", "1809", "1901", "1902", "1903", "1904", "1905", "1906", "1907",
                                "1908", "1909", "2001", "2002", "2003", "2101", "2102", "2103", "2104", "2105", "2106", "2107",
                                "2201", "2202", "2203", "2204", "2301", "2302", "2401", "2402", "2403", "8800", "9001", "9004",
                                "9005", "9006", "9007", "9008"),
                     labels = c("Cuenca", "Girón", "Gualaceo", "Nabón", "Paute", "Pucará", "San Fernando", "Santa Isabel",
                                "Sigsig", "Oña", "Chordeleg", "El Pan", "Sevilla De Oro", "Guachapala", "Camilo Ponce Enríquez",
                                "Guaranda", "Chillanes", "Chimbo", "Echeandia", "San Miguel", "Caluma", "Las Naves", "Azogues",
                                "Biblian", "Cañar", "La Troncal", "El Tambo", "Deleg", "Suscal", "Tulcán", "Bolívar", "Espejo",
                                "Mira", "Montúfar", "San Pedro De Huaca", "Latacunga", "La Maná", "Pangua", "Pujilí", "Salcedo",
                                "Saquisilí", "Sigchos", "Riobamba", "Alausí", "Colta", "Chambo", "Chunchi", "Guamote", "Guano", "Pallatanga",
                                "Penípe", "Cumandá", "Machala", "Arenillas", "Atahualpa", "Balsas", "Chilla", "El Guabo", "Huaquillas",
                                "Marcabelí", "Pasaje", "Piñas", "Portovelo", "Santa Rosa", "Zaruma", "Las Lajas", "Esmeraldas", "Eloy Alfaro",
                                "Muisne", "Quininde", "San Lorenzo", "Atacames", "Ríoverde", "Guayaquil", "Alfredo Baquerizo Moreno",
                                "Balao", "Balzar", "Colimes", "Daule", "Durán", "Empalme", "El Triunfo", "Milagro", "Naranjal", "Naranjito",
                                "Palestina", "Pedro Carbo", "Samborondón", "Santa Lucia", "Salitre", "San Jacinto De Yaguachi", "Playas",
                                "Simón Bolívar", "Crnel. Marcelino Maridueña", "Lomas De Sargentillo", "Nobol", "Gnral. Antonio Elizalde", "Isidro Ayora",
                                "Ibarra", "Antonio Ante", "Cotacahi", "Otavalo", "Pimampiro", "San Miguel De Urcuqui", "Loja", "Calvas", "Catamayo",
                                "Célica", "Chaguarpamba", "Espíndola", "Gonzanamá", "Macará", "Paltas", "Puyango", "Saraguro", "Sozoranga",
                                "Zapotillo", "Pindal", "Quilanga", "Olemdo", "Babahoyo", "Baba", "Montalvo", "Puebloviejo", "Quevedo", "Urdaneta",
                                "Ventanas", "Vinces", "Palenque", "Buena Fé", "Valencia", "Mocache", "Quinsaloma", "Portoviejo", "Bolívar",
                                "Chone", "El Carmen", "Flavio Alfaro", "Jipijapa", "Junín", "Manta", "Montecristi", "Paján", "Pichincha", "Rocafuerte",
                                "Santa Ana", "Sucre", "Tosagua", "24 De Mayo", "Pedernales", "Olmedo", "Puerto López", "Jama", "Jaramijó", "San Vicente",
                                "Morona", "Gualaquiza", "Limón Indanza", "Palora", "Santiago", "Sucúa", "Huamboya", "San Juan Bosco", "Taisha", "Logroño",
                                "Pablo Sexto", "Tiwintza", "Tena", "Archidona", "El Chaco", "Quijos", "Carlos Julio Arrosemena Tola", "Pastaza",
                                "Mera", "Santa Clara", "Arajuno", "Quito", "Cayambe", "Mejía", "Pedro Moncayo", "Rumiñahui", "San Miguel De Los Bancos",
                                "Pedro Vicente Maldonado", "Puerto Quito", "Ambato", "Baños De Agua Santa", "Cevallos", "Mocha", "Patate", "Quero", "San Pedro De Pelileo",
                                "Santiago De Pillaro", "Tisaleo", "Zamora", "Chinchipe", "Nangaritza", "Yacuambi", "Yantzaza", "El Pangui", "Centinela Del Cóndor",
                                "Palanda", "Paquisha", "San Cristobal", "Isabela", "Santa Cruz", "Lago Agrio", "Gonzalo Pizarro", "Putumayo",
                                "Shushufindi", "Sucumbios", "Cascales", "Cuyabeno", "Orellana", "Aguarico",
                                "La Joya De Los Sachas", "Loreto", "Santo Domingo", "La Condordia", "Santa Elena", "La Libertad", "Salinas", "Exterior", "Las Golondrinas",
                                "El Piedrero", "Santa Rosa De Agua Clara", "Juval", "Abdón Calderón", "Matilde Esther"),
                     ordered = FALSE)

# Provincia de fallecimiento

bd$prov_fall = factor(bd$prov_fall,
                      levels = c("01", "02", "03", "04", "05", "06", "07", "08", "09",
                                 "10", "11", "12", "13", "14", "15", "16", "17", "18",
                                 "19", "20", "21", "22", "23", "24", "90"),
                      labels = c("AZUAY", "BOLÍVAR", "CAÑAR", "CARCHI",
                                 "COTOPAXI", "CHIMBORAZO", "EL ORO",
                                 "ESMERALDAS", "GUAYAS", "IMBABURA",
                                 "LOJA", "LOS RÍOS", "MANABÍ", "MORONA SANTIAGO",
                                 "NAPO", "PASTAZA", "PICHINCHA", "TUNGURAHUA",
                                 "ZAMORA CHINCHIPE", "GALÁPAGOS", "SUCUMBÍOS",
                                 "ORELLANA", "SANTO DOMINGO DE LOS TSÁCHILAS",
                                 "SANTA ELENA", "ZONA NO DELIMITADA"),
                      ordered = FALSE)

# Mes de Inscripción de la defunción fetal

bd$mes_insc = factor(bd$mes_insc,
                     levels = c(1, 2, 3,
                                4, 5, 6,
                                7, 8, 9,
                                10, 11, 12),
                     labels = c("Enero", "Febrero", "Marzo",
                                "Abril", "Mayo", "Junio",
                                "Julio", "Agosto", "Septiembre",
                                "Octubre", "Noviembre", "Diciembre"),
                     ordered = FALSE)

# Mes de Nacimiento de la madre

bd$mes_mad = factor(bd$mes_mad,
                    levels = c(1, 2, 3,
                               4, 5, 6,
                               7, 8, 9,
                               10, 11, 12),
                    labels = c("Enero", "Febrero", "Marzo",
                               "Abril", "Mayo", "Junio",
                               "Julio", "Agosto", "Septiembre",
                               "Octubre", "Noviembre", "Diciembre"),
                    ordered = FALSE)

# Mes de Fallecimento

bd$mes_fall = factor(bd$mes_fall,
                     levels = c(1, 2, 3,
                                4, 5, 6,
                                7, 8, 9,
                                10, 11, 12),
                     labels = c("Enero", "Febrero", "Marzo",
                                "Abril", "Mayo", "Junio",
                                "Julio", "Agosto", "Septiembre",
                                "Octubre", "Noviembre", "Diciembre"),
                     ordered = FALSE)
# Código de País

bd$cod_pais = factor(bd$cod_pais,
                     levels = c("004",	"008",	"276",	"020",	"024",	"660",	"028",	"530",	"682",	"012",
                                "032",	"051",	"533",	"036",	"040",	"031",	"044",	"048",	"050",	"052",
                                "112",	"056",	"084",	"204",	"060",	"064",	"068",	"070",	"072",	"076",
                                "096",	"100",	"854",	"108",	"132",	"116",	"120",	"124",	"148",	"152",
                                "156",	"344",	"196",	"170",	"174",	"178",	"188",	"384",	"191",	"192",
                                "208",	"262",	"212",	"218",	"818",	"222",	"784",	"232",	"703",	"705",
                                "724",	"840",	"233",	"231",	"807",	"274",	"643",	"242",	"608",	"246",
                                "250",	"266",	"270",	"268",	"288",	"292",	"308",	"300",	"304",	"312",
                                "316",	"320",	"324",	"624",	"226",	"328",	"254",	"332",	"340",	"348",
                                "356",	"360",	"364",	"368",	"372",	"352",	"833",	"830",	"136",	"184",
                                "234",	"238",	"580",	"584",	"574",	"090",	"744",	"796",	"092",	"850",
                                "876",	"376",	"380",	"434",	"388",	"392",	"400",	"398",	"404",	"296",
                                "414",	"417",	"426",	"428",	"422",	"430",	"438",	"440",	"442",	"446",
                                "450",	"458",	"454",	"462",	"466",	"470",	"504",	"474",	"480",	"478",
                                "484",	"583",	"492",	"496",	"500",	"508",	"104",	"516",	"520",	"524",
                                "558",	"562",	"566",	"570",	"578",	"540",	"554",	"512",	"528",	"586",
                                "585",	"591",	"598",	"600",	"604",	"612",	"258",	"616",	"620",	"158",
                                "630",	"634",	"826",	"760",	"140",	"203",	"410",	"498",	"180",	"418",
                                "214",	"408",	"834",	"638",	"642",	"646",	"732",	"659",	"666",	"016",
                                "882",	"674",	"670",	"654",	"622",	"336",	"678",	"686",	"690",	"694",
                                "702",	"706",	"144",	"710",	"736",	"752",	"756",	"740",	"748",	"764",
                                "762",	"626",	"768",	"772",	"776",	"780",	"788",	"795",	"792",	"798",
                                "804",	"800",	"858",	"860",	"548",	"862",	"704",	"887",	"891",	"894",
                                "716",	"898",	"901",	"902",	"903",	"904",	"905",	"275",	"534",	"999"),
                     labels = c("AFGANISTAN",	"ALBANIA",	"GERMANY",	"ANDORRA",	"ANGOLA",	"ANGUILLA",	"ANTIGUA,BARB",	"NETH.ANTILES",	"SAUDI ARABIA",	"ARGELIA",
                                "ARGENTINA",	"ARMENIA",	"ARUBA",	"AUSTRALIA",	"AUSTRIA",	"AZERBAIJAN",	"BAHAMAS",	"BAHRAIN",	"BANGLADESH",	"BARBADOS",
                                "BELARUS",	"BELGIUM",	"BELIZE",	"BENIN",	"BERMUDA",	"BHUTAN",	"BOLIVIA",	"BOSNIA Y HERZEG",	"BOTSWANA",	"BRAZIL",
                                "BRUNEI DARSM",	"BULGARIA",	"BURKINA FASO",	"BURUNDI",	"CAPE VERDE",	"CAMBODIA",	"CAMEROON",	"CANADA",	"CHAD",	"CHILE",
                                "CHINA",	"HONGKONG SAR",	"CYPRUS",	"COLOMBIA",	"COMOROS",	"CONGO",	"COSTA RICA",	"COTE DIVOIRE",	"CROATIA",	"CUBA",
                                "DENMARK",	"DJIBOUTI",	"DOMINICA",	"ECUADOR",	"EGYPT",	"EL SALVADOR",	"UNTD ARAB EM",	"ERITREA",	"SLOVAKIA",	"SLOVENIA",
                                "SPAIN",	"USA",	"ESTONIA",	"ETHIOPIA",	"TFYROM",	"FAJA DE GAZA (FRANJA DE GAZA)",	"RUSSIAN FED",	"FIJI",	"PHILIPPINES",	"FINLAND",
                                "FRANCE",	"GABÓN",	"GAMBIA",	"GEORGIA",	"GHANA",	"GIBRALTAR",	"GRENADA",	"GREECE",	"GREENLAND",	"GUADELOUPE",
                                "GUAM",	"GUATEMALA",	"GUINEA",	"GUINEABISSAU",	"EQ.GUINEA",	"GUYANA",	"FR.GUIANA",	"HAITÍ",	"HONDURAS",	"HUNGARY",
                                "INDIA",	"INDONESIA",	"IRAN",	"IRAQ",	"IRELAND",	"ICELAND",	"ISLE OF MAN",	"CHANNEL IS",	"CAYMAN IS",	"COOK ISLAND",
                                "FAEROE IS",	"FALKLAND IS",	"N.MARIANA IS",	"MARSHALL IS",	"NORFOLK IS",	"SOLOMON IS",	"SVALBARD IS",	"TURKS,CAICOS",	"BR.VIRGIN IS",	"US.VIRGIN IS",
                                "WALLIS FUT.I",	"ISRAEL",	"ITALY",	"LIBYA",	"JAMAICA",	"JAPAN",	"JORDAN",	"KAZAKHSTAN",	"KENYA",	"KIRIBATI",
                                "KUWAIT",	"KYRGYZTAN",	"LESOTHO",	"LATVIA",	"LEBANON",	"LIBERIA",	"LIECHTENSTEN",	"LITHUANIA",	"LUXEMBOURG",	"MACAO",
                                "MADAGASCAR",	"MALASIA",	"MALAWI",	"MALDIVES",	"MALI",	"MALTA",	"MOROCCO",	"MARTINIQUE",	"MAURITIUS",	"MAURITANIA",
                                "MEXICO",	"MICRONESIA",	"MONACO",	"MONGOLIA",	"MONTSERRAT",	"MOZAMBIQUE",	"MYANMAR",	"NAMIBIA",	"NAURU",	"NEPAL",
                                "NICARAGUA",	"NIGER",	"NIGERIA",	"NIUE",	"NORWAY",	"NEW CALEDNIA",	"NEW ZEALAND",	"OMAN",	"NETHERLANDS",	"PAKISTAN",
                                "PALAU",	"PANAMA",	"PAPUA N.GUIN",	"PARAGUAY",	"PERU",	"PITCAIRN",	"FR.POLYNESIA",	"POLAND",	"PORTUGAL",	"PROVINCIA CHINA DE TAIWAN",
                                "PUERTO RICO",	"QATAR",	"UK",	"SYRIA",	"CENT.AFR.REP",	"CZECH REP",	"KOREA REP.",	"REP MOLDOVA",	"D. RP. CONGO",	"LAO P.DEM.R.",
                                "DOMINICAN RP",	"KOREA D P RP",	"TANZANIA",	"REUNION",	"ROMANIA",	"RWANDA",	"WESTN.SAHARA",	"ST.KITTS-NEV",	"ST.PIERRE,MQ",	"AMER SAMOA",
                                "SAMOA",	"SAN MARINO",	"ST.VINCENT,G",	"ST.HELENA",	"ST.LUCIA",	"HOLY SEE",	"SAO TOME PRN",	"SENEGAL",	"SEYCHELLES",	"SIERRA LEONE",
                                "SINGAPORE",	"SOMALIA",	"SRI LANKA",	"SOUTH AFRICA",	"SUDAN",	"SWEDEN",	"SWITZERLAND",	"SURINAME",	"SWAZILAND",	"THAILAND",
                                "TAJIKISTAN",	"EAST TIMOR",	"TOGO",	"TOKELAU",	"TONGA",	"TRINIDAD TBG",	"TUNISIA",	"TURKMENISTAN",	"TURKEY",	"TUVALU",
                                "UKRAINE",	"UGANDA",	"URUGUAY",	"UZBEKISTAN",	"VANUATU",	"VENEZUELA",	"VIET NAM",	"YEMEN",	"YUGOSLAVIA",	"ZAMBIA",
                                "ZIMBABWE",	"ZONAS NO ESPECIFICADAS",	"OTRAS NACIONES AMERICANAS",	"OTRAS NACIONES DE EUROPA",	"OTRAS NACIONES DE ASIA",	"OTRAS NACIONES DE AFRICA",	"OTRAS NACIONES DE OCEANIA",	"TERRITORIO PALESTINO OCUPADO",	"SAN MARTÍN",	"SIN INFORMACIÓN"),
                     ordered = FALSE)

# Categorías por sexo

bd$sexo = factor(bd$sexo,
                 levels = c(1, 2, 3),
                 labels = c("Hombre", "Mujer", "Indeterminado"),
                 ordered = FALSE)

# Categorías por área de residencia de la madre

bd$area_res = factor(bd$area_res,
                 levels = c(1, 2),
                 labels = c("Urbano", "Rural"),
                 ordered = FALSE)

# Identificación étnica de acuerdo con la cultura y costumbres de la madre

bd$etnia = factor(bd$etnia,
                  levels = c(1, 2, 3,
                             4, 5, 6,
                             7, 8, 9),
                  labels = c("Indígena", "Afroecuatoriana/ Afrodescendiente", "Negra",
                             "Mulata", "Montubia", "Mestiza", 
                             "Blanca", "Otra", "Sin información"),
                  ordered = FALSE)

# Estado civil y/o conyugal de la madre

bd$est_civil = factor(bd$est_civil,
                      levels = c(1, 2,
                                 3, 4,
                                 5, 6,
                                 7, 9),
                      labels = c("Soltero (a)", "Casado (a)",
                                 "Divorciado (a)", "Viudo (a)",
                                 "Unión de hecho", "Unión libre",
                                 "Separado (a)", "Sin información"),
                      ordered = FALSE)

# Nivel de instrucción de la madre

bd$niv_inst = factor(bd$niv_inst,
                     levels = c(0, 1, 2,
                                3, 4, 5,
                                6, 7, 8,
                                9),
                     labels = c("Ninguno", "Centro de alfabetización", "Primaria",
                                "Educación Básica", "Secundaria", "Educación media/Bachillerato",
                                "Superior no universitaria", "Superior universitaria", "Postgrado",
                                "Sin información"),
                     ordered = FALSE)


# Asistido por/ Autopsiado por

bd$asis_por = factor(bd$asis_por,
                     levels = c(1, 2,
                                3, 4, 5,
                                6, 7, 8),
                     labels = c("Médico/a", "Obstetriz/Obstetra",
                                "Enfermero/a", "Auxiliar de Enfermería", "Partero/a calificado/a (comadrona lider comunitario)",
                                "Partero/a no calificado/a", "Otro especifique", "Médico/a legista"),
                     ordered = FALSE)

# Lugar de ocurrencia

bd$lugar_ocur = factor(bd$lugar_ocur,
                     levels = c(1, 2,
                                3, 4, 5,
                                6, 7),
                     labels = c("Establecimiento del Ministerio de Salud", "Establecimiento del IESS",
                                "Establecimiento de la Junta de Beneficencia", "Otro Establecimiento Público",
                                "Hospital, Clínica o Consultorio Privado", "Casa", "Otro"),
                     ordered = FALSE)

# Semanas de gestación

bd$semgest <- factor(bd$semgest, levels = 1:6, labels = c("22-27","28-31"," 32-36"," 37-41"," 42_y_más","sin_información"))


# Tipo de asistencia


bd$tip_asis = factor(bd$tip_asis,
                       levels = c(1, 2,
                                  3,9),
                       labels = c("Médico", "Obstetriz o Enfermera",
                                  "Sin asistencia profesional","Sin Información"),
                       ordered = FALSE) 

# Tipo de asistencia

  
bd$asis = factor(bd$asis,
                     levels = c(1, 2),
                     labels = c("Con asistencia profesional",
                                "Sin asistencia profesional"),
                     ordered = FALSE) 

##Grupos de edad de la madre  

bd$edadmad = factor(bd$edadmad,
                       levels = c(1, 2,
                                  3, 4, 5,
                                  6, 7, 8,
                                  9, 10),
                       labels = c("Madres de 10 - 14 años", "Madres de 15 - 19 años",
                                  "Madres de 20 - 24 años", "Madres de 25 - 29 años",
                                  "Madres de 30 - 34 años", "Madres de 35 - 39 años",
                                  "Madres de 40 - 44 años", "Madres de 45 - 49 años",
                                  "Madres de 50 y más años", "Sin información"),
                       ordered = FALSE)

# Variable vcausa

bd <- bd %>%
  mutate(
  vcausa = case_when( vcausa == 0 ~ "P000 Feto y recién nacido afectados por trastornos hipertensivos de la madre",
                      vcausa == 1 ~ "P001 Feto y recién nacido afectados por enfermedades renales y de las vías urinarias de la madre",
                      vcausa == 2 ~ "P002 Feto y recién nacido afectados por enfermedades infecciosas y parasitarias de la madre",
                      vcausa == 3 ~ "P003 Feto y recién nacido afectados por otras enfermedades circulatorias y respiratorias de la madre",
                      vcausa == 4 ~ "P004 Feto y recién nacido afectados por trastornos nutricionales de la madre",
                      vcausa == 5 ~ "P005 Feto y recién nacido afectados por traumatismo de la madre",
                      vcausa == 6 ~ "P006 Feto y recién nacido afectados por procedimiento quirúrgico en la madre",
                      vcausa == 7 ~ "P007 Feto y recién nacido afectados por otro procedimiento médico en la madre, no clasificado en otra parte",
                      vcausa == 8 ~ "P008 Feto y recién nacido afectados por otras afecciones maternas",
                      vcausa == 9 ~ "P009 Feto y recién nacido afectados por afección materna no especificada",
                      vcausa == 10 ~ "P010 Feto y recién nacido afectados por incompetencia del cuello uterino",
                      vcausa == 11 ~ "P011 Feto y recién nacido afectados por ruptura prematura de las membranas",
                      vcausa == 12 ~ "P012 Feto y recién nacido afectados por oligohidramnios",
                      vcausa == 13 ~ "P013 Feto y recién nacido afectados por polihidramnios",
                      vcausa == 14 ~ "P014 Feto y recién nacido afectados por embarazo ectópico",
                      vcausa == 15 ~ "P015 Feto y recién nacido afectados por embarazo múltiple",
                      vcausa == 16 ~ "P016 Feto y recién nacido afectados por muerte materna",
                      vcausa == 17 ~ "P017 Feto y recién nacido afectados por presentación anómala antes del trabajo de parto",
                      vcausa == 18 ~ "P018 Feto y recién nacido afectados por otras complicaciones maternas del embarazo",
                      vcausa == 19 ~ "P019 Feto y recién nacido afectados por complicaciones maternas no especificadas del embarazo",
                      vcausa == 20 ~ "P020 Feto y recién nacido afectados por placenta previa",
                      vcausa == 21 ~ "P021 Feto y recién nacido afectados por otras formas de desprendimiento y de hemorragia placentarios",
                      vcausa == 22 ~ "P022 Feto y recién nacido afectados por otras anormalidades morfológicas y funcionales de la placenta y las no especificadas",
                      vcausa == 23 ~ "P023 Feto y recién nacido afectados por síndromes de transfusión placentaria",
                      vcausa == 24 ~ "P024 Feto y recién nacido afectados por prolapso el cordón umbilical",
                      vcausa == 25 ~ "P025 Feto y recién nacido afectados por otra compresión del cordón umbilical",
                      vcausa == 26 ~ "P026 Feto y recién nacido afectados por otras complicaciones del cordón umbilical y las no especificadas",
                      vcausa == 27 ~ "P027 Feto y recién nacido afectados por corioamnionitis",
                      vcausa == 28 ~ "P028 Feto y recién nacido afectados por otras anormalidades de las membranas",
                      vcausa == 29 ~ "P029 Feto y recién nacido afectados por anormalidad no especificada de las membranas",
                      vcausa == 30 ~ "P030 Feto y recién nacido afectados por parto y extracción de nalgas",
                      vcausa == 31 ~ "P031 Feto y recién nacido afectados por otra presentación anómala, posición anómala y desproporción durante el trabajo de parto y el parto",
                      vcausa == 32 ~ "P032 Feto y recién nacido afectados por parto con fórceps",
                      vcausa == 33 ~ "P033 Feto y recién nacido afectados por parto con ventosa extractora",
                      vcausa == 34 ~ "P034 Feto y recién nacido afectados por parto por ces rea",
                      vcausa == 35 ~ "P035 Feto y recién nacido afectados por parto precipitado",
                      vcausa == 36 ~ "P036 Feto y recién nacido afectados por contracciones uterinas anormales",
                      vcausa == 37 ~ "P038 Feto y recién nacido afectados por otras complicaciones especificadas del trabajo de parto y del parto",
                      vcausa == 38 ~ "P039 Feto y recién nacido afectados por complicaciones no especificadas del trabajo de parto y del parto",
                      vcausa == 39 ~ "P040 Feto y recién nacido afectados por anestesia y analgesia materna en el embarazo, en el trabajo de parto y en el parto",
                      vcausa == 40 ~ "P041 Feto y recién nacido afectados por otras medicaciones maternas",
                      vcausa == 41 ~ "P042 Feto y recién nacido afectados por tabaquismo de la madre",
                      vcausa == 42 ~ "P043 Feto y recién nacido afectados por alcoholismo de la madre",
                      vcausa == 43 ~ "P044 Feto y recién nacido afectados por drogradicción materna",
                      vcausa == 44 ~ "P045 Feto y recién nacido afectados por el uso materno de sustancias químicas nutricionales",
                      vcausa == 45 ~ "P046 Feto y recién nacido afectados por exposición materna a sustancias químicas ambientales",
                      vcausa == 46 ~ "P048 Feto y recién nacido afectados por otras influencias nocivas de la madre",
                      vcausa == 47 ~ "P049 Feto y recién nacido afectados por influencias nocivas de la madre, no especificadas",
                      vcausa == 48 ~ "P050 Bajo peso para la edad gestacional",
                      vcausa == 49 ~ "P051 Peque¤o para la edad gestacional",
                      vcausa == 50 ~ "P052 Desnutrición fetal, sin mención de peso o talla bajos para la edad gestacional",
                      vcausa == 51 ~ "P059 Retardo del crecimiento fetal, no especificado",
                      vcausa == 52 ~ "P070 Peso extremadamente bajo al nacer",
                      vcausa == 53 ~ "P071 Otro peso bajo al nacer",
                      vcausa == 54 ~ "P072 Inmaturidad extrema",
                      vcausa == 55 ~ "P073 Otros recién nacidos pretérmino",
                      vcausa == 56 ~ "P080 Recién nacido excepcionalmente grande",
                      vcausa == 57 ~ "P081 Otros recién nacidos con sobrepeso para la edad gestacional",
                      vcausa == 58 ~ "P082 Recién nacido postérmino sin sobrepeso para su edad gestacional",
                      vcausa == 59 ~ "P100 Hemorragia subdural debida a traumatismo del nacimiento",
                      vcausa == 60 ~ "P101 Hemorragia cerebral debida a traumatismo del nacimiento",
                      vcausa == 61 ~ "P102 Hemorragia intraventricular debida a traumatismo del nacimiento",
                      vcausa == 62 ~ "P103 Hemorragia subaracnoidea debida a traumatismo del nacimiento",
                      vcausa == 63 ~ "P104 Desgarro tentorial debido a traumatismo del nacimiento",
                      vcausa == 64 ~ "P108 Otras hemorragias y laceraciones intracraneales debidas a traumatismo del nacimiento",
                      vcausa == 65 ~ "P109 Hemorragia y laceración intracraneales no especificadas, debidas a traumatismo del nacimiento",
                      vcausa == 66 ~ "P110 Edema cerebral debido a traumatismo del nacimiento",
                      vcausa == 67 ~ "P111 Otras lesiones especificadas del encéfalo, debidas a traumatismo del nacimiento",
                      vcausa == 68 ~ "P112 Lesión no especificada del encéfalo, debida a traumatismo del nacimiento",
                      vcausa == 69 ~ "P113 Traumatismo del nacimiento en el nervio facial",
                      vcausa == 70 ~ "P114 Traumatismo del nacimiento en otros nervios craneales",
                      vcausa == 71 ~ "P115 Traumatismo del nacimiento en la columna vertebral y en la médula espinal",
                      vcausa == 72 ~ "P119 Traumatismo del nacimiento en el sistema nervioso central, no especificado",
                      vcausa == 73 ~ "P120 Cefalohematoma debido a traumatismo del nacimiento",
                      vcausa == 74 ~ "P121 Caput succedaneum debido a traumatismo del nacimiento",
                      vcausa == 75 ~ "P122 Hemorragia epicraneal subaponeurótica debida a traumatismo del nacimiento",
                      vcausa == 76 ~ "P123 Equimosis del cuero cabelludo debida a traumatismo del nacimiento",
                      vcausa == 77 ~ "P124 Traumatismo en el cuero cabelludo del recién nacido por monitoreo fetal",
                      vcausa == 78 ~ "P128 Otros traumatismos del nacimiento en el cuero cabelludo",
                      vcausa == 79 ~ "P129 Traumatismo del nacimiento en el cuero cabelludo, no especificado",
                      vcausa == 80 ~ "P130 Fractura del cr neo debida a traumatismo del nacimiento",
                      vcausa == 81 ~ "P131 Otros traumatismos del cr neo durante el nacimiento",
                      vcausa == 82 ~ "P132 Traumatismo del fémur durante el nacimiento",
                      vcausa == 83 ~ "P133 Traumatismo de otros huesos largos durante el nacimiento",
                      vcausa == 84 ~ "P134 Fractura de la clavícula debida a traumatismo del nacimiento",
                      vcausa == 85 ~ "P138 Traumatismo del nacimiento en otras partes del esqueleto",
                      vcausa == 86 ~ "P139 Traumatismo no especificado del esqueleto durante el nacimiento",
                      vcausa == 87 ~ "P140 Par lisis de erb debida a traumatismo del nacimiento",
                      vcausa == 88 ~ "P141 Par lisis de klumpke debida a traumatismo del nacimiento",
                      vcausa == 89 ~ "P142 Par lisis del nervio frénico debida a traumatismo del nacimiento",
                      vcausa == 90 ~ "P143 Otro traumatismo del plexo braquial durante el nacimiento",
                      vcausa == 91 ~ "P148 Traumatismo durante el nacimiento en otras partes del sistema nervioso periférico",
                      vcausa == 92 ~ "P149 Traumatismo no especificado del sistema nervioso periférico durante el nacimiento",
                      vcausa == 93 ~ "P150 Lesión del hígado durante el nacimiento",
                      vcausa == 94 ~ "P151 Lesión del bazo durante el nacimiento",
                      vcausa == 95 ~ "P152 Traumatismo del músculo esternocleidomastoideo durante el nacimiento",
                      vcausa == 96 ~ "P153 Traumatismo ocular durante el nacimiento",
                      vcausa == 97 ~ "P154 Traumatismo facial durante el nacimiento",
                      vcausa == 98 ~ "P155 Traumatismo de los genitales externos durante el nacimiento",
                      vcausa == 99 ~ "P156 Necrosis grasa subcut nea debida a traumatismo del nacimiento",
                      vcausa == 100 ~ "P158 Otros traumatismos especificados, durante el nacimiento",
                      vcausa == 101 ~ "P159 Traumatismo no especificado, durante el nacimiento",
                      vcausa == 102 ~ "P200 Hipoxia intrauterina notada por primera vez antes del inicio del trabajo de parto",
                      vcausa == 103 ~ "P201 Hipoxia intrauterina notada por primera vez durante el trabajo de parto y el parto",
                      vcausa == 104 ~ "P209 Hipoxia intrauterina, no especificada",
                      vcausa == 105 ~ "P210 Asfixia del nacimiento, severa",
                      vcausa == 106 ~ "P211 Asfixia del nacimiento, leve y moderada",
                      vcausa == 107 ~ "P219 Asfixia del nacimiento, no especificada",
                      vcausa == 108 ~ "P220 Síndrome de dificultad respiratoria del recién nacido",
                      vcausa == 109 ~ "P221 Taquipnea transitoria del recién nacido",
                      vcausa == 110 ~ "P228 Otras dificultades respiratorias del recién nacido",
                      vcausa == 111 ~ "P229 Dificultad respiratoria del recién nacido, no especificada",
                      vcausa == 112 ~ "P230 Neumonía congénita debida a agente viral",
                      vcausa == 113 ~ "P231 Neumonía congénita debida a chlamydia",
                      vcausa == 114 ~ "P232 Neumonía congénita debida a estafilococos",
                      vcausa == 115 ~ "P233 Neumonía congénita debida a estreptococos del grupo b",
                      vcausa == 116 ~ "P234 Neumonía congénita debida a escherichia coli",
                      vcausa == 117 ~ "P235 Neumonía congénita debida a pseudomonas",
                      vcausa == 118 ~ "P236 Neumonía congénita debida a otros agentes bacterianos",
                      vcausa == 119 ~ "P238 Neumonía congénita debida a otros organismos",
                      vcausa == 120 ~ "P239 Neumonía congénita, organismo no especificado",
                      vcausa == 121 ~ "P240 Aspiración neonatal de meconio",
                      vcausa == 122 ~ "P241 Aspiración neonatal de líquido amniótico y de moco",
                      vcausa == 123 ~ "P242 Aspiración neonatal de sangre",
                      vcausa == 124 ~ "P243 Aspiración neonatal de leche y alimento regurgitado",
                      vcausa == 125 ~ "P248 Otros síndromes de aspiración neonatal",
                      vcausa == 126 ~ "P249 Síndrome de aspiración neonatal, sin otra especificación",
                      vcausa == 127 ~ "P250 Enfisema intersticial originado en el período perinatal",
                      vcausa == 128 ~ "P251 Neumotórax originado en el período perinatal",
                      vcausa == 129 ~ "P252 Neumomediastino originado en el período perinatal",
                      vcausa == 130 ~ "P253 Neumopericardio originado en el período perinatal",
                      vcausa == 131 ~ "P258 Otras afecciones relacionadas con el enfisema intersticial, originadas en el período perinatal",
                      vcausa == 132 ~ "P260 Hemorragia traqueobronquial originada en el período perinatal",
                      vcausa == 133 ~ "P261 Hemorragia pulmonar masiva originada en el período perinatal",
                      vcausa == 134 ~ "P268 Otras hemorragias pulmonares originadas en el período perinatal",
                      vcausa == 135 ~ "P269 Hemorragia pulmonar no especificada, originada en el período perinatal",
                      vcausa == 136 ~ "P270 Síndrome de wilson-mikity",
                      vcausa == 137 ~ "P271 Displasia broncopulmonar originada en el período perinatal",
                      vcausa == 138 ~ "P278 Otras enfermedades respiratorias crónicas originadas en el período perinatal",
                      vcausa == 139 ~ "P279 Enfermedad respiratoria crónica no especificada originada en el período perinatal",
                      vcausa == 140 ~ "P280 Atelectasia primaria del recién nacido",
                      vcausa == 141 ~ "P281 Otras atelectasias del recién nacido y las no especificadas",
                      vcausa == 142 ~ "P282 Ataque cianótico del recién nacido",
                      vcausa == 143 ~ "P283 Apnea primaria del sue¤o del recién nacido",
                      vcausa == 144 ~ "P284 Otras apneas del recién nacido",
                      vcausa == 145 ~ "P285 Insuficiencia respiratoria del recién nacido",
                      vcausa == 146 ~ "P288 Otros problemas respiratorios especificados del recién nacido",
                      vcausa == 147 ~ "P289 Afección respiratoria no especificada del recién nacido",
                      vcausa == 148 ~ "P290 Insuficiencia cardíaca neonatal",
                      vcausa == 149 ~ "P291 Disritmia cardíaca neonatal",
                      vcausa == 150 ~ "P292 Hipertensión neonatal",
                      vcausa == 151 ~ "P293 Persistencia de la circulación fetal",
                      vcausa == 152 ~ "P294 Isquemia mioc rdica transitoria del recién nacido",
                      vcausa == 153 ~ "P298 Otros trastornos cardiovasculares originados en el período perinatal",
                      vcausa == 154 ~ "P299 Trastorno cardiovascular no especificado, originado en el período perinatal",
                      vcausa == 155 ~ "P350 Síndrome de rubéola congénita",
                      vcausa == 156 ~ "P351 Infección citomegalovírica congénita",
                      vcausa == 157 ~ "P352 Infecciones congénitas por virus del herpes simple",
                      vcausa == 158 ~ "P353 Hepatitis viral congénita",
                      vcausa == 159 ~ "P358 Otras enfermedades virales congénitas",
                      vcausa == 160 ~ "P359 Enfermedad viral congénita, sin otra especificación",
                      vcausa == 161 ~ "P360 Sepsis del recién nacido debida a estreptococo del grupo b",
                      vcausa == 162 ~ "P361 Sepsis del recién nacido debida a otros estreptococos y a los no especificados",
                      vcausa == 163 ~ "P362 Sepsis del recién nacido debida a staphylococcus aureus",
                      vcausa == 164 ~ "P363 Sepsis del recién nacido debida a otros estafilococos y a los no especificados",
                      vcausa == 165 ~ "P364 Sepsis del recién nacido debida a escherichia coli",
                      vcausa == 166 ~ "P365 Sepsis del recién nacido debida a anaerobios",
                      vcausa == 167 ~ "P368 Sepsis del recién nacido debida a otras bacterias",
                      vcausa == 168 ~ "P369 Sepsis bacteriana del recién nacido, no especificada",
                      vcausa == 169 ~ "P370 Tuberculosis congénita",
                      vcausa == 170 ~ "P371 Toxoplasmosis congénita",
                      vcausa == 171 ~ "P372 Listeriosis congénita (diseminada)",
                      vcausa == 172 ~ "P373 Paludismo congénito por plasmodium falciparum",
                      vcausa == 173 ~ "P374 Otros paludismos congénitos",
                      vcausa == 174 ~ "P375 Candidiasis neonatal",
                      vcausa == 175 ~ "P378 Otras enfermedades neonatales infecciosas o parasitarias especificadas",
                      vcausa == 176 ~ "P379 Enfermedad infecciosa y parasitaria congénita, no especificada",
                      vcausa == 177 ~ "P38 Onfalitis del recién nacido con o sin hemorragia leve",
                      vcausa == 178 ~ "P390 Mastitis infecciosa neonatal",
                      vcausa == 179 ~ "P391 Conjuntivitis y dacriocistitis neonatales",
                      vcausa == 180 ~ "P392 Infección intraamniótica del feto, no clasificada en otra parte",
                      vcausa == 181 ~ "P393 Infección neonatal de las vías urinarias",
                      vcausa == 182 ~ "P394 Infección cut nea neonatal",
                      vcausa == 183 ~ "P398 Otras infecciones especificadas propias del período perinatal",
                      vcausa == 184 ~ "P399 Infección propia del período perinatal, no especificada",
                      vcausa == 185 ~ "P500 Pérdida de sangre fetal por vasa previa",
                      vcausa == 186 ~ "P501 Pérdida de sangre fetal por ruptura del cordón umbilical",
                      vcausa == 187 ~ "P502 Pérdida de sangre fetal por la placenta",
                      vcausa == 188 ~ "P503 Hemorragia fetal hacia el otro gemelo",
                      vcausa == 189 ~ "P504 Hemorragia fetal hacia la circulación materna",
                      vcausa == 190 ~ "P505 Pérdida de sangre fetal por el corte del cordón umbilical en el otro gemelo",
                      vcausa == 191 ~ "P508 Otras pérdidas de sangre fetal",
                      vcausa == 192 ~ "P509 Pérdida de sangre fetal, no especificada",
                      vcausa == 193 ~ "P510 Hemorragia umbilical masiva del recién nacido",
                      vcausa == 194 ~ "P518 Otras hemorragias umbilicales del recién nacido",
                      vcausa == 195 ~ "P519 Hemorragia umbilical del recién nacido, sin otra especificación",
                      vcausa == 196 ~ "P520 Hemorragia intraventricular (no traum tica) grado 1 del feto y del recién nacido",
                      vcausa == 197 ~ "P521 Hemorragia intraventricular (no traum tica) grado 2 del feto y del recién nacido",
                      vcausa == 198 ~ "P522 Hemorragia intraventricular (no traum tica) grado 3 del feto y del recién nacido",
                      vcausa == 199 ~ "P523 Hemorragia intraventricular (no traum tica) del feto y del recién nacido, sin otra especificación",
                      vcausa == 200 ~ "P524 Hemorragia intracerebral (no traum tica) del feto y del recién nacido",
                      vcausa == 201 ~ "P525 Hemorragia subaracnoidea (no traum tica) del feto y del recién nacido",
                      vcausa == 202 ~ "P526 Hemorragia cerebelosa y de la fosa posterior (no traum tica) del feto y del recién nacido",
                      vcausa == 203 ~ "P528 Otras hemorragias intracraneales (no traum ticas) del feto y del recién nacido",
                      vcausa == 204 ~ "P529 Hemorragia intracraneal (no traum tica) del feto y del recién nacido, sin otra especificación",
                      vcausa == 205 ~ "P53 Enfermedad hemorr gica del feto y del recién nacido",
                      vcausa == 206 ~ "P540 Hematemesis neonatal",
                      vcausa == 207 ~ "P541 Melena neonatal",
                      vcausa == 208 ~ "P542 Hemorragia rectal neonatal",
                      vcausa == 209 ~ "P543 Otras hemorragias gastrointestinales neonatales",
                      vcausa == 210 ~ "P544 Hemorragia suprarrenal neonatal",
                      vcausa == 211 ~ "P545 Hemorragia cut nea neonatal",
                      vcausa == 212 ~ "P546 Hemorragia vaginal neonatal",
                      vcausa == 213 ~ "P548 Otras hemorragias fetales y neonatales especificadas",
                      vcausa == 214 ~ "P549 Hemorragia fetal y neonatal, no especificada",
                      vcausa == 215 ~ "P550 Incompatibilidad rh del feto y del recién nacido",
                      vcausa == 216 ~ "P551 Incompatibilidad abo del feto y del recién nacido",
                      vcausa == 217 ~ "P558 Otras enfermedades hemolíticas del feto y del recién nacido",
                      vcausa == 218 ~ "P559 Enfermedad hemolítica del feto y del recién nacido, no especificada",
                      vcausa == 219 ~ "P560 Hidropesía fetal debida a incompatibilidad",
                      vcausa == 220 ~ "P569 Hidropesía fetal debida a otras enfermedades hemolíticas especificadas y a las no especificadas",
                      vcausa == 221 ~ "P570 Kernicterus debido a incompatibilidad",
                      vcausa == 222 ~ "P578 Kernicterus debido a otras causas especificadas",
                      vcausa == 223 ~ "P579 Kernicterus, no especificado",
                      vcausa == 224 ~ "P580 Ictericia neonatal debida a contusión",
                      vcausa == 225 ~ "P581 Ictericia neonatal debida a hemorragia",
                      vcausa == 226 ~ "P582 Ictericia neonatal debida a infección",
                      vcausa == 227 ~ "P583 Ictericia neonatal debida a policitemia",
                      vcausa == 228 ~ "P584 Ictericia neonatal debida a drogas o toxinas transmitidas por la madre o administradas al recién nacido",
                      vcausa == 229 ~ "P585 Ictericia neonatal debida a deglución de sangre materna",
                      vcausa == 230 ~ "P588 Ictericia neonatal debida a otras hemólisis excesivas especificadas",
                      vcausa == 231 ~ "P589 Ictericia neonatal debida a hemólisis excesiva, sin otra especificación",
                      vcausa == 232 ~ "P590 Ictericia neonatal asociada con el parto antes de término",
                      vcausa == 233 ~ "P591 Síndrome de la bilis espesa",
                      vcausa == 234 ~ "P592 Ictericia neonatal debida a otra lesión hep tica especificada o no",
                      vcausa == 235 ~ "P593 Ictericia neonatal por inhibidor de la leche materna",
                      vcausa == 236 ~ "P598 Ictericia neonatal por otras causas especificadas",
                      vcausa == 237 ~ "P599 Ictericia neonatal, no especificada",
                      vcausa == 238 ~ "P60 Coagulación intravascular diseminada en el feto y el recién nacido",
                      vcausa == 239 ~ "P610 Trombocitopenia neonatal transitoria",
                      vcausa == 240 ~ "P611 Policitemia neonatal",
                      vcausa == 241 ~ "P612 Anemia de la prematuridad",
                      vcausa == 242 ~ "P613 Anemia congénita debida a pérdida de sangre fetal",
                      vcausa == 243 ~ "P614 Otras anemias congénitas, no clasificadas en otra parte",
                      vcausa == 244 ~ "P615 Neutropenia neonatal transitoria",
                      vcausa == 245 ~ "P616 Otros trastornos neonatales transitorios de la coagulación",
                      vcausa == 246 ~ "P618 Otros trastornos hematológicos perinatales especificados",
                      vcausa == 247 ~ "P619 Trastorno hematológico perinatal, no especificado",
                      vcausa == 248 ~ "P700 Síndrome del recién nacido de madre con diabetes gestacional",
                      vcausa == 249 ~ "P701 Síndrome del recién nacido de madre diabética",
                      vcausa == 250 ~ "P702 Diabetes mellitus neonatal",
                      vcausa == 251 ~ "P703 Hipoglicemia neonatal yatrogénica",
                      vcausa == 252 ~ "P704 Otras hipoglicemias neonatales",
                      vcausa == 253 ~ "P708 Otros trastornos transitorios del metabolismo de los carbohidratos en el feto y el recién nacido",
                      vcausa == 254 ~ "P709 Trastorno transitorio no especificado del metabolismo de los carbohidratos en el feto y el recién nacido",
                      vcausa == 255 ~ "P710 Hipocalcemia del recién nacido debida a la leche de vaca",
                      vcausa == 256 ~ "P711 Otra hipocalcemia neonatal",
                      vcausa == 257 ~ "P712 Hipomagnesemia neonatal",
                      vcausa == 258 ~ "P713 Tetania neonatal sin mención de deficiencia de calcio o de magnesio",
                      vcausa == 259 ~ "P714 Hipoparatiroidismo neonatal transitorio",
                      vcausa == 260 ~ "P718 Otros trastornos neonatales transitorios del metabolismo del calcio y del magnesio",
                      vcausa == 261 ~ "P719 Trastorno neonatal transitorio no especificado del metabolismo del calcio y del magnesio",
                      vcausa == 262 ~ "P720 Bocio neonatal, no clasificado en otra parte",
                      vcausa == 263 ~ "P721 Hipertiroidismo neonatal transitorio",
                      vcausa == 264 ~ "P722 Otros trastornos neonatales transitorios de la función tiroidea, no clasificados en otra parte",
                      vcausa == 265 ~ "P728 Otros trastornos endocrinos neonatales transitorios especificados",
                      vcausa == 266 ~ "P729 Trastorno endocrino neonatal transitorio, no especificado",
                      vcausa == 267 ~ "P740 Acidosis metabólica tardía del recién nacido",
                      vcausa == 268 ~ "P741 Deshidratación del recién nacido",
                      vcausa == 269 ~ "P742 Alteraciones del equilibrio del sodio en el recién nacido",
                      vcausa == 270 ~ "P743 Alteraciones del equilibrio del potasio en el recién nacido",
                      vcausa == 271 ~ "P744 Otras alteraciones electrolíticas transitorias del recién nacido",
                      vcausa == 272 ~ "P745 Tirosinemia transitoria del recién nacido",
                      vcausa == 273 ~ "P748 Otras alteraciones metabólicas transitorias del recién nacido",
                      vcausa == 274 ~ "P749 Trastorno metabólico transitorio del recién nacido, no especificado",
                      vcausa == 275 ~ "P75* Ileo meconial (e841+)",
                      vcausa == 276 ~ "P760 Síndrome del tapón de meconio",
                      vcausa == 277 ~ "P761 Ileo transitorio del recién nacido",
                      vcausa == 278 ~ "P762 Obstrucción intestinal debida a la leche espesa",
                      vcausa == 279 ~ "P768 Otras obstrucciones intestinales especificadas del recién nacido",
                      vcausa == 280 ~ "P769 Obstrucción intestinal del recién nacido, no especificada",
                      vcausa == 281 ~ "P77 Enterocolitis necrotizante del feto y del recién nacido",
                      vcausa == 282 ~ "P780 Perforación intestinal perinatal",
                      vcausa == 283 ~ "P781 Otras peritonitis neonatales",
                      vcausa == 284 ~ "P782 Hematemesis y melena neonatales debidas a la deglución de sangre materna",
                      vcausa == 285 ~ "P783 Diarrea neonatal no infecciosa",
                      vcausa == 286 ~ "P788 Otros trastornos perinatales específicos del sistema digestivo",
                      vcausa == 287 ~ "P789 Trastorno perinatal del sistema digestivo, no especificado",
                      vcausa == 288 ~ "P800 Síndrome del enfriamiento",
                      vcausa == 289 ~ "P808 Otras hipotermias del recién nacido",
                      vcausa == 290 ~ "P809 Hipotermia del recién nacido, no especificada",
                      vcausa == 291 ~ "P810 Hipertermia del recién nacido inducida por las condiciones ambientales",
                      vcausa == 292 ~ "P818 Otras alteraciones especificadas de la regulación de la temperatura del recién nacido",
                      vcausa == 293 ~ "P819 Alteración no especificada de la regulación de la temperatura en el recién nacido",
                      vcausa == 294 ~ "P830 Esclerema neonatal",
                      vcausa == 295 ~ "P831 Eritema tóxico neonatal",
                      vcausa == 296 ~ "P832 Hidropesía fetal no debida a enfermedad hemolítica",
                      vcausa == 297 ~ "P833 Otros edemas y los no especificados, propios del feto y del recién nacido",
                      vcausa == 298 ~ "P834 Ingurgitación mamaria del recién nacido",
                      vcausa == 299 ~ "P835 Hidrocele congénito",
                      vcausa == 300 ~ "P836 Pólipo umbilical del recién nacido",
                      vcausa == 301 ~ "P838 Otras afecciones especificadas de la piel, propias del feto y del recién nacido",
                      vcausa == 302 ~ "P839 Afección no especificada de la piel, propia del feto y del recién nacido",
                      vcausa == 303 ~ "P90 Convulsiones del recién nacido",
                      vcausa == 304 ~ "P910 Isquemia cerebral neonatal",
                      vcausa == 305 ~ "P911 Quistes periventriculares adquiridos del recién nacido",
                      vcausa == 306 ~ "P912 Leucomalacia cerebral neonatal",
                      vcausa == 307 ~ "P913 Irritabilidad cerebral neonatal",
                      vcausa == 308 ~ "P914 Depresión cerebral neonatal",
                      vcausa == 309 ~ "P915 Coma neonatal",
                      vcausa == 310 ~ "P918 Otras alteraciones cerebrales especificadas del recién nacido",
                      vcausa == 311 ~ "P919 Alteración cerebral no especificada del recién nacido",
                      vcausa == 312 ~ "P920 Vómitos del recién nacido",
                      vcausa == 313 ~ "P921 Regurgitación y rumiación del recién nacido",
                      vcausa == 314 ~ "P922 Lentitud en la ingestión de alimentos del recién nacido",
                      vcausa == 315 ~ "P923 Hipoalimentación del recién nacido",
                      vcausa == 316 ~ "P924 Hiperalimentación del recién nacido",
                      vcausa == 317 ~ "P925 Dificultad neonatal en la lactancia materna",
                      vcausa == 318 ~ "P928 Otros problemas de alimentación del recién nacido",
                      vcausa == 319 ~ "P929 Problema no especificado de la alimentación del recién nacido",
                      vcausa == 320 ~ "P93 Reacciones e intoxicaciones debidas a drogas administradas al feto y al recién nacido",
                      vcausa == 321 ~ "P940 Miastenia grave neonatal transitoria",
                      vcausa == 322 ~ "P941 Hipertonía congénita",
                      vcausa == 323 ~ "P942 Hipotonía congénita",
                      vcausa == 324 ~ "P948 Otros trastornos del tono muscular en el recién nacido",
                      vcausa == 325 ~ "P949 Trastorno no especificado del tono muscular en el recién nacido",
                      vcausa == 326 ~ "P95 Muerte fetal de causa no especificada",
                      vcausa == 327 ~ "P960 Insuficiencia renal congénita",
                      vcausa == 328 ~ "P961 Síntomas neonatales de abstinencia por drogadicción materna",
                      vcausa == 329 ~ "P962 Síntomas de abstinencia por el uso terapéutico de drogas en el recién nacido",
                      vcausa == 330 ~ "P963 Amplitud de las suturas craneales del recién nacido",
                      vcausa == 331 ~ "P964 Terminación del embarazo, feto y recién nacido",
                      vcausa == 332 ~ "P965 Complicaciones de procedimientos intrauterinos, no clasificados en otra parte",
                      vcausa == 333 ~ "P968 Otras afecciones especificadas originadas en el período perinatal",
                      vcausa == 334 ~ "P969 Afección no especificada originada en el período perinatal",
                      vcausa == 335 ~ "Q000 Anencefalia",
                      vcausa == 336 ~ "Q001 Craneorraquisquisis",
                      vcausa == 337 ~ "Q002 Iniencefalia",
                      vcausa == 338 ~ "Q010 Encefalocele frontal",
                      vcausa == 339 ~ "Q011 Encefalocele nasofrontal",
                      vcausa == 340 ~ "Q012 Encefalocele occipital",
                      vcausa == 341 ~ "Q018 Encefalocele de otros sitios",
                      vcausa == 342 ~ "Q019 Encefalocele, no especificado",
                      vcausa == 343 ~ "Q02 Microcefalia",
                      vcausa == 344 ~ "Q030 Malformaciones del acueducto de silvio",
                      vcausa == 345 ~ "Q031 Atresia de los agujeros de magendie y de luschka",
                      vcausa == 346 ~ "Q038 Otros hidrocéfalos congénitos",
                      vcausa == 347 ~ "Q039 Hidrocéfalo congénito, no especificado",
                      vcausa == 348 ~ "Q040 Malformaciones congénitas del cuerpo calloso",
                      vcausa == 349 ~ "Q041 Arrinencefalia",
                      vcausa == 350 ~ "Q042 Holoprosencefalia",
                      vcausa == 351 ~ "Q043 Otras anomalías hipopl sicas del encéfalo",
                      vcausa == 352 ~ "Q044 Displasia opticoseptal",
                      vcausa == 353 ~ "Q045 Megalencefalia",
                      vcausa == 354 ~ "Q046 Quistes cerebrales congénitos",
                      vcausa == 355 ~ "Q048 Otras malformaciones congénitas del encéfalo, especificadas",
                      vcausa == 356 ~ "Q049 Malformación congénita del encéfalo, no especificada",
                      vcausa == 357 ~ "Q050 Espina bífida cervical con hidrocéfalo",
                      vcausa == 358 ~ "Q051 Espina bífida tor cica con hidrocéfalo",
                      vcausa == 359 ~ "Q052 Espina bífida lumbar con hidrocéfalo",
                      vcausa == 360 ~ "Q053 Espina bífida sacra con hidrocéfalo",
                      vcausa == 361 ~ "Q054 Espina bífida con hidrocéfalo, sin otra especificación",
                      vcausa == 362 ~ "Q055 Espina bífida cervical sin hidrocéfalo",
                      vcausa == 363 ~ "Q056 Espina bífida tor cica sin hidrocéfalo",
                      vcausa == 364 ~ "Q057 Espina bífida lumbar sin hidrocéfalo",
                      vcausa == 365 ~ "Q058 Espina bífida sacra sin hidrocéfalo",
                      vcausa == 366 ~ "Q059 Espina bífida, no especificada",
                      vcausa == 367 ~ "Q060 Amielia",
                      vcausa == 368 ~ "Q061 Hipoplasia y displasia de la médula espinal",
                      vcausa == 369 ~ "Q062 Diastematomielia",
                      vcausa == 370 ~ "Q063 Otras anomalías congénitas de la cola de caballo",
                      vcausa == 371 ~ "Q064 Hidromielia",
                      vcausa == 372 ~ "Q068 Otras malformaciones congénitas especificadas de la médula espinal",
                      vcausa == 373 ~ "Q069 Malformación congénita de la médula espinal, no especificada",
                      vcausa == 374 ~ "Q070 Síndrome de arnold-chiari",
                      vcausa == 375 ~ "Q078 Otras malformaciones congénitas del sistema nervioso, especificadas",
                      vcausa == 376 ~ "Q079 Malformación congénita del sistema nervioso, no especificada",
                      vcausa == 377 ~ "Q100 Blefaroptosis congénita",
                      vcausa == 378 ~ "Q101 Ectropión congénito",
                      vcausa == 379 ~ "Q102 Entropión congénito",
                      vcausa == 380 ~ "Q103 Otras malformaciones congénitas de los p rpados",
                      vcausa == 381 ~ "Q104 Ausencia y agenesia del aparato lagrimal",
                      vcausa == 382 ~ "Q105 Estenosis y estrechez congénitas del conducto lagrimal",
                      vcausa == 383 ~ "Q106 Otras malformaciones congénitas del aparato lagrimal",
                      vcausa == 384 ~ "Q107 Malformación congénita de la órbita",
                      vcausa == 385 ~ "Q110 Globo ocular quístico",
                      vcausa == 386 ~ "Q111 Otras anoftalmías",
                      vcausa == 387 ~ "Q112 Microftalmía",
                      vcausa == 388 ~ "Q113 Macroftalmía",
                      vcausa == 389 ~ "Q120 Catarata congénita",
                      vcausa == 390 ~ "Q121 Desplazamiento congénito del cristalino",
                      vcausa == 391 ~ "Q122 Coloboma del cristalino",
                      vcausa == 392 ~ "Q123 Afaquia congénita",
                      vcausa == 393 ~ "Q124 Esferofaquia",
                      vcausa == 394 ~ "Q128 Otras malformaciones congénitas del cristalino",
                      vcausa == 395 ~ "Q129 Malformación congénita del cristalino, no especificada",
                      vcausa == 396 ~ "Q130 Coloboma del iris",
                      vcausa == 397 ~ "Q131 Ausencia del iris",
                      vcausa == 398 ~ "Q132 Otras malformaciones congénitas del iris",
                      vcausa == 399 ~ "Q133 Opacidad corneal congénita",
                      vcausa == 400 ~ "Q134 Otras malformaciones congénitas de la córnea",
                      vcausa == 401 ~ "Q135 Esclerótica azul",
                      vcausa == 402 ~ "Q138 Otras malformaciones congénitas del segmento anterior del ojo",
                      vcausa == 403 ~ "Q139 Malformación congénita del segmento anterior del ojo, no especificada",
                      vcausa == 404 ~ "Q140 Malformación congénita del humor vítreo",
                      vcausa == 405 ~ "Q141 Malformación congénita de la retina",
                      vcausa == 406 ~ "Q142 Malformación congénita del disco óptico",
                      vcausa == 407 ~ "Q143 Malformación congénita de la coroides",
                      vcausa == 408 ~ "Q148 Otras malformaciones congénitas del segmento posterior del ojo",
                      vcausa == 409 ~ "Q149 Malformación congénita del segmento posterior del ojo, no especificada",
                      vcausa == 410 ~ "Q150 Glaucoma congénito",
                      vcausa == 411 ~ "Q158 Otras malformaciones congénitas del ojo, especificadas",
                      vcausa == 412 ~ "Q159 Malformaciones congénitas del ojo, no especificadas",
                      vcausa == 413 ~ "Q160 Ausencia congénita del pabellón (de la oreja)",
                      vcausa == 414 ~ "Q161 Ausencia congénita, atresia o estrechez del conducto auditivo (externo)",
                      vcausa == 415 ~ "Q162 Ausencia de la trompa de eustaquio",
                      vcausa == 416 ~ "Q163 Malformación congénita de los huesecillos del oído",
                      vcausa == 417 ~ "Q164 Otras malformaciones congénitas del oído medio",
                      vcausa == 418 ~ "Q165 Malformación congénita del oído interno",
                      vcausa == 419 ~ "Q169 Malformación congénita del oído que causa alteración de la audición, sin otra especificación",
                      vcausa == 420 ~ "Q170 Oreja supernumeraria",
                      vcausa == 421 ~ "Q171 Macrotia",
                      vcausa == 422 ~ "Q172 Microtia",
                      vcausa == 423 ~ "Q173 Otras deformidades del pabellón auricular",
                      vcausa == 424 ~ "Q174 Anomalía de la posición de la oreja",
                      vcausa == 425 ~ "Q175 Oreja prominente",
                      vcausa == 426 ~ "Q178 Otras malformaciones congénitas del oído, especificadas",
                      vcausa == 427 ~ "Q179 Malformación congénita del oído, no especificada",
                      vcausa == 428 ~ "Q180 Seno, fístula o quiste de la hendidura branquial",
                      vcausa == 429 ~ "Q181 Seno y quiste preauricular",
                      vcausa == 430 ~ "Q182 Otras malformaciones de las hendiduras branquiales",
                      vcausa == 431 ~ "Q183 Pterigión del cuello",
                      vcausa == 432 ~ "Q184 Macrostomía",
                      vcausa == 433 ~ "Q185 Microstomía",
                      vcausa == 434 ~ "Q186 Macroqueilia",
                      vcausa == 435 ~ "Q187 Microqueilia",
                      vcausa == 436 ~ "Q188 Otras malformaciones congénitas especificadas de cara y cuello",
                      vcausa == 437 ~ "Q189 Malformación congénita de la cara y del cuello, no especificada",
                      vcausa == 438 ~ "Q200 Tronco arterioso común",
                      vcausa == 439 ~ "Q201 Transposición de los grandes vasos en ventrículo derecho",
                      vcausa == 440 ~ "Q202 Transposición de los grandes vasos en ventrículo izquierdo",
                      vcausa == 441 ~ "Q203 Discordancia de la conexión ventriculoarterial",
                      vcausa == 442 ~ "Q204 Ventrículo con doble entrada",
                      vcausa == 443 ~ "Q205 Discordancia de la conexión auriculoventricular",
                      vcausa == 444 ~ "Q206 Isomerismo de los apéndices auriculares",
                      vcausa == 445 ~ "Q208 Otras malformaciones congénitas de las c maras cardíacas y sus conexiones",
                      vcausa == 446 ~ "Q209 Malformación congénita de las c maras cardíacas y sus conexiones, no especificada",
                      vcausa == 447 ~ "Q210 Defecto del tabique ventricular",
                      vcausa == 448 ~ "Q211 Defecto del tabique auricular",
                      vcausa == 449 ~ "Q212 Defecto del tabique auriculoventricular",
                      vcausa == 450 ~ "Q213 Tetralogía de fallot",
                      vcausa == 451 ~ "Q214 Defecto del tabique aortopulmonar",
                      vcausa == 452 ~ "Q218 Otras malformaciones congénitas de los tabiques cardíacos",
                      vcausa == 453 ~ "Q219 Malformación congénita del tabique cardíaco, no especificada",
                      vcausa == 454 ~ "Q220 Atresia de la v lvula pulmonar",
                      vcausa == 455 ~ "Q221 Estenosis congénita de la v lvula pulmonar",
                      vcausa == 456 ~ "Q222 Insuficiencia congénita de la v lvula pulmonar",
                      vcausa == 457 ~ "Q223 Otras malformaciones congénitas de la v lvula pulmonar",
                      vcausa == 458 ~ "Q224 Estenosis congénita de la v lvula tricúspide",
                      vcausa == 459 ~ "Q225 Anomalía de ebstein",
                      vcausa == 460 ~ "Q226 Síndrome de hipoplasia del corazón derecho",
                      vcausa == 461 ~ "Q228 Otras malformaciones congénitas de la v lvula tricúspide",
                      vcausa == 462 ~ "Q229 Malformación congénita de la v lvula tricúspide, no especificada",
                      vcausa == 463 ~ "Q230 Estenosis congénita de la v lvula aórtica",
                      vcausa == 464 ~ "Q231 Insuficiencia congénita de la v lvula aórtica",
                      vcausa == 465 ~ "Q232 Estenosis mitral congénita",
                      vcausa == 466 ~ "Q233 Insuficiencia mitral congénita",
                      vcausa == 467 ~ "Q234 Síndrome de hipoplasia del corazón izquierdo",
                      vcausa == 468 ~ "Q238 Otras malformaciones congénitas de las v lvulas aórtica y mitral",
                      vcausa == 469 ~ "Q239 Malformación congénita de las v lvulas aórtica y mitral, no especificada",
                      vcausa == 470 ~ "Q240 Dextrocardia",
                      vcausa == 471 ~ "Q241 Levocardia",
                      vcausa == 472 ~ "Q242 Corazón triauricular",
                      vcausa == 473 ~ "Q243 Estenosis del infundíbulo pulmonar",
                      vcausa == 474 ~ "Q244 Estenosis subaórtica congénita",
                      vcausa == 475 ~ "Q245 Malformación de los vasos coronarios",
                      vcausa == 476 ~ "Q246 Bloqueo cardíaco congénito",
                      vcausa == 477 ~ "Q248 Otras malformaciones congénitas del corazón, especificadas",
                      vcausa == 478 ~ "Q249 Malformación congénita del corazón, no especificada",
                      vcausa == 479 ~ "Q250 Conducto arterioso permeable",
                      vcausa == 480 ~ "Q251 Coartación de la aorta",
                      vcausa == 481 ~ "Q252 Atresia de la aorta",
                      vcausa == 482 ~ "Q253 Estenosis de la aorta",
                      vcausa == 483 ~ "Q254 Otras malformaciones congénitas de la aorta",
                      vcausa == 484 ~ "Q255 Atresia de la arteria pulmonar",
                      vcausa == 485 ~ "Q256 Estenosis de la arteria pulmonar",
                      vcausa == 486 ~ "Q257 Otras malformaciones congénitas de la arteria pulmonar",
                      vcausa == 487 ~ "Q258 Otras malformaciones congénitas de las grandes arterias",
                      vcausa == 488 ~ "Q259 Malformación congénita de las grandes arterias, no especificada",
                      vcausa == 489 ~ "Q260 Estenosis congénita de la vena cava",
                      vcausa == 490 ~ "Q261 Persistencia de la vena cava superior izquierda",
                      vcausa == 491 ~ "Q262 Conexión anómala total de las venas pulmonares",
                      vcausa == 492 ~ "Q263 Conexión anómala parcial de las venas pulmonares",
                      vcausa == 493 ~ "Q264 Conexión anómala de las venas pulmonares, sin otra especificación",
                      vcausa == 494 ~ "Q265 Conexión anómala de la vena porta",
                      vcausa == 495 ~ "Q266 Fístula arteria hep tica-vena porta",
                      vcausa == 496 ~ "Q268 Otras malformaciones congénitas de las grandes venas",
                      vcausa == 497 ~ "Q269 Malformación congénita de las grandes venas, no especificada",
                      vcausa == 498 ~ "Q270 Ausencia e hipoplasia congénita de la arteria umbilical",
                      vcausa == 499 ~ "Q271 Estenosis congénita de la arteria renal",
                      vcausa == 500 ~ "Q272 Otras malformaciones congénitas de la arteria renal",
                      vcausa == 501 ~ "Q273 Malformación arteriovenosa periférica",
                      vcausa == 502 ~ "Q274 Flebectasia congénita",
                      vcausa == 503 ~ "Q278 Otras malformaciones congénitas del sistema vascular periférico, especificadas",
                      vcausa == 504 ~ "Q279 Malformación congénita del sistema vascular periférico, no especificada",
                      vcausa == 505 ~ "Q280 Malformación arteriovenosa de los vasos precerebrales",
                      vcausa == 506 ~ "Q281 Otras malformaciones de los vasos precerebrales",
                      vcausa == 507 ~ "Q282 Malformación arteriovenosa de los vasos cerebrales",
                      vcausa == 508 ~ "Q283 Otras malformaciones de los vasos cerebrales",
                      vcausa == 509 ~ "Q288 Otras malformaciones congénitas del sistema circulatorio, especificadas",
                      vcausa == 510 ~ "Q289 Malformación congénita del sistema circulatorio, no especificada",
                      vcausa == 511 ~ "Q300 Atresia de las coanas",
                      vcausa == 512 ~ "Q301 Agenesia o hipoplasia de la nariz",
                      vcausa == 513 ~ "Q302 Hendidura, fisura o muesca de la nariz",
                      vcausa == 514 ~ "Q303 Perforación congénita del tabique nasal",
                      vcausa == 515 ~ "Q308 Otras malformaciones congénitas de la nariz",
                      vcausa == 516 ~ "Q309 Malformación congénita de la nariz, no especificada",
                      vcausa == 517 ~ "Q310 Pterigión de la laringe",
                      vcausa == 518 ~ "Q311 Estenosis subglótica congénita",
                      vcausa == 519 ~ "Q312 Hipoplasia laríngea",
                      vcausa == 520 ~ "Q313 Laringocele",
                      vcausa == 521 ~ "Q314 Estridor laríngeo congénito",
                      vcausa == 522 ~ "Q318 Otras malformaciones congénitas de la laringe",
                      vcausa == 523 ~ "Q319 Malformación congénita de la laringe, no especificada",
                      vcausa == 524 ~ "Q320 Traqueomalacia congénita",
                      vcausa == 525 ~ "Q321 Otras malformaciones congénitas de la tr quea",
                      vcausa == 526 ~ "Q322 Broncomalacia congénita",
                      vcausa == 527 ~ "Q323 Estenosis congénita de los bronquios",
                      vcausa == 528 ~ "Q324 Otras malformaciones congénitas de los bronquios",
                      vcausa == 529 ~ "Q330 Quiste pulmonar congénito",
                      vcausa == 530 ~ "Q331 Lóbulo pulmonar supernumerario",
                      vcausa == 531 ~ "Q332 Secuestro del pulmón",
                      vcausa == 532 ~ "Q333 Agenesia del pulmón",
                      vcausa == 533 ~ "Q334 Bronquiectasia congénita",
                      vcausa == 534 ~ "Q335 Tejido ectópico en el pulmón",
                      vcausa == 535 ~ "Q336 Hipoplasia y displasia pulmonar",
                      vcausa == 536 ~ "Q338 Otras malformaciones congénitas del pulmón",
                      vcausa == 537 ~ "Q339 Malformación congénita del pulmón, no especificada",
                      vcausa == 538 ~ "Q340 Anomalía de la pleura",
                      vcausa == 539 ~ "Q341 Quiste congénito del mediastino",
                      vcausa == 540 ~ "Q348 Otras malformaciones congénitas especificadas del sistema respiratorio",
                      vcausa == 541 ~ "Q349 Malformación congénita del sistema respiratorio, no especificada",
                      vcausa == 543 ~ "Q351 Fisura del paladar duro",
                      vcausa == 545 ~ "Q353 Fisura del paladar blando",
                      vcausa == 547 ~ "Q355 Fisura del paladar duro y del paladar blando",
                      vcausa == 549 ~ "Q357 Fisura de la úvula",
                      vcausa == 551 ~ "Q359 Fisura del paladar, sin otra especificación",
                      vcausa == 552 ~ "Q360 Labio leporino, bilateral",
                      vcausa == 553 ~ "Q361 Labio leporino, línea media",
                      vcausa == 554 ~ "Q369 Labio leporino, unilateral",
                      vcausa == 555 ~ "Q370 Fisura del paladar duro con labio leporino, bilateral",
                      vcausa == 556 ~ "Q371 Fisura del paladar duro con labio leporino, unilateral",
                      vcausa == 557 ~ "Q372 Fisura del paladar blando con labio leporino, bilateral",
                      vcausa == 558 ~ "Q373 Fisura del paladar blando con labio leporino, unilateral",
                      vcausa == 559 ~ "Q374 Fisura del paladar duro y del paladar blando con labio leporino, bilateral",
                      vcausa == 560 ~ "Q375 Fisura del paladar duro y del paladar blando con labio leporino, unilateral",
                      vcausa == 561 ~ "Q378 Fisura del paladar con labio leporino bilateral, sin otra especificación",
                      vcausa == 562 ~ "Q379 Fisura del paladar con labio leporino unilateral, sin otra especificación",
                      vcausa == 563 ~ "Q380 Malformaciones congénitas de los labios, no clasificadas en otra parte",
                      vcausa == 564 ~ "Q381 Anquiloglosia",
                      vcausa == 565 ~ "Q382 Macroglosia",
                      vcausa == 566 ~ "Q383 Otras malformaciones congénitas de la lengua",
                      vcausa == 567 ~ "Q384 Malformaciones congénitas de las gl ndulas y de los conductos salivales",
                      vcausa == 568 ~ "Q385 Malformaciones congénitas del paladar, no clasificadas en otra parte",
                      vcausa == 569 ~ "Q386 Otras malformaciones congénitas de la boca",
                      vcausa == 570 ~ "Q387 Divertículo faríngeo",
                      vcausa == 571 ~ "Q388 Otras malformaciones congénitas de la faringe",
                      vcausa == 572 ~ "Q390 Atresia del esófago sin mención de fístula",
                      vcausa == 573 ~ "Q391 Atresia del esófago con fístula traqueoesof gica",
                      vcausa == 574 ~ "Q392 Fístula traqueoesof gica congénita sin mención de atresia",
                      vcausa == 575 ~ "Q393 Estrechez o estenosis congénita del esófago",
                      vcausa == 576 ~ "Q394 Pterigión del esófago",
                      vcausa == 577 ~ "Q395 Dilatación congénita del esófago",
                      vcausa == 578 ~ "Q396 Divertículo del esófago",
                      vcausa == 579 ~ "Q398 Otras malformaciones congénitas del esófago",
                      vcausa == 580 ~ "Q399 Malformación congénita del esófago, no especificada",
                      vcausa == 581 ~ "Q400 Estenosis hipertrófica congénita del píloro",
                      vcausa == 582 ~ "Q401 Hernia hiatal congénita",
                      vcausa == 583 ~ "Q402 Otras malformaciones congénitas del estómago, especificadas",
                      vcausa == 584 ~ "Q403 Malformación congénita del estómago, no especificada",
                      vcausa == 585 ~ "Q408 Otras malformaciones congénitas de la parte superior del tubo digestivo",
                      vcausa == 586 ~ "Q409 Malformación congénita de la parte superior del tubo digestivo, no especificada",
                      vcausa == 587 ~ "Q410 Ausencia, atresia y estenosis congénita del duodeno",
                      vcausa == 588 ~ "Q411 Ausencia, atresia y estenosis congénita del yeyuno",
                      vcausa == 589 ~ "Q412 Ausencia, atresia y estenosis congénita del íleon",
                      vcausa == 590 ~ "Q418 Ausencia, atresia y estenosis congénita de otras partes especificadas del intestino delgado",
                      vcausa == 591 ~ "Q419 Ausencia, atresia y estenosis congénita del intestino delgado, parte no especificada",
                      vcausa == 592 ~ "Q420 Ausencia, atresia y estenosis congénita del recto, con fístula",
                      vcausa == 593 ~ "Q421 Ausencia, atresia y estenosis congénita del recto, sin fístula",
                      vcausa == 594 ~ "Q422 Ausencia, atresia y estenosis congénita del ano, con fístula",
                      vcausa == 595 ~ "Q423 Ausencia, atresia y estenosis congénita del ano, sin fístula",
                      vcausa == 596 ~ "Q428 Ausencia, atresia y estenosis congénita de otras partes del intestino grueso",
                      vcausa == 597 ~ "Q429 Ausencia, atresia y estenosis congénita del intestino grueso, parte no especificada",
                      vcausa == 598 ~ "Q430 Divertículo de meckel",
                      vcausa == 599 ~ "Q431 Enfermedad de hirschsprung",
                      vcausa == 600 ~ "Q432 Otros trastornos funcionales congénitos del colon",
                      vcausa == 601 ~ "Q433 Malformaciones congénitas de la fijación del intestino",
                      vcausa == 602 ~ "Q434 Duplicación del intestino",
                      vcausa == 603 ~ "Q435 Ano ectópico",
                      vcausa == 604 ~ "Q436 Fístula congénita del recto y del ano",
                      vcausa == 605 ~ "Q437 Persistencia de la cloaca",
                      vcausa == 606 ~ "Q438 Otras malformaciones congénitas del intestino, especificadas",
                      vcausa == 607 ~ "Q439 Malformación congénita del intestino, no especificada",
                      vcausa == 608 ~ "Q440 Agenesia, aplasia e hipoplasia de la vesícula biliar",
                      vcausa == 609 ~ "Q441 Otras malformaciones congénitas de la vesícula biliar",
                      vcausa == 610 ~ "Q442 Atresia de los conductos biliares",
                      vcausa == 611 ~ "Q443 Estrechez y estenosis congénita de los conductos biliares",
                      vcausa == 612 ~ "Q444 Quiste del colédoco",
                      vcausa == 613 ~ "Q445 Otras malformaciones congénitas de los conductos biliares",
                      vcausa == 614 ~ "Q446 Enfermedad quística del hígado",
                      vcausa == 615 ~ "Q447 Otras malformaciones congénitas del hígado",
                      vcausa == 616 ~ "Q450 Agenesia, aplasia e hipoplasia del p ncreas",
                      vcausa == 617 ~ "Q451 P ncreas anular",
                      vcausa == 618 ~ "Q452 Quiste congénito del p ncreas",
                      vcausa == 619 ~ "Q453 Otras malformaciones congénitas del p ncreas y del conducto pancre tico",
                      vcausa == 620 ~ "Q458 Otras malformaciones congénitas del sistema digestivo, especificadas",
                      vcausa == 621 ~ "Q459 Malformación congénita del sistema digestivo, no especificada",
                      vcausa == 622 ~ "Q500 Ausencia congénita de ovario",
                      vcausa == 623 ~ "Q501 Quiste en desarrollo del ovario",
                      vcausa == 624 ~ "Q502 Torsión congénita del ovario",
                      vcausa == 625 ~ "Q503 Otras malformaciones congénitas de los ovarios",
                      vcausa == 626 ~ "Q504 Quiste embrionario de la trompa de falopio",
                      vcausa == 627 ~ "Q505 Quiste embrionario del ligamento ancho",
                      vcausa == 628 ~ "Q506 Otras malformaciones congénitas de la trompa de falopio y del ligamento ancho",
                      vcausa == 629 ~ "Q510 Agenesia y aplasia del útero",
                      vcausa == 630 ~ "Q511 Duplicación del útero con duplicación del cuello uterino y de la vagina",
                      vcausa == 631 ~ "Q512 Otra duplicación del útero",
                      vcausa == 632 ~ "Q513 Utero bicorne",
                      vcausa == 633 ~ "Q514 Utero unicorne",
                      vcausa == 634 ~ "Q515 Agenesia y aplasia del cuello uterino",
                      vcausa == 635 ~ "Q516 Quiste embrionario del cuello uterino",
                      vcausa == 636 ~ "Q517 Fístula congénita entre el útero y el tracto digestivo y urinario",
                      vcausa == 637 ~ "Q518 Otras malformaciones congénitas del útero y del cuello uterino",
                      vcausa == 638 ~ "Q519 Malformación congénita del útero y del cuello uterino, no especificada",
                      vcausa == 639 ~ "Q520 Ausencia congénita de la vagina",
                      vcausa == 640 ~ "Q521 Duplicación de la vagina",
                      vcausa == 641 ~ "Q522 Fístula rectovaginal congénita",
                      vcausa == 642 ~ "Q523 Himen imperforado",
                      vcausa == 643 ~ "Q524 Otras malformaciones congénitas de la vagina",
                      vcausa == 644 ~ "Q525 Fusión de labios de la vulva",
                      vcausa == 645 ~ "Q526 Malformación congénita del clítoris",
                      vcausa == 646 ~ "Q527 Otras malformaciones congénitas de la vulva",
                      vcausa == 647 ~ "Q528 Otras malformaciones congénitas de los órganos genitales femeninos, especificadas",
                      vcausa == 648 ~ "Q529 Malformación congénita de los genitales femeninos, no especificada",
                      vcausa == 649 ~ "Q530 Ectopia testicular",
                      vcausa == 650 ~ "Q531 Testículo no descendido, unilateral",
                      vcausa == 651 ~ "Q532 Testículo no descendido, bilateral",
                      vcausa == 652 ~ "Q539 Testículo no descendido, sin otra especificación",
                      vcausa == 653 ~ "Q540 Hipospadias del glande",
                      vcausa == 654 ~ "Q541 Hipospadias peneana",
                      vcausa == 655 ~ "Q542 Hipospadias penoscrotal",
                      vcausa == 656 ~ "Q543 Hipospadias perineal",
                      vcausa == 657 ~ "Q544 Encordamiento congénito del pene",
                      vcausa == 658 ~ "Q548 Otras hipospadias",
                      vcausa == 659 ~ "Q549 Hipospadias, no especificada",
                      vcausa == 660 ~ "Q550 Ausencia y aplasia del testículo",
                      vcausa == 661 ~ "Q551 Hipoplasia del testículo y del escroto",
                      vcausa == 662 ~ "Q552 Otras malformaciones congénitas de los testículos y del escroto",
                      vcausa == 663 ~ "Q553 Atresia del conducto deferente",
                      vcausa == 664 ~ "Q554 Otras malformaciones congénitas de los conductos deferentes, del epidídimo, de las vesículas seminales y de la próstata",
                      vcausa == 665 ~ "Q555 Aplasia y ausencia congénita del pene",
                      vcausa == 666 ~ "Q556 Otras malformaciones congénitas del pene",
                      vcausa == 667 ~ "Q558 Otras malformaciones congénitas de los órganos genitales masculinos, especificadas",
                      vcausa == 668 ~ "Q559 Malformación congénita de los órganos genitales masculinos, no especificada",
                      vcausa == 669 ~ "Q560 Hermafroditismo, no clasificado en otra parte",
                      vcausa == 670 ~ "Q561 Seudohermafroditismo masculino, no clasificado en otra parte",
                      vcausa == 671 ~ "Q562 Seudohermafroditismo femenino, no clasificado en otra parte",
                      vcausa == 672 ~ "Q563 Seudohermafroditismo, no especificado",
                      vcausa == 673 ~ "Q564 Sexo indeterminado, sin otra especificación",
                      vcausa == 674 ~ "Q600 Agenesia renal, unilateral",
                      vcausa == 675 ~ "Q601 Agenesia renal, bilateral",
                      vcausa == 676 ~ "Q602 Agenesia renal, sin otra especificación",
                      vcausa == 677 ~ "Q603 Hipoplasia renal, unilateral",
                      vcausa == 678 ~ "Q604 Hipoplasia renal, bilateral",
                      vcausa == 679 ~ "Q605 Hipoplasia renal, no especificada",
                      vcausa == 680 ~ "Q606 Síndrome de potter",
                      vcausa == 681 ~ "Q610 Quiste renal solitario congénito",
                      vcausa == 682 ~ "Q611 Ri¤ón poliquístico, tipo infantil",
                      vcausa == 683 ~ "Q612 Ri¤ón poliquístico, tipo adulto",
                      vcausa == 684 ~ "Q613 Ri¤ón poliquístico, tipo no especificado",
                      vcausa == 685 ~ "Q614 Displasia renal",
                      vcausa == 686 ~ "Q615 Ri¤ón quístico medular",
                      vcausa == 687 ~ "Q618 Otras enfermedades renales quísticas",
                      vcausa == 688 ~ "Q619 Enfermedad quística del ri¤ón, no especificada",
                      vcausa == 689 ~ "Q620 Hidronefrosis congénita",
                      vcausa == 690 ~ "Q621 Atresia y estenosis del uréter",
                      vcausa == 691 ~ "Q622 Megalouréter congénito",
                      vcausa == 692 ~ "Q623 Otros defectos obstructivos de la pelvis renal y del uréter",
                      vcausa == 693 ~ "Q624 Agenesia del uréter",
                      vcausa == 694 ~ "Q625 Duplicación del uréter",
                      vcausa == 695 ~ "Q626 Mala posición del uréter",
                      vcausa == 696 ~ "Q627 Reflujo vésico-urétero-renal congénito",
                      vcausa == 697 ~ "Q628 Otras malformaciones congénitas del uréter",
                      vcausa == 698 ~ "Q630 Ri¤ón supernumerario",
                      vcausa == 699 ~ "Q631 Ri¤ón lobulado, fusionado y en herradura",
                      vcausa == 700 ~ "Q632 Ri¤ón ectópico",
                      vcausa == 701 ~ "Q633 Hiperplasia renal y ri¤ón gigante",
                      vcausa == 702 ~ "Q638 Otras malformaciones congénitas del ri¤ón, especificadas",
                      vcausa == 703 ~ "Q639 Malformación congénita del ri¤ón, no especificada",
                      vcausa == 704 ~ "Q640 Epispadias",
                      vcausa == 705 ~ "Q641 Extrofia de la vejiga urinaria",
                      vcausa == 706 ~ "Q642 V lvulas uretrales posteriores congénitas",
                      vcausa == 707 ~ "Q643 Otras atresias y estenosis de la uretra y del cuello de la vejiga",
                      vcausa == 708 ~ "Q644 Malformación del uraco",
                      vcausa == 709 ~ "Q645 Ausencia congénita de la vejiga y de la uretra",
                      vcausa == 710 ~ "Q646 Divertículo congénito de la vejiga",
                      vcausa == 711 ~ "Q647 Otras malformaciones congénitas de la vejiga y de la uretra",
                      vcausa == 712 ~ "Q648 Otras malformaciones congénitas del aparato urinario, especificadas",
                      vcausa == 713 ~ "Q649 Malformación congénita del aparato urinario, no especificada",
                      vcausa == 714 ~ "Q650 Luxación congénita de la cadera, unilateral",
                      vcausa == 715 ~ "Q651 Luxación congénita de la cadera, bilateral",
                      vcausa == 716 ~ "Q652 Luxación congénita de la cadera, no especificada",
                      vcausa == 717 ~ "Q653 Subluxación congénita de la cadera, unilateral",
                      vcausa == 718 ~ "Q654 Subluxación congénita de la cadera, bilateral",
                      vcausa == 719 ~ "Q655 Subluxación congénita de la cadera, no especificada",
                      vcausa == 720 ~ "Q656 Cadera inestable",
                      vcausa == 721 ~ "Q658 Otras deformidades congénitas de la cadera",
                      vcausa == 722 ~ "Q659 Deformidad congénita de la cadera, no especificada",
                      vcausa == 723 ~ "Q660 Talipes equinovarus",
                      vcausa == 724 ~ "Q661 Talipes calcaneovarus",
                      vcausa == 725 ~ "Q662 Metatarsus varus",
                      vcausa == 726 ~ "Q663 Otras deformidades varus congénitas de los pies",
                      vcausa == 727 ~ "Q664 Talipes calcaneovalgus",
                      vcausa == 728 ~ "Q665 Pie plano congénito",
                      vcausa == 729 ~ "Q666 Otras deformidades valgus congénitas de los pies",
                      vcausa == 730 ~ "Q667 Pie cavus",
                      vcausa == 731 ~ "Q668 Otras deformidades congénitas de los pies",
                      vcausa == 732 ~ "Q669 Deformidad congénita de los pies, no especificada",
                      vcausa == 733 ~ "Q670 Asimetría facial",
                      vcausa == 734 ~ "Q671 Facies comprimida",
                      vcausa == 735 ~ "Q672 Dolicocefalia",
                      vcausa == 736 ~ "Q673 Plagiocefalia",
                      vcausa == 737 ~ "Q674 Otras deformidades congénitas del cr neo, de la cara y de la mandíbula",
                      vcausa == 738 ~ "Q675 Deformidad congénita de la columna vertebral",
                      vcausa == 739 ~ "Q676 Tórax excavado",
                      vcausa == 740 ~ "Q677 Tórax en quilla",
                      vcausa == 741 ~ "Q678 Otras deformidades congénitas del tórax",
                      vcausa == 742 ~ "Q680 Deformidad congénita del músculo esternocleidomastoideo",
                      vcausa == 743 ~ "Q681 Deformidad congénita de la mano",
                      vcausa == 744 ~ "Q682 Deformidad congénita de la rodilla",
                      vcausa == 745 ~ "Q683 Curvatura congénita del fémur",
                      vcausa == 746 ~ "Q684 Curvatura congénita de la tibia y del peroné",
                      vcausa == 747 ~ "Q685 Curvatura congénita de hueso(s) largo(s) del miembro inferior, sin otra especificación",
                      vcausa == 748 ~ "Q688 Otras deformidades congénitas osteomusculares, especificadas",
                      vcausa == 749 ~ "Q690 Dedo(s) supernumerario(s) de la mano",
                      vcausa == 750 ~ "Q691 Pulgar(es) supernumerario(s)",
                      vcausa == 751 ~ "Q692 Dedo(s) supernumerario(s) del pie",
                      vcausa == 752 ~ "Q699 Polidactilia, no especificada",
                      vcausa == 753 ~ "Q700 Fusión de los dedos de la mano",
                      vcausa == 754 ~ "Q701 Membrana interdigital de la mano",
                      vcausa == 755 ~ "Q702 Fusión de los dedos del pie",
                      vcausa == 756 ~ "Q703 Membrana interdigital del pie",
                      vcausa == 757 ~ "Q704 Polisindactilia",
                      vcausa == 758 ~ "Q709 Sindactilia, no especificada",
                      vcausa == 759 ~ "Q710 Ausencia congénita completa del (de los) miembro(s) superior(es)",
                      vcausa == 760 ~ "Q711 Ausencia congénita del brazo y del antebrazo con presencia de la mano",
                      vcausa == 761 ~ "Q712 Ausencia congénita del antebrazo y de la mano",
                      vcausa == 762 ~ "Q713 Ausencia congénita de la mano y el (los) dedo(s)",
                      vcausa == 763 ~ "Q714 Defecto por reducción longitudinal del radio",
                      vcausa == 764 ~ "Q715 Defecto por reducción longitudinal del cúbito",
                      vcausa == 765 ~ "Q716 Mano en pinza de langosta",
                      vcausa == 766 ~ "Q718 Otros defectos por reducción del (de los) miembro(s) superior(es)",
                      vcausa == 767 ~ "Q719 Defecto por reducción del miembro superior, no especificado",
                      vcausa == 768 ~ "Q720 Ausencia congénita completa del (de los) miembro(s) inferior(es)",
                      vcausa == 769 ~ "Q721 Ausencia congénita del muslo y de la pierna con presencia del pie",
                      vcausa == 770 ~ "Q722 Ausencia congénita de la pierna y del pie",
                      vcausa == 771 ~ "Q723 Ausencia congénita del pie y dedo(s) del pie",
                      vcausa == 772 ~ "Q724 Defecto por reducción longitudinal del fémur",
                      vcausa == 773 ~ "Q725 Defecto por reducción longitudinal de la tibia",
                      vcausa == 774 ~ "Q726 Defecto por reducción longitudinal del peroné",
                      vcausa == 775 ~ "Q727 Pie hendido",
                      vcausa == 776 ~ "Q728 Otros defectos por reducción del (de los) miembro(s) inferior(es)",
                      vcausa == 777 ~ "Q729 Defecto por reducción del miembro inferior, no especificado",
                      vcausa == 778 ~ "Q730 Ausencia completa de miembro(s) no especificado(s)",
                      vcausa == 779 ~ "Q731 Focomelia, miembro(s) no especificado(s)",
                      vcausa == 780 ~ "Q738 Otros defectos por reducción de miembro(s) no especificado(s)",
                      vcausa == 781 ~ "Q740 Otras malformaciones congénitas del (de los) miembro(s) superior(es), incluida la cintura escapular",
                      vcausa == 782 ~ "Q741 Malformación congénita de la rodilla",
                      vcausa == 783 ~ "Q742 Otras malformaciones congénitas del (de los) miembro(s) inferior(es), incluida la cintura pelviana",
                      vcausa == 784 ~ "Q743 Artrogriposis múltiple congénita",
                      vcausa == 785 ~ "Q748 Otras malformaciones congénitas especificadas del (de los) miembro(s)",
                      vcausa == 786 ~ "Q749 Malformación congénita de miembro(s), no especificada",
                      vcausa == 787 ~ "Q750 Craneosinostosis",
                      vcausa == 788 ~ "Q751 Disostosis craneofacial",
                      vcausa == 789 ~ "Q752 Hipertelorismo",
                      vcausa == 790 ~ "Q753 Macrocefalia",
                      vcausa == 791 ~ "Q754 Disostosis maxilofacial",
                      vcausa == 792 ~ "Q755 Disostosis oculomaxilar",
                      vcausa == 793 ~ "Q758 Otras malformaciones congénitas especificadas de los huesos del cr neo y de la cara",
                      vcausa == 794 ~ "Q759 Malformación congénita no especificada de los huesos del cr neo y de la cara",
                      vcausa == 795 ~ "Q760 Espina bífida oculta",
                      vcausa == 796 ~ "Q761 Síndrome de klippel-feil",
                      vcausa == 797 ~ "Q762 Espondilolistesis congénita",
                      vcausa == 798 ~ "Q763 Escoliosis congénita debida a malformación congénita ósea",
                      vcausa == 799 ~ "Q764 Otra malformación congénita de la columna vertebral, no asociada con escoliosis",
                      vcausa == 800 ~ "Q765 Costilla cervical",
                      vcausa == 801 ~ "Q766 Otras malformaciones congénitas de las costillas",
                      vcausa == 802 ~ "Q767 Malformación congénita del esternón",
                      vcausa == 803 ~ "Q768 Otras malformaciones congénitas del tórax óseo",
                      vcausa == 804 ~ "Q769 Malformación congénita del tórax óseo, no especificada",
                      vcausa == 805 ~ "Q770 Acondrogénesis",
                      vcausa == 806 ~ "Q771 Enanismo tanatofórico",
                      vcausa == 807 ~ "Q772 Síndrome de costilla corta",
                      vcausa == 808 ~ "Q773 Condrodisplasia punctata",
                      vcausa == 809 ~ "Q774 Acondroplasia",
                      vcausa == 810 ~ "Q775 Displasia distrófica",
                      vcausa == 811 ~ "Q776 Displasia condroectodérmica",
                      vcausa == 812 ~ "Q777 Displasia espondiloepifisaria",
                      vcausa == 813 ~ "Q778 Otras osteocondrodisplasias con defectos del crecimiento de los huesos largos y de la columna vertebral",
                      vcausa == 814 ~ "Q779 Osteocondrodisplasia con defectos del crecimiento de los huesos largos y de la columna vertebral, sin otra especificación",
                      vcausa == 815 ~ "Q780 Osteogénesis imperfecta",
                      vcausa == 816 ~ "Q781 Displasia poliostótica fibrosa",
                      vcausa == 817 ~ "Q782 Osteopetrosis",
                      vcausa == 818 ~ "Q783 Displasia diafisaria progresiva",
                      vcausa == 819 ~ "Q784 Encondromatosis",
                      vcausa == 820 ~ "Q785 Displasia metafisaria",
                      vcausa == 821 ~ "Q786 Exostosis congénita múltiple",
                      vcausa == 822 ~ "Q788 Otras osteocondrodisplasias especificadas",
                      vcausa == 823 ~ "Q789 Osteocondrodisplasia, no especificada",
                      vcausa == 824 ~ "Q790 Hernia diafragm tica congénita",
                      vcausa == 825 ~ "Q791 Otras malformaciones congénitas del diafragma",
                      vcausa == 826 ~ "Q792 Exónfalos",
                      vcausa == 827 ~ "Q793 Gastrosquisis",
                      vcausa == 828 ~ "Q794 Síndrome del abdomen en ciruela pasa",
                      vcausa == 829 ~ "Q795 Otras malformaciones congénitas de la pared abdominal",
                      vcausa == 830 ~ "Q796 Síndrome de ehlers-danlos",
                      vcausa == 831 ~ "Q798 Otras malformaciones congénitas del sistema osteomuscular",
                      vcausa == 832 ~ "Q799 Malformación congénita del sistema osteomuscular, no especificada",
                      vcausa == 833 ~ "Q800 Ictiosis vulgar",
                      vcausa == 834 ~ "Q801 Ictiosis ligada al cromosoma x",
                      vcausa == 835 ~ "Q802 Ictiosis lamelar",
                      vcausa == 836 ~ "Q803 Eritrodermia ictiosiforme vesicular congénita",
                      vcausa == 837 ~ "Q804 Feto arlequín",
                      vcausa == 838 ~ "Q808 Otras ictiosis congénitas",
                      vcausa == 839 ~ "Q809 Ictiosis congénita, no especificada",
                      vcausa == 840 ~ "Q810 Epidermólisis bullosa simple",
                      vcausa == 841 ~ "Q811 Epidermólisis bullosa letal",
                      vcausa == 842 ~ "Q812 Epidermólisis bullosa distrófica",
                      vcausa == 843 ~ "Q818 Otras epidermólisis bullosas",
                      vcausa == 844 ~ "Q819 Epidermólisis bullosa, no especificada",
                      vcausa == 845 ~ "Q820 Linfedema hereditario",
                      vcausa == 846 ~ "Q821 Xeroderma pigmentoso",
                      vcausa == 847 ~ "Q822 Mastocitosis",
                      vcausa == 848 ~ "Q823 Incontinencia pigmentaria",
                      vcausa == 849 ~ "Q824 Displasia ectodérmica (anhidrótica)",
                      vcausa == 850 ~ "Q825 Nevo no neopl sico, congénito",
                      vcausa == 851 ~ "Q828 Otras malformaciones congénitas de la piel, especificadas",
                      vcausa == 852 ~ "Q829 Malformación congénita de la piel, no especificada",
                      vcausa == 853 ~ "Q830 Ausencia congénita de la mama con ausencia del pezón",
                      vcausa == 854 ~ "Q831 Mama supernumeraria",
                      vcausa == 855 ~ "Q832 Ausencia de pezón",
                      vcausa == 856 ~ "Q833 Pezón supernumerario",
                      vcausa == 857 ~ "Q838 Otras malformaciones congénitas de la mama",
                      vcausa == 858 ~ "Q839 Malformación congénita de la mama, no especificada",
                      vcausa == 859 ~ "Q840 Alopecia congénita",
                      vcausa == 860 ~ "Q841 Alteraciones morfológicas congénitas del pelo, no clasificadas en otra parte",
                      vcausa == 861 ~ "Q842 Otras malformaciones congénitas del pelo",
                      vcausa == 862 ~ "Q843 Anoniquia",
                      vcausa == 863 ~ "Q844 Leuconiquia congénita",
                      vcausa == 864 ~ "Q845 Agrandamiento e hipertrofia de las u¤as",
                      vcausa == 865 ~ "Q846 Otras malformaciones congénitas de las u¤as",
                      vcausa == 866 ~ "Q848 Otras malformaciones congénitas de las faneras, especificadas",
                      vcausa == 867 ~ "Q849 Malformación congénita de las faneras, no especificada",
                      vcausa == 868 ~ "Q850 Neurofibromatosis (no maligna)",
                      vcausa == 869 ~ "Q851 Esclerosis tuberosa",
                      vcausa == 870 ~ "Q858 Otras facomatosis, no clasificadas en otra parte",
                      vcausa == 871 ~ "Q859 Facomatosis, no especificada",
                      vcausa == 872 ~ "Q860 Síndrome fetal (dismórfico) debido al alcohol",
                      vcausa == 873 ~ "Q861 Síndrome de hidantoína fetal",
                      vcausa == 874 ~ "Q862 Dismorfismo debido a warfarina",
                      vcausa == 875 ~ "Q868 Otros síndromes de malformaciones congénitas debidos a causas exógenas conocidas",
                      vcausa == 876 ~ "Q870 Síndromes de malformaciones congénitas que afectan principalmente la apariencia facial",
                      vcausa == 877 ~ "Q871 Síndromes de malformaciones congénitas asociadas principalmente con estatura baja:",
                      vcausa == 878 ~ "Q872 Síndromes de malformaciones congénitas que afectan principalmente los miembros",
                      vcausa == 879 ~ "Q873 Síndromes de malformaciones congénitas con exceso de crecimiento precoz",
                      vcausa == 880 ~ "Q874 Síndrome de marfan",
                      vcausa == 881 ~ "Q875 Otros síndromes de malformaciones congénitas con otros cambios esqueléticos",
                      vcausa == 882 ~ "Q878 Otros síndromes de malformaciones congénitas especificados, no clasificados en otra parte",
                      vcausa == 883 ~ "Q890 Malformaciones congénitas del bazo",
                      vcausa == 884 ~ "Q891 Malformaciones congénitas de la gl ndula suprarrenal",
                      vcausa == 885 ~ "Q892 Malformaciones congénitas de otras gl ndulas endocrinas",
                      vcausa == 886 ~ "Q893 Situs inversus",
                      vcausa == 887 ~ "Q894 Gemelos siameses",
                      vcausa == 888 ~ "Q897 Malformaciones congénitas múltiples, no clasificadas en otra parte",
                      vcausa == 889 ~ "Q898 Otras malformaciones congénitas, especificadas",
                      vcausa == 890 ~ "Q899 Malformación congénita, no especificada",
                      vcausa == 891 ~ "Q900 Trisomía 21 por falta de disyunción meiótica",
                      vcausa == 892 ~ "Q901 Trisomía 21 mosaico (por falta de disyunción mitótica)",
                      vcausa == 893 ~ "Q902 Trisomía 21 por translocación",
                      vcausa == 894 ~ "Q909 Síndrome de down, no especificado",
                      vcausa == 895 ~ "Q910 Trisomía 18 por falta de disyunción meiótica",
                      vcausa == 896 ~ "Q911 Trisomía 18 mosaico (por falta de disyunción mitótica)",
                      vcausa == 897 ~ "Q912 Trisomía 18 por translocación",
                      vcausa == 898 ~ "Q913 Síndrome de edwards, no especificado",
                      vcausa == 899 ~ "Q914 Trisomía 13 por falta de disyunción meiótica",
                      vcausa == 900 ~ "Q915 Trisomía 13 mosaico (por falta de disyunción mitótica)",
                      vcausa == 901 ~ "Q916 Trisomía 13 por translocación",
                      vcausa == 902 ~ "Q917 Síndrome de patau, no especificado",
                      vcausa == 903 ~ "Q920 Trisomía de un cromosoma completo, por falta de disyunción meiótica",
                      vcausa == 904 ~ "Q921 Trisomía de un cromosoma completo, mosaico (por falta de disyunción mitótica)",
                      vcausa == 905 ~ "Q922 Trisomía parcial mayor",
                      vcausa == 906 ~ "Q923 Trisomía parcial menor",
                      vcausa == 907 ~ "Q924 Duplicaciones visibles sólo en la prometafase",
                      vcausa == 908 ~ "Q925 Duplicaciones con otros reordenamientos complejos",
                      vcausa == 909 ~ "Q926 Cromosomas marcadores suplementarios",
                      vcausa == 910 ~ "Q927 Triploidía y poliploidía",
                      vcausa == 911 ~ "Q928 Otras trisomías y trisomías parciales de los autosomas, especificadas",
                      vcausa == 912 ~ "Q929 Trisomía y trisomía parcial de los autosomas, sin otra especificación",
                      vcausa == 913 ~ "Q930 Monosomía completa de un cromosoma, por falta de disyunción meiótica",
                      vcausa == 914 ~ "Q931 Monosomía completa de un cromosoma, mosaico (por falta de disyunción mitótica)",
                      vcausa == 915 ~ "Q932 Cromosoma reemplazado por anillo o dicéntrico",
                      vcausa == 916 ~ "Q933 Supresión del brazo corto del cromosoma 4",
                      vcausa == 917 ~ "Q934 Supresión del brazo corto del cromosoma 5",
                      vcausa == 918 ~ "Q935 Otras supresiones de parte de un cromosoma",
                      vcausa == 919 ~ "Q936 Supresiones visibles sólo en la prometafase",
                      vcausa == 920 ~ "Q937 Supresiones con otros reordenamientos complejos",
                      vcausa == 921 ~ "Q938 Otras supresiones de los autosomas",
                      vcausa == 922 ~ "Q939 Supresión de los autosomas, no especificada",
                      vcausa == 923 ~ "Q950 Translocación equilibrada e inserción en individuo normal",
                      vcausa == 924 ~ "Q951 Inversión cromosómica en individuo normal",
                      vcausa == 925 ~ "Q952 Reordenamiento autosómico equilibrado en individuo anormal",
                      vcausa == 926 ~ "Q953 Reordenamiento autosómico/sexual equilibrado en individuo anormal",
                      vcausa == 927 ~ "Q954 Individuos con heterocromatina marcadora",
                      vcausa == 928 ~ "Q955 Individuos con sitio fr gil autosómico",
                      vcausa == 929 ~ "Q958 Otros reordenamientos equilibrados y marcadores estructurales",
                      vcausa == 930 ~ "Q959 Reordenamiento equilibrado y marcador estructural, sin otra especificación",
                      vcausa == 931 ~ "Q960 Cariotipo 45,x",
                      vcausa == 932 ~ "Q961 Cariotipo 46,x iso (xq)",
                      vcausa == 933 ~ "Q962 Cariotipo 46,x con cromosoma sexual anormal excepto iso (xq)",
                      vcausa == 934 ~ "Q963 Mosaico 45,x/46,xx o xy",
                      vcausa == 935 ~ "Q964 Mosaico 45,x/otra(s) línea(s) celular(es) con cromosoma sexual anormal",
                      vcausa == 936 ~ "Q968 Otras variantes del síndrome de turner",
                      vcausa == 937 ~ "Q969 Síndrome de turner, no especificado",
                      vcausa == 938 ~ "Q970 Cariotipo 47,xxx",
                      vcausa == 939 ~ "Q971 Mujer con m s de tres cromosomas x",
                      vcausa == 940 ~ "Q972 Mosaico, líneas con número variable de cromosomas x",
                      vcausa == 941 ~ "Q973 Mujer con cariotipo 46,xy",
                      vcausa == 942 ~ "Q978 Otras anomalías de los cromosomas sexuales, con fenotipo femenino, especificadas",
                      vcausa == 943 ~ "Q979 Anomalía de los cromosomas sexuales, con fenotipo femenino, sin otra especificación",
                      vcausa == 944 ~ "Q980 Síndrome de klinefelter, cariotipo 47,xxy",
                      vcausa == 945 ~ "Q981 Síndrome de klinefelter, hombre con m s de dos cromosomas x",
                      vcausa == 946 ~ "Q982 Síndrome de klinefelter, hombre con cariotipo 46,xx",
                      vcausa == 947 ~ "Q983 Otro hombre con cariotipo 46,xx",
                      vcausa == 948 ~ "Q984 Síndrome de Klinefelter, no especificado",
                      vcausa == 949 ~ "Q985 Cariotipo 47,xyy",
                      vcausa == 950 ~ "Q986 Hombre con cromosoma sexual estructuralmente anormal",
                      vcausa == 951 ~ "Q987 Hombre con mosaico de cromosomas sexuales",
                      vcausa == 952 ~ "Q988 Otras anomalías de los cromosomas sexuales, con fenotipo masculino, especificadas",
                      vcausa == 953 ~ "Q989 Anomalía de los cromosomas sexuales, fenotipo masculino, sin otra especificación",
                      vcausa == 954 ~ "Q99 Otras anomalías cromosomicas, no clasificadas en otra parte",
                      vcausa == 955 ~ "Q990 Quimera 46,xx/46,xy",
                      vcausa == 956 ~ "Q991 Hermafrodita VERDADERO 46,xx",
                      vcausa == 957 ~ "Q992 Cromosoma X frágil",
                      vcausa == 958 ~ "Q998 Otras anomalías de los cromosomas, especificadas",
                      vcausa == 959 ~ "Q999 Anomalía cromosómica, no especificada"))

# Variable gcausa


bd <- bd %>%                      
mutate(
  gcausa =  case_when(gcausa == 1 ~ "P00 Feto y recién nacido afectados por condiciones de la mare no necesariamente relacionadas con el embarazo presente",
                      gcausa == 2 ~ "P01 Feto y recién nacido afectados por complicaciones maternas del embarazo",
                      gcausa == 3 ~ "P02 Feto y recién nacido afectados por complicaciones de la placenta, del cordón umbilical y de las membranas",
                      gcausa == 4 ~ "P03 Feto y recién nacido afectados por otras complicaciones del trabajo de parto y del parto",
                      gcausa == 5 ~ "P04 Feto y recién nacido afectados por influencias nocivas transmitidas a través de la placenta o de la leche materna",
                      gcausa == 6 ~ "P05 Retardo del crecimiento fetal y desmutrición fetal",
                      gcausa == 7 ~ "P07 Trastornos relacionados con duración corta de la gestación y con bajo peso al nacer, no clasificados en otra parte",
                      gcausa == 8 ~ "P08 Trastornos relacionados con el embarazo prolongado y con sobrepeso al nacer",
                      gcausa == 9 ~ "P10 Hemorragia y laceración intracraneal debidas a traumatismo del nacimiento",
                      gcausa == 10 ~ "P11 Otros trumatismos del nacimiento en el sistema nervioso central",
                      gcausa == 11 ~ "P12 Traumatismo del nacimiento en el cuero cabelludo",
                      gcausa == 12 ~ "P13 Traumatismo del esqueleto durante el nacimiento",
                      gcausa == 13 ~ "P14 Traumatismo del sistema nervioso periférico durante el nacimiento",
                      gcausa == 14 ~ "P15 Otros traumatismos del nacimiento",
                      gcausa == 15 ~ "P20 Hipoxia intrauterina",
                      gcausa == 16 ~ "P21 Asfixia del nacimiento",
                      gcausa == 17 ~ "P22 Dificultad respiratoria del recién nacido",
                      gcausa == 18 ~ "P23 Neumonía congénita",
                      gcausa == 19 ~ "P24 Síndromes de aspiración neonatal",
                      gcausa == 20 ~ "P25 Enfisema intersticial y afecciones relacionadas, originadas en el período perinatal",
                      gcausa == 21 ~ "P26 Hemorragia pulmonar originada en el período perinatal",
                      gcausa == 22 ~ "P27 Enfermedad respiratoria crónica originada en el período perinatal",
                      gcausa == 23 ~ "P28 Otros problemas respiratorios del recién nacido, originados en el período perinatal",
                      gcausa == 24 ~ "P29 Trastornos cardiovasculares originados en el período perinatal",
                      gcausa == 25 ~ "P35 Enfermedades virales congénitas",
                      gcausa == 26 ~ "P36 Sepsis bacteriana del recién nacido",
                      gcausa == 27 ~ "P37 Otras enfermedades infeccioasas y parasitarias congénitas",
                      gcausa == 28 ~ "P38 Onfalitis del recién nacido con o sin hemorragia leve",
                      gcausa == 29 ~ "P39 Otras infecciones específicas del período perinatal",
                      gcausa == 30 ~ "P50 Pérdida de sangre fetal",
                      gcausa == 31 ~ "P51 Hemorragia umbilical del recién nacido",
                      gcausa == 32 ~ "P52 Hemorragia intracraneal no trumática del feto y del recién nacido",
                      gcausa == 33 ~ "P53 Enfermedad hemorr gica del feto y del recién nacido",
                      gcausa == 34 ~ "P54 Otras hemorragias neonatales",
                      gcausa == 35 ~ "P55 Enfermedad hemolítica del feto y del recién nacido",
                      gcausa == 36 ~ "P56 Hidropesía fetal debida a enfermedad hemolítica",
                      gcausa == 37 ~ "P57 Kernicterus",
                      gcausa == 38 ~ "P58 Icetericia neonatal debida a otras hemólisis excesivas",
                      gcausa == 39 ~ "P59 Icetericia neonatal por otras causas y por las no especificadas",
                      gcausa == 40 ~ "P60 Coagulación intravascular diseminada en el feto y el recién nacido",
                      gcausa == 41 ~ "P61 Otros trastornos hematológicos perinatales",
                      gcausa == 42 ~ "P70 Trastornos transitorios del metabolismo de los carbohidratos específicos del feto y del recién nacido",
                      gcausa == 43 ~ "P71 Trastornos neonatales transitorios del metabolismo del calcio y del magnesio",
                      gcausa == 44 ~ "P72 Otros trastornos endocrinos neonatales transitorios",
                      gcausa == 45 ~ "P74 Otras alteraciones metabólicas y electrolíticas neonatales transitorias",
                      gcausa == 46 ~ "P75* Ileo meconial (E84.1+)",
                      gcausa == 47 ~ "P76 Otras obstrucciones intestinales del recién nacido",
                      gcausa == 48 ~ "P77 Enterocolitis necrotizante del feto y del recién nacido",
                      gcausa == 49 ~ "P78 Otros trastornos perinatales del sistema digestivo",
                      gcausa == 50 ~ "P80 Hipotermia del recién nacido",
                      gcausa == 51 ~ "P81 Otras alteraciones de la regulación de la temperatura en el recién nacido",
                      gcausa == 52 ~ "P83 Otras afecciones de la piel específicas del feto y del recién nacido",
                      gcausa == 53 ~ "P90 Convulsiones del recién nacido",
                      gcausa == 54 ~ "P91 Otras alteraciones cerebrales del recién nacido",
                      gcausa == 55 ~ "P92 Problemas de la ingestión de alimentos del recién nacido",
                      gcausa == 56 ~ "P93 Reacciones e intoxicaciones debidas a drogas administradas al feto y al recién nacido",
                      gcausa == 57 ~ "P94 Trastornos del tono muscular en el recién nacido",
                      gcausa == 58 ~ "P95 Muerte fetal de causa no especificada",
                      gcausa == 59 ~ "P96 Otras afecciones originadas en el período perinatal",
                      gcausa == 60 ~ "Q00 Anencefalia y malformaciones congénitas similares",
                      gcausa == 61 ~ "Q01 Encefalocele",
                      gcausa == 62 ~ "Q02 Microcefalia",
                      gcausa == 63 ~ "Q03 Hidrocéfalo congénito",
                      gcausa == 64 ~ "Q04 Otras malformaciones congénitas del encéfalo",
                      gcausa == 65 ~ "Q05 Espina bífida",
                      gcausa == 66 ~ "Q06 Otras malformaciones congénitas de la médula espinal",
                      gcausa == 67 ~ "Q07 Otras malformaciones congénitas del sistema nervioso",
                      gcausa == 68 ~ "Q10 Malformaciones congénitas de los párpados, del aparato lagrimal y de la órbita",
                      gcausa == 69 ~ "Q11 Anoftalmía, microftalmía y macroftalmía",
                      gcausa == 70 ~ "Q12 Malformaciones congénitas del cristalino",
                      gcausa == 71 ~ "Q13 Malformaciones congénitas del segmento anterior del ojo",
                      gcausa == 72 ~ "Q14 Malformaciones congénitas del segmento posterior del ojo",
                      gcausa == 73 ~ "Q15 Otras malformaciones congénitas del ojo",
                      gcausa == 74 ~ "Q16 Malformaciones congénitas del oído que causan alteración de la audición",
                      gcausa == 75 ~ "Q17 Otras malformaciones congénitas del oído",
                      gcausa == 76 ~ "Q18 Otras malformaciones congénitas de la cara y del cuello",
                      gcausa == 77 ~ "Q20 Malformaciones congénitas de las cámaras cardíacas y sus conexines",
                      gcausa == 78 ~ "Q21 Malformaciones congénitas de los tabiques cardíacos",
                      gcausa == 79 ~ "Q22 Malformaciones congénitas de las válvulas pulmonar y tricúspide",
                      gcausa == 80 ~ "Q23 Malformaciones congénitas de las válvulas aórtica y mitral",
                      gcausa == 81 ~ "Q24 Otras malformaciones congénitas del corazón",
                      gcausa == 82 ~ "Q25 Malformaciones congénitas de las grandes arterias",
                      gcausa == 83 ~ "Q26 Malformaciones congénitas de las grandes venas",
                      gcausa == 84 ~ "Q27 Otras malformaciones congénitas del sistema vascular",
                      gcausa == 85 ~ "Q28 Otras malformaciones congénitas del sistema circulatorio",
                      gcausa == 86 ~ "Q30 Malformaciones congénitas de la nariz",
                      gcausa == 87 ~ "Q31 Malformaciones congénitas de la laringe",
                      gcausa == 88 ~ "Q32 Malformaciones congénitas de la tráquea y de los bronquios",
                      gcausa == 89 ~ "Q33 Malformaciones congénitas del pulmón",
                      gcausa == 90 ~ "Q34 Otras malformaciones congénitas del sistema respiratorio",
                      gcausa == 91 ~ "Q35 Fisura del paladar",
                      gcausa == 92 ~ "Q36 Labio leporino",
                      gcausa == 93 ~ "Q37 Fisura del paladar con labio leporino",
                      gcausa == 94 ~ "Q38 Otras malformaciones congénitas de la lengua, de la boca y de la faringe",
                      gcausa == 95 ~ "Q39 Malformaciones congénitas del esófago",
                      gcausa == 96 ~ "Q40 Otras malformaciones congénitas de la parte superior del tubo digestivo",
                      gcausa == 97 ~ "Q41Ausencia, atresia y estenosis congénita del intestino delgado",
                      gcausa == 98 ~ "Q42 Ausencia, atresia y estenosis congénita del intestino grueso",
                      gcausa == 99 ~ "Q43 Otras malformaciones congénitas del intestino",
                      gcausa == 100 ~ "Q44 Malformaciones congénitas de la vesícula biliar, de los conductos biliares y del hígado",
                      gcausa == 101 ~ "Q45 Otras malformaciones congénitas del sistema digestivo",
                      gcausa == 102 ~ "Q50 Malformaciones congénitas de los ovarios, de las trompas de Falopio y de los ligamentos anchos",
                      gcausa == 103 ~ "Q51 Malformaciones congénitas del útero y del cuello uterino",
                      gcausa == 104 ~ "Q52 Otras malformaciones congénitas de los órganos genitale femeninos",
                      gcausa == 105 ~ "Q53 Testículo no descendido",
                      gcausa == 106 ~ "Q54 Hipospadias",
                      gcausa == 107 ~ "Q55 Otras malformaciones congénitas de los órganos genitales masculinos",
                      gcausa == 108 ~ "Q56 Sexo indeterminado y seudohermafroditismo",
                      gcausa == 109 ~ "Q60 Agnesia renal y otras malformaciones hipoplásicas del riñón",
                      gcausa == 110 ~ "Q61 Enfermedad quística del riñón",
                      gcausa == 111 ~ "Q62 Defectos obstructivos congénitos de la pelvis renal y malformaciones congénitas del uréter",
                      gcausa == 112 ~ "Q63 Otras malformaciones congénitas del riñón",
                      gcausa == 113 ~ "Q64 Otras malformaciones congénitas del sistema urinario",
                      gcausa == 114 ~ "Q65 Deformidades congénitas de la cadera",
                      gcausa == 115 ~ "Q66 Deformidades congénitas de los pies",
                      gcausa == 116 ~ "Q67 Deformidades osteomusculares congénitas de la cabeza, de la cara, de la columna vertebral y del tórax",
                      gcausa == 117 ~ "Q68 Otras deformidades osteomusculares congénitas",
                      gcausa == 118 ~ "Q69 Polidactilia",
                      gcausa == 119 ~ "Q70 Sindactilia",
                      gcausa == 120 ~ "Q71 Defectos por reducción del miembro superior",
                      gcausa == 121 ~ "Q72 Defectoss por reducción del miembro inferior",
                      gcausa == 122 ~ "Q73 Defectos por reducción de miembro no especificado",
                      gcausa == 123 ~ "Q74 Otras anomalías congénitas del (de los) miembro(s)",
                      gcausa == 124 ~ "Q75 Otras malformaciones congénitas de los huesos del cráneo y de la cara",
                      gcausa == 125 ~ "Q76 Malformaciones congénitas de la columna vertebral y tórax óseo",
                      gcausa == 126 ~ "Q77 Osteocondrodisplasia con defecto del crecimiento de los huesos largos y de la columna vertebral",
                      gcausa == 127 ~ "Q78 Otras osteocondrodisplasias",
                      gcausa == 128 ~ "Q79 Malformaciones congénitas del sistema osteomuscular, no clasificadas en otra parte",
                      gcausa == 129 ~ "Q80 Ictiosis congénita",
                      gcausa == 130 ~ "Q81 Epidermólisis bullosa",
                      gcausa == 131 ~ "Q82 Otras malformaciones congénitas de la piel",
                      gcausa == 132 ~ "Q83 Malformaciones congénitas de la mama",
                      gcausa == 133 ~ "Q84 Otras malformaciones congénitas de las faneras",
                      gcausa == 134 ~ "Q85 Facomatosis, no clasificada en otra parte",
                      gcausa == 135 ~ "Q86 Síndromes de malformacioenes congénitas debidos a causas exógenas conocidas, no clasificadas en otra parte",
                      gcausa == 136 ~ "Q87 Otros síndromes de malformaciones congénitas especificados que afectan múltiples sistemas",
                      gcausa == 137 ~ "Q89 Otras malformaciones congénitas, no clasificadas en otra parte",
                      gcausa == 138 ~ "Q90 Síndrome de Down",
                      gcausa == 139 ~ "Q91 Síndrome de Edwards y síndrome de Patau",
                      gcausa == 140 ~ "Q92 Otras trisonomías y trisonomías parciales de los autosomas, no clasificadas en otra parte",
                      gcausa == 141 ~ "Q93 Monosomías y supresiones de los autosomas, no clasificadas en otra parte",
                      gcausa == 142 ~ "Q95 Reordenamientos equilibrados y marcadores estructurales, no clasificados en otra parte",
                      gcausa == 143 ~ "Q96 Síndrome de Turner",
                      gcausa == 144 ~ "Q97 Otras anomalías de los cromosomas sexuales, con fenotipo femenino, no clasificadas en otra parte",
                      gcausa == 145 ~ "Q98 Otras anomalías de los cromosomas sexuales, con fenotipo masculino, no clasificadas en otra parte",
                      gcausa == 146 ~ "Q99 Otras anomalías cromosómicas, no clasificadas en otra parte"))




# Tabulados EDF_2024

# Serie No. 1.4.1 Número de muertes fetales en el año (t) a nivel nacional. Periodo 1997 - 2024


Serie.1.4.1 <- left_join(
  as.data.frame(
    bd %>% 
      group_by(anio_fall) %>% 
        filter(anio_fall == 2024) %>%
      summarise(
        total = sum(t, na.rm = TRUE))),
    as.data.frame(
    bd %>% 
      dcast(anio_fall ~ sexo, sum, value.var = "t")), by = c("anio_fall"))

# Serie No. 1.4.2 Número de muertes fetales en el año (t) según semanas de gestación Periodo 1997 - 2024


Serie.1.4.2 <- left_join(
  as.data.frame(
    bd %>% 
      group_by(anio_fall) %>% 
      filter(anio_fall == 2024) %>%
      summarise(
        total = sum(t, na.rm = TRUE))),
  as.data.frame(
    bd %>% 
      dcast(anio_fall ~ sem_gest, sum, value.var = "t")), by = c("anio_fall"))

# Serie No. 1.4.3 Defunciones fetales por edades simples de la madre a nivel nacional Periodo 1997 - 2024


Serie.1.4.3 <- left_join(
  as.data.frame(
    bd %>% 
      group_by(anio_fall) %>% 
      filter(anio_fall == 2024) %>%
      summarise(
        total = sum(t, na.rm = TRUE))),
  as.data.frame(
    bd %>% 
      dcast(anio_fall ~ edad_mad, sum, value.var = "t")), by = c("anio_fall"))

# Serie No. 1.4.4 Defunciones fetales en el año (t), según región y provincia de residencia habitual de la madre Periodo 2008 - 2024

Serie.1.4.4 <- left_join(
  as.data.frame(
    bd %>% 
      group_by(reg_res, prov_res) %>% 
      filter(anio_fall == 2024) %>% 
      summarise(
        total = sum(t, na.rm = TRUE))),
  as.data.frame(
    bd %>% 
      dcast(reg_res + prov_res ~ t, sum, value.var = "t")), by = c("reg_res", "prov_res")) %>% 
     select (reg_res, prov_res, total) %>% 
     adorn_totals()

# Serie No. 1.4.5 Defunciones fetales en el año (t), según lugar de ocurrencia Periodo 2008 - 2024

Serie.1.4.5 <- left_join(
  as.data.frame(
    bd %>% 
      group_by(anio_fall) %>% 
      filter(anio_fall == 2024) %>%
      summarise(
        total = sum(t, na.rm = TRUE))),
  as.data.frame(
    bd %>% 
      dcast(anio_fall ~ lugar_ocur, sum, value.var = "t")), by = c("anio_fall"))

# Cuadro No. 3.2.1 Defunciones fetales, por mes de ocurrencia, según provincia y área de residencia habitual de la madre Año 2024

Cuadro.3.2.1 <- left_join(
  as.data.frame(
    bd %>% 
      group_by(reg_res, prov_res) %>% 
      filter(anio_fall == 2024) %>% 
      summarise(
        total = sum(t, na.rm = TRUE))),
  as.data.frame(
    bd %>% 
      dcast(reg_res + prov_res + area_res ~ mes_fall, sum, value.var = "t")), by = c("reg_res", "prov_res")) %>% 
    mutate(totalm = (Enero + Febrero + Marzo + Abril + Mayo + Junio + Julio + Agosto + Septiembre + Octubre + Noviembre + Diciembre))  %>%
    select(reg_res, prov_res, area_res, totalm, everything(), -total) %>% 
    adorn_totals()
  

# Cuadro No. 3.2.2 Defunciones fetales, por semanas de gestación y sexo, según región y provincia de residencia habitual de la madre Año 2024

Cuadro.3.2.2 <- left_join(
  as.data.frame(
    bd %>% 
      group_by(reg_res, prov_res) %>% 
      filter(anio_fall == 2024 ) %>% 
      summarise(
        total = sum(t, na.rm = TRUE))),
  as.data.frame(
    bd %>% 
      dcast(reg_res + prov_res ~ semgest + sexo, value.var = "t")), by = c("reg_res", "prov_res")) %>%  
     adorn_totals()


# Cuadro No. 3.2.3  Defunciones fetales, por tipo de asistencia y sexo, según causas de defunción Año 2024

Cuadro.3.2.3 <- left_join(
  as.data.frame(
    bd %>% 
      group_by(gcausa, vcausa) %>% 
      filter(anio_fall == 2024) %>% 
      summarise(
        total = sum(t, na.rm = TRUE))),
  as.data.frame(
    bd %>% 
      dcast(gcausa + vcausa ~ asis + tip_asis + sexo , sum, value.var = "t")), by = c("gcausa", "vcausa")) %>%   
adorn_totals()

# Cuadro No. 3.2.4  Defunciones fetales, por lugar de residencia habitual de la madre según grupos de edad de la madre y sexo del feto Año 2024

Cuadro.3.2.4 <- left_join(
  as.data.frame(
    bd %>% 
      group_by(prov_res) %>% 
      filter(anio_fall == 2024) %>% 
      summarise(
        total = sum(t, na.rm = TRUE))),
  as.data.frame(
    bd %>% 
      dcast(prov_res ~ edadmad, sum, value.var = "t")), by = c("prov_res")) %>% 
  adorn_totals()

# Cuadro No. 3.2.5  Defunciones fetales, por lugar de fallecimiento y tipo de asistencia Año 2024

Cuadro.3.2.5 <- left_join(
  as.data.frame(
    bd %>% 
      group_by(prov_fall) %>% 
      filter(anio_fall == 2024) %>% 
      summarise(
        total = sum(t, na.rm = TRUE))),
  as.data.frame(
    bd %>% 
      dcast(prov_fall ~ asis_por, sum, value.var = "t")), by = c("prov_fall")) %>% 
  adorn_totals()


# Cuadro No. 3.2.6 Defunciones fetales, por provincia de residencia y lugar de ocurrencia Año 2024

Cuadro.3.2.6 <- left_join(
  as.data.frame(
    bd %>% 
      group_by(prov_res) %>% 
      filter(anio_fall == 2024) %>% 
      summarise(
        total = sum(t, na.rm = TRUE))),
  as.data.frame(
    bd %>% 
      dcast(prov_res ~ lugar_ocur, sum, value.var = "t")), by = c("prov_res")) %>% 
  adorn_totals()

# Cuadro No. 3.2.7 Defunciones fetales, por provincia de residencia y lugar de ocurrencia Año 2024

Cuadro.3.2.7 <- left_join(
  as.data.frame(
    bd %>% 
      group_by(prov_res, cant_res) %>% 
      filter(anio_fall == 2024) %>% 
      summarise(
        total = sum(t, na.rm = TRUE))),
  as.data.frame(
    bd %>% 
      dcast(prov_res  + cant_res ~ etnia, sum, value.var = "t")), by = c("prov_res", "cant_res")) %>% 
  adorn_totals()

# Cuadro No. 3.2.8 Defunciones fetales, por provincia de residencia y lugar de ocurrencia Año 2024

Cuadro.3.2.8 <- left_join(
  as.data.frame(
    bd %>% 
      group_by(prov_res, cant_res) %>% 
      filter(anio_fall == 2024) %>% 
      summarise(
        total = sum(t, na.rm = TRUE))),
  as.data.frame(
    bd %>% 
      dcast(prov_res  + cant_res ~ est_civil, sum, value.var = "t")), by = c("prov_res", "cant_res")) %>% 
  adorn_totals()


# Mapa No. 4.2.1 Mapa de razón de muertes fetales segun proivincia habitual de madre Año 2024

Cuadro.4.2.1 <- left_join(
  as.data.frame(
    bd %>% 
      group_by(prov_res, proy) %>% 
      filter(anio_fall == 2024) %>% 
      summarise(
        total = sum(t, na.rm = TRUE))),
  as.data.frame(
    bd %>% 
      dcast( prov_res + proy ~ sexo, sum, value.var = "t")), by = c( "prov_res", "proy")) %>% 
  mutate(TOTAL_POR_SEXO = (Hombre + Mujer))  %>%
  select(prov_res, proy, TOTAL_POR_SEXO, everything(), -total, -Indeterminado) %>% 
  mutate(TOTAL_IND = ((TOTAL_POR_SEXO / proy)*1000))  %>%
  select(prov_res, proy, TOTAL_POR_SEXO, TOTAL_IND, everything()) %>% 
  adorn_totals()


