#==============================================================================*
  
# TÍTULO DE LA SINTAXIS:
# Sintaxis de Tabulados 
# OPERACIÓN ESTADÍSTICA:
# Nacidos Vivos, Año 2024 (ENV - 2024)
# UNIDAD TÉCNICA RESPONSABLE:
# Gestión de Estadísticas Sociodemográficas en Base a Registros Administrativos
# Dirección Estadísticas Sociodemográficas (DIES) 
# ENTIDAD EJECUTORA:
# Instituto Nacional de Estadística y Censos (INEC) 

#==============================================================================*

# Fecha última modificación:Junio de 2025

#==============================================================================*

# Elaborado por:
# Gestión de Estadísticas Sociodemográficas en Base a Registros Administrativos (GESRA) 
# Instituto Nacional de Estadística y Censos (INEC)

#==============================================================================*

# Revisado por: 
# Jefe de la Gestión de Estadísticas Sociodemográficas en Base a Registros Administrativos (GESRA) 
# Responsable de la Gestión de Estadísticas Sociodemográficas en Base a Registros Administrativos (GESRA) 
# Instituto Nacional de Estadística y Censos (INEC)

#==============================================================================*
#Sintaxis de Tabulados Nacidos Vivos, Año 2024 (ENV - 2024)
#==============================================================================*

#Indicaciones.

#1- Descargue la Carpeta Base de datos periodo vigente, convierta la base de SPSS en un archivo xlsx
#2- Cree una carpeta llamada ENV 2024 en el cualquier disco local.

# Limpiamos la consola (área de trabajo)

rm(list = ls())  

# Instalamos los paquetes "rio" y "tidyverse" en caso de no tenerlos

install.packages("rio")
install.packages("tidyverse")
install.packages("expss")
install.packages("dplyr")
install.packages("tables")
install.packages("car")
install.packages("carData")

library(rio)
library(tidyverse)
library(expss)
library(dplyr)
library(tables)
library(car)
library(carData)


# CREAMOS LA CAPETA ENV 2024

# Colocamos la ruta de la dirección en donde se encuentra la carpeta con la que vamos a trabajar

setwd("XXXX/ENV 2024")
dir()


# Cargamos la base de datos y la guardamos en el objeto bd

bd <- import("ENV_2024.sav")

# Formato de Variables

as.character(bd$prov_insc)
as.character(bd$cant_insc)
as.character(bd$parr_insc)
as.numeric(bd$anio_insc)
as.numeric(bd$mes_insc)
as.numeric(bd$dia_insc)
as.character(bd$fecha_insc)
as.numeric(bd$sexo)
as.numeric(bd$anio_nac)
as.numeric(bd$mes_nac)
as.numeric(bd$dia_nac)
as.character(bd$fecha_nac)
as.numeric(bd$talla)
as.numeric(bd$peso)
as.numeric(bd$sem_gest)
as.numeric(bd$tipo_part)
as.numeric(bd$apgar1)
as.numeric(bd$apgar5)
as.numeric(bd$p_emb)
as.numeric(bd$lugar_ocur)
as.character(bd$prov_nac)
as.character(bd$cant_nac)
as.character(bd$parr_nac)
as.numeric(bd$area_nac)
as.numeric(bd$asis_por)
as.numeric(bd$nac_mad)
as.character(bd$cod_pais)
as.character(bd$fecha_mad)
as.numeric(bd$anio_mad)
as.numeric(bd$mes_mad)
as.numeric(bd$dia_mad)
as.numeric(bd$edad_mad)
as.numeric(bd$con_pren)
as.numeric(bd$num_emb)
as.numeric(bd$num_par)
as.numeric(bd$hij_viv)
as.numeric(bd$hij_vivm)
as.numeric(bd$hij_nacm)
as.numeric(bd$etnia)
as.numeric(bd$est_civil)
as.numeric(bd$niv_inst)
as.numeric(bd$sabe_leer)
as.character(bd$prov_res)
as.character(bd$cant_res)
as.character(bd$parr_res)
as.numeric(bd$area_res)
as.numeric(bd$residente)

# Etiquetamos las variables

bd<- apply_labels(bd,
                  prov_insc	= "SecA P2 Provincia de inscripción",
                  cant_insc	= "SecA P2 Cantón de inscripción",
                  parr_insc	= "SecA P2 Parroquia de inscripción",
                  anio_insc	= "SecA P3 Año de inscripción",
                  mes_insc	= "SecA P3 Mes de inscripción",
                  dia_insc	= "SecA P3 Día de inscripción",
                  fecha_insc = "SecA P3 Fecha de inscripción",
                  sexo	= "SecA P6 Sexo del nacido vivo",
                  anio_nac	= "SecA P7 Año de nacimiento nacido vivo",
                  mes_nac	= "SecA P7 Mes de nacimiento nacido vivo",
                  dia_nac	= "SecA P7 Día de nacimiento nacido vivo",
                  fecha_nac	= "SecA P7 Fecha de nacimiento nacido vivo",
                  talla	= "SecA P8 Talla del nacido vivo",
                  peso	= "SecA P9 Peso del nacido vivo",
                  sem_gest	= "SecA P10 Semanas de gestación",
                  tipo_part	= "SecA P11 Tipo de parto",
                  apgar1	= "SecA P12 Apgar al minuto",
                  apgar5	= "SecA P12 Apgar a los 5 minutos",
                  p_emb	= "SecA P13 Producto del embarazo",
                  lugar_ocur	= "SecA P14 Lugar de ocurrencia",
                  prov_nac	= "SecA P14.2 Provincia de nacimiento",
                  cant_nac	= "SecA P14.3 Cantón de nacimiento",
                  parr_nac	= "SecA P14.4 Parroquia de nacimiento",
                  area_nac	= "SecA P14.5 Area de nacimiento",
                  asis_por	= "SecA P16 Asistido por",
                  nac_mad	= "SecB P26 Nacionalidad de la madre",
                  cod_pais	= "SecB P26 Código del país",
                  fecha_mad	= "SecB P27 Fecha de nacimiento de la madre",
                  anio_mad	= "SecB P27 Año de nacimiento de la madre",
                  mes_mad	= "SecB P27 Mes de nacimiento de la madre",
                  dia_mad	= "SecB P27 Día de nacimiento de la madre",
                  edad_mad	= "SecB P28 Edad de la madre",
                  con_pren	= "SecB P29 ¿Cuántos controles prenatales recibió en este embarazo?",
                  num_emb	= "SecB P30.1 Número de embarazos 	"	,
                  num_par	= "SecB P30.2 Número de parto",
                  hij_viv	= "SecB P31 ¿Cuántos hijos vivos tiene actualmente",
                  hij_vivm	= "SecB P32 ¿Cuántos hijos que nacieron vivos han muerto?",
                  hij_nacm	= "SecB P33 ¿Cuántos hijos nacieron muertos?",
                  etnia	= "SecB P34 Autoidentificación étnica de la madre",
                  est_civil	= "SecB P35 Estado civil y/o conyugal de la madre",
                  niv_inst	= "SecB P36.1 Nivel de instrucción alcanzado",
                  sabe_leer	= "SecB P36.2 ¿Sabe leer y escribir?",
                  prov_res	= "SecB P37.1 Provincia de residencia habitual de la madre",
                  cant_res	= "SecB P37.2 Cantón de residencia habitual de la madre",
                  parr_res	= "SecB P37.3 Parroquia de residencia habitual de la madre",
                  area_res	= "SecB P37 Area de residencia habitual de la madre",
                  residente	= "SecB P37 Es residente habitual")

# SINTAXIS TABULADOS Nacidos Vivos 2024 

# Para la creación de Tabulados debemos instalar los siguientes paquetes: 
                  

# Cuadro No. 1.3.1 
# Nacidos Vivos,según lugar de residencia y estado civil de la madre

# Crear la variable reg_res para clasificar a las provincias en regiones del Ecuador

bd<- bd %>%
  mutate(reg_res = if_else(anio_nac == 2024 & (prov_res >= "01" & prov_res <= "06"), 1, 0),
         reg_res = if_else(anio_nac == 2024 & (prov_res >= "10" & prov_res <= "11"), 1, reg_res),
         reg_res = if_else(anio_nac == 2024 & (prov_res >= "17" & prov_res <= "18"), 1, reg_res),
         reg_res = if_else(anio_nac == 2024 & (prov_res == "23"), 1, reg_res),
         reg_res = if_else(anio_nac == 2024 & (prov_res >= "07" & prov_res <= "09"), 2, reg_res),
         reg_res = if_else(anio_nac == 2024 & (prov_res >= "12" & prov_res <= "13"), 2, reg_res),
         reg_res = if_else(anio_nac == 2024 & (prov_res == "24"), 2, reg_res),
         reg_res = if_else(anio_nac == 2024 & (prov_res >= "14" & prov_res <= "16"), 3, reg_res),
         reg_res = if_else(anio_nac == 2024 & (prov_res == "19"), 3, reg_res),
         reg_res = if_else(anio_nac == 2024 & (prov_res >= "21" & prov_res <= "22"), 3, reg_res),
         reg_res = if_else(anio_nac == 2024 & (prov_res == "20"), 4, reg_res),
         reg_res = if_else(anio_nac == 2024 & (prov_res == "90"), 5, reg_res),
         reg_res = if_else(anio_nac == 2024 & (prov_res == "88"), 6, reg_res))

bd <- apply_labels(bd, reg_res = "Regiones del Ecuador")

as.numeric(bd$reg_res)

# Asignar categorías de valor a la variable reg_res

bd$reg_res = factor(bd$reg_res,
                    levels = c(1, 2,
                               3, 4,
                               5, 6),
                    labels = c("Región Sierra:", "Región Costa:",
                               "Región Amazónica:", "Región Insular:",
                               "Exterior:"),
                    ordered = FALSE)

# Creamos la variable t para determinar el Total Nacional

bd <- bd %>% mutate(t = if_else(anio_nac == 2024, 1, 0))

bd <- apply_labels(bd, t="Total Nacional")

as.numeric(bd$t)

# Provincia de residencia habitual de la madre

bd$prov_res = factor(bd$prov_res,
                     levels = c("01", "02", "03", "04", "05", "06", "07", "08", "09",
                                "10", "11", "12", "13", "14", "15", "16", "17", "18",
                                "19", "20", "21", "22", "23", "24", "90"),
                     labels = c("AZUAY", "BOLÍVAR", "CAÑAR", "CARCHI",
                                "COTOPAXI", "CHIMBORAZO", "EL ORO",
                                "ESMERALDAS", "GUAYAS", "IMBABURA",
                                "LOJA", "LOS RÍOS", "MANABÍ", "MORONA SANTIAGO",
                                "NAPO", "PASTAZA", "PICHINCHA", "TUNGURAHUA",
                                "ZAMORA CHINCHIPE", "GALÁPAGOS", "SUCUMBÍOS",
                                "ORELLANA", "SANTO DOMINGO DE LOS TSÁCHILAS",
                                "SANTA ELENA", "ZONA NO DELIMITADA"),
                     ordered = FALSE)

# Tabulados

tabla1.3.1 <- tabular(
  (`Región Sierra:`= bd$reg_res == "Región Sierra:") +
    (`Azuay`= bd$prov_res == "AZUAY") +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") +
    (`Cañar`= bd$prov_res == "CAÑAR") +
    (`Carchi`= bd$prov_res == "CARCHI") +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") +
    (`Imbabura`= bd$prov_res == "IMBABURA") +
    (`Loja`= bd$prov_res == "LOJA") +
    (`Pichincha`= bd$prov_res == "PICHINCHA") +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") +
    (`El Oro`= bd$prov_res == "EL ORO") +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS") +
    (`Guayas`= bd$prov_res == "GUAYAS") +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") +
    (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") +
    (`Napo`= bd$prov_res == "NAPO") +
    (`Pastaza`= bd$prov_res == "PASTAZA") +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") +
    (`Orellana`= bd$prov_res == "ORELLANA") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") +
    (`Exterior:`= bd$reg_res == "Exterior:") ~
    (
    (`Total Nacional`= bd$t) * (sum)
  ),
  data = bd) 

print(tabla1.3.1)

write.csv.tabular(tabla1.3.1, file = "Tabla 1.3.1.csv")
 
# Cuadro No. 1.3.2 
# Nacidos Vivos, por sexo, según región y provincia de residencia habitual de la madre 

# Categorías por sexo

bd$sexo = factor(bd$sexo,
                 levels = c(1, 2),
                 labels = c("Hombre", "Mujer"),
                 ordered = FALSE)

# Tabulado

tabla1.3.2 <- tabular(
  (`Región Sierra:`= bd$reg_res == "Región Sierra:") +
    (`Azuay`= bd$prov_res == "AZUAY") +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") +
    (`Cañar`= bd$prov_res == "CAÑAR") +
    (`Carchi`= bd$prov_res == "CARCHI") +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") +
    (`Imbabura`= bd$prov_res == "IMBABURA") +
    (`Loja`= bd$prov_res == "LOJA") +
    (`Pichincha`= bd$prov_res == "PICHINCHA") +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") +
    (`El Oro`= bd$prov_res == "EL ORO") +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS") +
    (`Guayas`= bd$prov_res == "GUAYAS") +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") +
    (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") +
    (`Napo`= bd$prov_res == "NAPO") +
    (`Pastaza`= bd$prov_res == "PASTAZA") +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") +
    (`Orellana`= bd$prov_res == "ORELLANA") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") +
    (`Exterior:`= bd$reg_res == "Exterior:") ~
    (
      ((`Total Nacional`= bd$t) * (sum)) +
        ((`Total Nacional`= bd$t) * (sum) * (`Hombre`= bd$sexo == "Hombre")) +
        ((`Total Nacional`= bd$t) * (sum) * (`Mujer`= bd$sexo == "Mujer"))
    ),
  data = bd)  

print(tabla1.3.2)

write.csv.tabular(tabla1.3.2, file = "Tabla 1.3.2.csv")

# Cuadro No. 1.3.3 
# Nacidos Vivos, y tasa de natalidad por grupos de edad de la madre 

# Crear la variable grupoedad para clasificar la edad de la madre 

bd <- bd %>%
  mutate(grupoedad = if_else(anio_nac == 2024 & (edad_mad >= "10" & edad_mad <= "14"), 1, 0),
         grupoedad = if_else(anio_nac == 2024 & (edad_mad >= "15" & edad_mad <= "19"), 2, grupoedad),
         grupoedad = if_else(anio_nac == 2024 & (edad_mad >= "20" & edad_mad <= "24"), 3, grupoedad),
         grupoedad = if_else(anio_nac == 2024 & (edad_mad >= "25" & edad_mad <= "29"), 4, grupoedad),
         grupoedad = if_else(anio_nac == 2024 & (edad_mad >= "30" & edad_mad <= "34"), 5, grupoedad),
         grupoedad = if_else(anio_nac == 2024 & (edad_mad >= "35" & edad_mad <= "39"), 6, grupoedad),
         grupoedad = if_else(anio_nac == 2024 & (edad_mad >= "40" & edad_mad <= "44"), 7, grupoedad),
         grupoedad = if_else(anio_nac == 2024 & (edad_mad >= "45" & edad_mad <= "49"), 8, grupoedad),
         grupoedad = if_else(anio_nac == 2024 & (edad_mad >= "50") & (edad_mad != "99"), 9, grupoedad),
         grupoedad = if_else(anio_nac == 2024 & (edad_mad == "99"), 10, grupoedad))

bd <- apply_labels(bd, grupoedad = "Edad de la Madre")

as.numeric(bd$grupoedad)

# Asignar categorías a grupos de edad de la madre

bd$grupoedad = factor(bd$grupoedad,
                    levels = c(1, 2, 3, 4,
                               5, 6, 7, 8,
                               9, 10),
                    labels = c("Menores a 15 años:", "15 - 19 años:", "20 - 24 años:", "25 - 29 años:",
                               "30 - 34 años:", "35 - 39 años:", "40 - 44 años:", "45 - 49 años:",
                               "Mayores a 50 años:", "Sin información:"),
                    ordered = FALSE)

resultados <- as.data.frame(table(bd$grupoedad))

#Tabulado

tabla1.3.3 <- transform(resultados,
                        Porcentajes = round(prop.table(resultados$Freq) * 100,1),
                        Porcentajes_Validos = round(prop.table(resultados$Freq) * 100,1),
                        Porcenajes_Acumulados = round(cumsum(prop.table(resultados$Freq)) * 100,1))

print(tabla1.3.3)

write.csv.tabular(tabla1.3.3, file = "Tabla 1.3.3.csv")

# Cuadro No. 2.1.1 

resul <- as.data.frame(table(bd$reg_res))

tabla2.1.1 <- transform(resul,
                        Porcentajes = round(prop.table(resul$Freq) * 100,1),
                        Porcentajes_Validos = round(prop.table(resul$Freq) * 100,1),
                        Porcenajes_Acumulados = round(cumsum(prop.table(resul$Freq)) * 100,1))

print(tabla2.1.1)

write.csv.tabular(tabla2.1.1, file = "Tabla 2.1.1.csv")

# Cuadro No. 2.1.2
# Nacidos vivos en el año 2024 por grupos de edad de la madre, según región de residencia habitual

# Crear la variable asis para clasificar por tipo de asistencia medica

bd <- bd %>%
  mutate(asis = if_else(anio_nac == 2024 & ((asis_por >= 1 & asis_por <= 3) | asis_por == 5), 1, 0),
         asis = if_else(anio_nac == 2024 & (asis_por == 4 | (asis_por >=6 & asis_por <= 7)), 2, asis),
         asis = if_else(anio_nac == 2024 & (asis_por == 9), 3, asis))

bd <- apply_labels(bd, asis = "tipo de asistencia")

as.numeric(bd$asis)

# Asignar categorías al tipo de asistencia

bd$asis = factor(bd$asis,
                      levels = c(1, 2, 3),
                      labels = c("Con asistencia profesional", "Sin asistencia profesional", "Sin información"),
                      ordered = FALSE)

# Área de residencia habitual de la madre

bd$area_res = factor(bd$area_res,
                     levels = c(1, 2),
                     labels = c("Urbano", "Rural"),
                     ordered = FALSE)

# Tabular

tabla2.1.2 <- tabular(
  (`Región`= bd$reg_res) ~ 
    (
      (`Total`= bd$t) +
        (`Con asistencia profesional`= bd$asis == "Con asistencia profesional") +
        (`Sin asistencia profesional`= bd$asis == "Sin asistencia profesional") +
        (`Sin Informacion`= bd$asis == "Sin información") +
        ((`Total`= bd$t) & (`Urbana`= bd$area_res == "Urbano")) +
        (`Urbana`= bd$area_res == "Urbano") * (`Con asistencia profesional`= bd$asis == "Con asistencia profesiona:") +
        (`Urbana`= bd$area_res == "Urbano") * (`Sin asistencia profesional`= bd$asis == "Sin asistencia profesiona:") +
        (`Urbana`= bd$area_res == "Urbano") * (`Sin Informacion`= bd$asis == "Sin información") +
        ((`Total`= bd$t) & (`Rural`= bd$area_res == "Rural")) +
        (`Rural`= bd$area_res == "Rural") * (`Con asistencia profesional`= bd$asis == "Con asistencia profesiona:") +
        (`Rural`= bd$area_res == "Rural") * (`Sin asistencia profesional`= bd$asis == "Sin asistencia profesiona:") +
        (`Rural`= bd$area_res == "Rural") * (`Sin Informacion`= bd$asis == "Sin información")
      ),
  data = bd)

print(tabla2.1.2)

write.csv.tabular(tabla2.1.2, file = "Tabla 2.1.2.csv")

# Cuadro No. 2.1.3
# Nacidos vivos en el año 2024 por grupos de edad de la madre,según región de residencia habitual de la madre 

# Tabulado

tabla2.1.3 <- as.data.frame(bd %>%
                              group_by(reg_res, grupoedad) %>% 
                              summarise(total = sum(t, na.rm = TRUE)) %>%
                              pivot_wider(names_from = grupoedad, values_from = total, values_fill = 0))

print(tabla2.1.3)

rio::export(list("2.1.3" = tabla2.1.3),"D:/Nacidos y Defunciones/ENV 2024/tabla 2.1.3.csv")

# Cuadro No. 2.1.4
# Nacidos vivos en el año 2024 según nivel de instrucción de la madre y tipo de asistencia profesional

# Nivel de instrucción

bd$niv_inst = factor(bd$niv_inst,
                     levels = c(0, 1, 2,
                                3, 4, 5,
                                6, 7, 8,
                                9),
                     labels = c("Ninguno", "Centro de alfabetización", "Primaria",
                                "Educación Básica", "Secundaria", "Educación media/Bachillerato",
                                "Superior no universitaria", "Superior universitaria", "Postgrado",
                                "Sin información"),
                     ordered = FALSE)

# Tabular

tabla2.1.4 <- as.data.frame(bd %>%
                              dcast(niv_inst ~ asis, sum, value.var = "t"))

print(tabla2.1.4)

rio::export(list("2.1.4" = tabla2.1.4),"D:/Nacidos y Defunciones/ENV 2024/tabla 2.1.4.csv")

# Cuadro No. 3.1.1
# Nacidos Vivos, por Áreas y Sexo, según región y provincia de Residencia Habitual de la Madre 

# Tabulado

tabla3.1.1 <- tabular(
  (`Región Sierra:`= bd$reg_res == "Región Sierra:") +
    (`Azuay`= bd$prov_res == "AZUAY") +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") +
    (`Cañar`= bd$prov_res == "CAÑAR") +
    (`Carchi`= bd$prov_res == "CARCHI") +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") +
    (`Imbabura`= bd$prov_res == "IMBABURA") +
    (`Loja`= bd$prov_res == "LOJA") +
    (`Pichincha`= bd$prov_res == "PICHINCHA") +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") +
    (`El Oro`= bd$prov_res == "EL ORO") +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS") +
    (`Guayas`= bd$prov_res == "GUAYAS") +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") +
    (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") +
    (`Napo`= bd$prov_res == "NAPO") +
    (`Pastaza`= bd$prov_res == "PASTAZA") +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") +
    (`Orellana`= bd$prov_res == "ORELLANA") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") +
    (`Exterior:`= bd$reg_res == "Exterior:") ~
    (
      (`Total`= bd$t) * (sum) +
        (`Total`= bd$t) * (sum) * (`Hombre`= bd$sexo == "Hombre") +
        (`Total`= bd$t) * (sum) * (`Mujer`= bd$sexo == "Mujer") +
        ((`Total`= bd$t) & (`Urbana`= bd$area_res == "Urbano")) +
        (`Urbana`= bd$area_res == "Urbano") * (`Total`= bd$t) * (sum) * (`Hombre`= bd$sexo == "Hombre") +
        (`Urbana`= bd$area_res == "Urbano") * (`Total`= bd$t) * (sum) * (`Mujer`= bd$sexo == "Mujer") +
        ((`Total`= bd$t) & (`Rural`= bd$area_res == "Rural")) +
        (`Rural`= bd$area_res == "Rural") * (`Total`= bd$t) * (sum) * (`Hombre`= bd$sexo == "Hombre") +
        (`Rural`= bd$area_res == "Rural") * (`Total`= bd$t) * (sum) * (`Mujer`= bd$sexo == "Mujer")
    ),
  data = bd)

print(tabla3.1.1)

write.csv.tabular(tabla3.1.1, file = "Tabla 3.1.1.csv")

# Cuadro No. 3.1.2 
# Nacidos Vivos, por Áreas y Tipo de Asistencia, según región y provincia de Residencia Habitual de la Madre
# Tabulado

tabla3.1.2 <- tabular(
  (`Región Sierra:`= bd$reg_res == "Región Sierra:") +
    (`Azuay`= bd$prov_res == "AZUAY") +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") +
    (`Cañar`= bd$prov_res == "CAÑAR") +
    (`Carchi`= bd$prov_res == "CARCHI") +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") +
    (`Imbabura`= bd$prov_res == "IMBABURA") +
    (`Loja`= bd$prov_res == "LOJA") +
    (`Pichincha`= bd$prov_res == "PICHINCHA") +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") +
    (`El Oro`= bd$prov_res == "EL ORO") +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS") +
    (`Guayas`= bd$prov_res == "GUAYAS") +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") +
    (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") +
    (`Napo`= bd$prov_res == "NAPO") +
    (`Pastaza`= bd$prov_res == "PASTAZA") +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") +
    (`Orellana`= bd$prov_res == "ORELLANA") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") +
    (`Exterior:`= bd$reg_res == "Exterior:") ~
    (
      (`Total`= bd$t) * (sum) +
        (`Total`= bd$t) * (sum) * (`Con asistencia profesional`= bd$asis == "Con asistencia profesiona:") +
        (`Total`= bd$t) * (sum) * (`Sin asistencia profesional`= bd$asis == "Sin asistencia profesiona:") +
        (`Sin Informacion`= bd$asis == "Sin información:") +
        ((`Total`= bd$t) & (`Urbana`= bd$area_res == "Urbano")) +
        (`Urbana`= bd$area_res == "Urbano") * (`Total`= bd$t) * (sum) * (`Con asistencia profesional`= bd$asis == "Con asistencia profesiona:") +
        (`Urbana`= bd$area_res == "Urbano") * (`Total`= bd$t) * (sum) * (`Sin asistencia profesional`= bd$asis == "Sin asistencia profesiona:") +
        (`Urbana`= bd$area_res == "Urbano") * (`Total`= bd$t) * (sum) * (`Sin Informacion`= bd$asis == "Sin información:") +
        ((`Total`= bd$t) & (`Rural`= bd$area_res == "Rural")) +
        (`Rural`= bd$area_res == "Rural") * (`Total`= bd$t) * (sum) * (`Con asistencia profesional`= bd$asis == "Con asistencia profesiona:") +
        (`Rural`= bd$area_res == "Rural") * (`Total`= bd$t) * (sum) * (`Sin asistencia profesional`= bd$asis == "Sin asistencia profesiona:") +
        (`Rural`= bd$area_res == "Rural") * (`Total`= bd$t) * (sum) * (`Sin Informacion`= bd$asis == "Sin información:")
    ),
  data = bd)

print(tabla3.1.2)

write.csv.tabular(tabla3.1.2, file = "Tabla 3.1.2.csv")

# Cuadro No. 3.1.3
# Nacidos Vivos, por Áreas y Tipo de Asistencia, según región, provincia y Cantones de Residencia Habitual de la Madre

# Asignación de los cantones

bd$cant_res = factor(bd$cant_res,
                     levels = c("0101", "0102", "0103", "0104", "0105", "0106", "0107", "0108", "0109", "0110", "0111", "0112", "0113", "0114", "0115", "0201", "0202", "0203", "0204", "0205",
                                "0206", "0207", "0301", "0302", "0303", "0304", "0305", "0306", "0307", "0401", "0402", "0403", "0404", "0405", "0406", "0501", "0502", "0503", "0504",
                                "0505", "0506", "0507", "0601", "0602", "0603", "0604", "0605", "0606", "0607", "0608", "0609", "0610", "0701", "0702", "0703", "0704", "0705", "0706",
                                "0707", "0708", "0709", "0710", "0711", "0712", "0713", "0714", "0801", "0802", "0803", "0804", "0805", "0806", "0807", "0901", "0902", "0903", "0904",
                                "0905", "0906", "0907", "0908", "0909", "0910", "0911", "0912", "0913", "0914", "0915", "0916", "0917", "0918", "0919", "0920", "0921", "0922", "0923",
                                "0924", "0925", "0926", "0927", "0928", "1001", "1002", "1003", "1004", "1005", "1006", "1101", "1102", "1103", "1104", "1105", "1106", "1107", "1108",
                                "1109", "1110", "1111", "1112", "1113", "1114", "1115", "1116", "1201", "1202", "1203", "1204", "1205", "1206", "1207", "1208", "1209", "1210", "1211",
                                "1212", "1213", "1301", "1302", "1303", "1304", "1305", "1306", "1307", "1308", "1309", "1310", "1311", "1312", "1313", "1314", "1315", "1316", "1317",
                                "1318", "1319", "1320", "1321", "1322", "1401", "1402", "1403", "1404", "1405", "1406", "1407", "1408", "1409", "1410", "1411", "1412", "1501", "1502",
                                "1503", "1504", "1505", "1506", "1507", "1508", "1509", "1601", "1602", "1603", "1604", "1701", "1702", "1703", "1704", "1705", "1706", "1707", "1708",
                                "1709", "1801", "1802", "1803", "1804", "1805", "1806", "1807", "1808", "1809", "1901", "1902", "1903", "1904", "1905", "1906", "1907", "1908", "1909", 
                                "2001", "2002", "2003", "2101", "2102", "2103", "2104", "2105", "2106", "2107", "2201", "2202", "2203", "2204", "2301", "2302", "2401", "2402", "2403",
                                "8800", "9001", "9003", "9004"),
                     labels = c("Cuenca", "Girón", "Gualaceo", "Nabón", "Paute", "Pucará", "San Fernando", "Santa Isabel", "Sigsig", "Oña", "Chordeleg", "El Pan", "Sevilla de Oro", "Guachapala",
                                "Camilo Ponce Enríquez", "Guaranda", "Chillanes", "Chimbo", "Echeandía", "San Miguel", "Caluma", "Las Naves", "Azogues", "Biblián", "Cañar", "La Troncal", "El Tambo",
                                "Deleg", "Suscal", "Tulcán", "Bolívar", "Espejo", "Mira", "Montúfar", "San Pedro de Huaca", "Latacunga", "La Maná", "Pangua", "Pujilí", "Salcedo", "Saquisilí",
                                "Sigchos", "Riobamba", "Alausí", "Colta", "Chambo", "Chunchi", "Guamote", "Guano", "Pallatanga", "Penipe", "Cumandá", "Machala", "Arenillas", "Atahualpa", "Balsas",
                                "Chilla", "El Guabo", "Huaquillas", "Marcabelí", "Pasaje", "Piñas", "Portovelo", "Santa Rosa", "Zaruma", "Las Lajas", "Esmeraldas", "Eloy Alfaro", "Muisne", "Quinindé",
                                "San Lorenzo", "Atacames", "Rioverde", "Guayaquil", "Alfredo Baquerizo Moreno (Juján)", "Balao", "Balzar", "Colimes", "Daule", "Durán", "El Empalme", "El Triunfo", 
                                "Milagro", "Naranjal", "Naranjito", "Palestina", "Pedro Carbo", "Salinas", "Samborondón", "Santa Elena", "Santa Lucía", "Salitre (Urbina Jado)", "San Jacinto de Yaguachi",
                                "Playas", "Simón Bolívar", "Coronel Marcelino Maridueña", "Lomas de Sargentillo", "Nobol", "La Libertad", "General Antonio Elizalde (Bucay)", "Isidro Ayora", "Ibarra",
                                "Antonio Ante", "Cotacachi", "Otavalo", "Pimampiro", "San Miguel de Urcuquí", "Loja", "Calvas", "Catamayo", "Celica", "Chaguarpamba", "Espíndola", "Gonzanamí", "Macará",
                                "Paltas", "Puyango", "Saraguro", "Sozoranga", "Zapotillo", "Pindal", "Quilanga", "Olmedo", "Babahoyo", "Baba", "Montalvo", "Puebloviejo", "Quevedo", "Urdaneta", 
                                "Ventanas", "Vinces", "Palenque", "Buena Fe", "Valencia", "Mocache", "Quinsaloma", "Portoviejo", "Bolívar", "Chone", "El Carmen", "Flavio Alfaro", "Jipijapa", "Junin",
                                "Manta",  "Montecristi", "Paján", "Pichincha", "Rocafuerte", "Santa Ana", "Sucre", "Tosagua", "24 de Mayo", "Pedernales", "Olmedo", "Puerto López", "Jama", "Jaramijo", 
                                "San Vicente", "Morona", "Gualaquiza", "Limon Indanza", "Palora", "Santiago", "Sucua", "Huamboya", "San Juan Bosco", "Taisha", "Logroño", "Pablo Sexto", "Tiwintza",
                                "Tena", "Aguarico", "Archidona", "El Chaco", "La Joya de los Sachas", "Orellana", "Quijos", "Loreto", "Carlos Julio Arosemena Tola", "Pastaza", "Mera", "Santa Clara",
                                "Arajuno",  "Quito", "Cayambe", "Mejía", "Pedro Moncayo", "Rumiñahui", "Santo Domingo", "San Miguel de los Bancos", "Pedro Vicente Maldonado", "Puerto Quito", "Ambato",
                                "Baños de Agua Santa", "Cevallos", "Mocha", "Patate", "Quero", "San Pedro de Pelileo", "Santiago de Píllaro", "Tisaleo", "Zamora", "Chinchipe", "Nangaritza", "Yacuambí",
                                "Yantzaza (Yanzatza)", "El Pangui", "Centinela del Cóndor", "Palanda", "Paquisha", "San Cristóbal", "Isabela", "Santa Cruz", "Lago Agrio", "Gonzalo Pizarro", "Putumayo",
                                "Shushufindi", "Sucumbíos", "Cascales", "Cuyabeno", "Orellana", "Aguarico", "La Joya de los Sachas", "Loreto", "Santo Domingo", "La Concordia", "Santa Elena", "La Libertad",
                                "Salinas", "Exterior", "Las Golondrinas", "Manga del Cura", "El Piedrero"),
                     ordered = FALSE)

# Categorias para la variable asis_por

bd$asis_por = factor(bd$asis_por,
                     levels = c(1, 2, 3, 
                                4, 5, 6,
                                7),
                     labels = c("Médico/a", "Obstetriz/Obstetra", "Enfermera/o", 
                                "Auxiliar de enfermería", "Partero/a calificado/a", "Partero/a no calificado/a",
                                "Otro"),
                     ordered = FALSE)

# Tabulado

tabla3.1.3 <- tabular(
  (`Región Sierra:`= bd$reg_res == "Región Sierra:") +
    (`Azuay`= bd$prov_res == "AZUAY") +
    (`Cuenca`= bd$cant_res == "Cuenca") +
    (`Girón`= bd$cant_res == "Girón") +
    (`Gualaceo`= bd$cant_res == "Gualaceo") +
    (`Nabón`= bd$cant_res == "Nabón") +
    (`Paute`= bd$cant_res == "Paute") +
    (`Pucará`= bd$cant_res == "Pucará") +
    (`San Fernando`= bd$cant_res == "San Fernando") +
    (`Santa Isabel`= bd$cant_res == "Santa Isabel") +
    (`Sigsig`= bd$cant_res == "Sigsig") +
    (`Oña`= bd$cant_res == "Oña") +
    (`Chordeleg`= bd$cant_res == "Chordeleg") +
    (`El Pan`= bd$cant_res == "El Pan") + 
    (`Sevilla De Oro`= bd$cant_res == "Sevilla De Oro") +
    (`Guachapala`= bd$cant_res == "Guachapala") +
    (`Camilo Ponce Enríquez`= bd$cant_res == "Camilo Ponce Enríquez") +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") +
    (`Guaranda`= bd$cant_res == "Guaranda") +
    (`Chillanes`= bd$cant_res == "Chillanes") +
    (`Chimbo`= bd$cant_res == "Chimbo") +
    (`Echeandia`= bd$cant_res == "Echeandia") +
    (`San Miguel`= bd$cant_res == "San Miguel") +
    (`Caluma`= bd$cant_res== "Caluma") +
    (`Las Naves`= bd$cant_res == "Las Naves") +
    (`Cañar`= bd$prov_res == "CAÑAR") +
    (`Azogues`= bd$cant_res == "Azogues") +
    (`Biblian`= bd$cant_res == "Biblian") +
    (`Cañar`= bd$cant_res == "Cañar") +
    (`La Troncal`= bd$cant_res == "La Troncal") +
    (`El Tambo`= bd$cant_res == "El Tambo") +
    (`Deleg`= bd$cant_res == "Deleg") +
    (`Suscal`= bd$cant_res == "Suscal") +
    (`Carchi`= bd$prov_res == "CARCHI") +
    (`Tulcán`= bd$cant_res == "Tulcán") +
    (`Bolívar`= bd$cant_res == "Bolívar") * (`Carchi`= bd$prov_res == "CARCHI") +
    (`Espejo`= bd$cant_res == "Espejo") +
    (`Mira`= bd$cant_res == "Mira") +
    (`Montúfar`= bd$cant_res == "Montúfar") +
    (`San Pedro De Huaca`= bd$cant_res == "San Pedro De Huaca") +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") +
    (`Latacunga`= bd$cant_res == "Latacunga") +
    (`La Maná`= bd$cant_res == "La Maná") +
    (`Pangua`= bd$cant_res == "Pangua") +
    (`Pujilí`= bd$cant_res == "Pujilí") +
    (`Salcedo`= bd$cant_res == "Salcedo") +
    (`Saquisilí`= bd$cant_res == "Saquisilí") +
    (`Sigchos`= bd$cant_res == "Sigchos") +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") +
    (`Riobamba`= bd$cant_res == "Riobamba") +
    (`Alausí`= bd$cant_res == "Alausí") +
    (`Colta`= bd$cant_res == "Colta") +
    (`Chambo`= bd$cant_res == "Chambo") +
    (`Chunchi`= bd$cant_res == "Chunchi") +
    (`Guamote`= bd$cant_res == "Guamote") +
    (`Guano`= bd$cant_res == "Guano") +
    (`Pallatanga`= bd$cant_res == "Pallatanga") +
    (`Penípe`= bd$cant_res == "Penípe") +
    (`Cumandá`= bd$cant_res == "Cumandá") +
    (`Imbabura`= bd$prov_res == "IMBABURA") +
    (`Ibarra`= bd$cant_res == "Ibarra") +
    (`Antonio Ante`= bd$cant_res == "Antonio Ante") +
    (`Cotacahi`= bd$cant_res == "Cotacahi") +
    (`Otavalo`= bd$cant_res == "Otavalo") +
    (`Pimampiro`= bd$cant_res == "Pimampiro") +
    (`San Miguel De Urcuqui`= bd$cant_res == "San Miguel De Urcuqui") +
    (`Loja`= bd$prov_res == "LOJA") +
    (`Loja`= bd$cant_res == "Loja") +
    (`Calvas`= bd$cant_res == "Calvas") +
    (`Catamayo`= bd$cant_res == "Catamayo") +
    (`Célica`= bd$cant_res == "Célica") +
    (`Chaguarpamba`= bd$cant_res == "Chaguarpamba") +
    (`Espíndola`= bd$cant_res == "Espíndola") +
    (`Gonzanamá`= bd$cant_res == "Gonzanamá") +
    (`Macará`= bd$cant_res == "Macará") +
    (`Paltas`= bd$cant_res == "Paltas") +
    (`Puyango`= bd$cant_res == "Puyango") +
    (`Saraguro`= bd$cant_res == "Saraguro") +
    (`Sozoranga`= bd$cant_res == "Sozoranga") +
    (`Zapotillo`= bd$cant_res == "Zapotillo") +
    (`Pindal`= bd$cant_res == "Pindal") +
    (`Quilanga`= bd$cant_res == "Quilanga") +
    (`Olemdo`= bd$cant_res == "Olemdo") +
    (`Pichincha`= bd$prov_res == "PICHINCHA") +
    (`Quito`= bd$cant_res == "Quito") +
    (`Cayambe`= bd$cant_res == "Cayambe") +
    (`Mejía`= bd$cant_res == "Mejía") +
    (`Pedro Moncayo`= bd$cant_res == "Pedro Moncayo") +
    (`Rumiñahui`= bd$cant_res == "Rumiñahui") +
    (`San Miguel De Los Bancos`= bd$cant_res == "San Miguel De Los Bancos") +
    (`Pedro Vicente Maldonado`= bd$cant_res == "Pedro Vicente Maldonado") +
    (`Puerto Quito`= bd$cant_res == "Puerto Quito") +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") +
    (`Ambato`= bd$cant_res == "Ambato") +
    (`Baños De Agua Santa`= bd$cant_res == "Baños De Agua Santa") +
    (`Cevallos`= bd$cant_res == "Cevallos") +
    (`Mocha`= bd$cant_res == "Mocha") +
    (`Patate`= bd$cant_res == "Patate") +
    (`Quero`= bd$cant_res == "Quero") +
    (`San Pedro De Pelileo`= bd$cant_res == "San Pedro De Pelileo") +
    (`Santiago De Pillaro`= bd$cant_res == "Santiago De Pillaro") +
    (`Tisaleo`= bd$cant_res == "Tisaleo") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Santo Domingo`= bd$cant_res == "Santo Domingo") +
    (`La Condordia`= bd$cant_res == "La Condordia") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") +
    (`El Oro`= bd$prov_res == "EL ORO") +
    (`Machala`= bd$cant_res == "Machala") +
    (`Arenillas`= bd$cant_res == "Arenillas") +
    (`Atahualpa`= bd$cant_res == "Atahualpa") +
    (`Balsas`= bd$cant_res == "Balsas") +
    (`Chilla`= bd$cant_res == "Chilla") +
    (`El Guabo`= bd$cant_res == "El Guabo") +
    (`Huaquillas`= bd$cant_res == "Huaquillas") +
    (`Marcabelí`= bd$cant_res == "Marcabelí") +
    (`Pasaje`= bd$cant_res == "Pasaje") +
    (`Piñas`= bd$cant_res == "Piñas") +
    (`Portovelo`= bd$cant_res == "Portovelo") +
    (`Santa Rosa`= bd$cant_res == "Santa Rosa") +
    (`Zaruma`= bd$cant_res == "Zaruma") +
    (`Las Lajas`= bd$cant_res == "Las Lajas") +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS") +
    (`Esmeraldas`= bd$cant_res == "Esmeraldas") +
    (`Eloy Alfaro`= bd$cant_res == "Eloy Alfaro") +
    (`Muisne`= bd$cant_res == "Muisne") +
    (`Quininde`= bd$cant_res == "Quininde") +
    (`San Lorenzo`= bd$cant_res == "San Lorenzo") +
    (`Atacames`= bd$cant_res == "Atacames") +
    (`Ríoverde`= bd$cant_res == "Ríoverde") +
    (`Guayas`= bd$prov_res == "GUAYAS") +
    (`Guayaquil`= bd$cant_res == "Guayaquil") +
    (`Alfredo Baquerizo Moreno`= bd$cant_res == "Alfredo Baquerizo Moreno") +
    (`Balao`= bd$cant_res == "Balao") +
    (`Balzar`= bd$cant_res == "Balzar") +
    (`Colimes`= bd$cant_res == "Colimes") +
    (`Daule`= bd$cant_res == "Daule") +
    (`Durán`= bd$cant_res == "Durán") +
    (`Empalme`= bd$cant_res == "Empalme") +
    (`El Triunfo`= bd$cant_res == "El Triunfo") +
    (`Milagro`= bd$cant_res == "Milagro") +
    (`Naranjal`= bd$cant_res == "Naranjal") +
    (`Naranjito`= bd$cant_res == "Naranjito") +
    (`Palestina`= bd$cant_res == "Palestina") +
    (`Pedro Carbo`= bd$cant_res == "Pedro Carbo") +
    (`Samborondón`= bd$cant_res == "Samborondón") +
    (`Santa Lucia`= bd$cant_res == "Santa Lucia") +
    (`Salitre`= bd$cant_res == "Salitre") +
    (`San Jacinto De Yaguachi`= bd$cant_res == "San Jacinto De Yaguachi") +
    (`Playas`= bd$cant_res == "Playas") +
    (`Simón Bolívar`= bd$cant_res == "Simón Bolívar") +
    (`Crnel. Marcelino Maridueña`= bd$cant_res == "Crnel. Marcelino Maridueña") +
    (`Lomas De Sargentillo`= bd$cant_res == "Lomas De Sargentillo") +
    (`Nobol`= bd$cant_res == "Nobol") +
    (`Gnral. Antonio Elizalde`= bd$cant_res == "Gnral. Antonio Elizalde") +
    (`Isidro Ayora`= bd$cant_res == "Isidro Ayora") +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") +
    (`Babahoyo`= bd$cant_res == "Babahoyo") +
    (`Baba`= bd$cant_res == "Baba") +
    (`Montalvo`= bd$cant_res == "Montalvo") +
    (`Puebloviejo`= bd$cant_res == "Puebloviejo") +
    (`Quevedo`= bd$cant_res == "Quevedo") +
    (`Urdaneta`= bd$cant_res == "Urdaneta") +
    (`Ventanas`= bd$cant_res == "Ventanas") +
    (`Vinces`= bd$cant_res == "Vinces") +
    (`Palenque`= bd$cant_res == "Palenque") +
    (`Buena Fé`= bd$cant_res == "Buena Fé") +
    (`Valencia`= bd$cant_res == "Valencia") +
    (`Mocache`= bd$cant_res == "Mocache") +
    (`Quinsaloma`= bd$cant_res == "Quinsaloma") +
    (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Portoviejo`= bd$cant_res == "Portoviejo") +
    (`Bolívar`= bd$cant_res == "Bolívar") * (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Chone`= bd$cant_res == "Chone") +
    (`El Carmen`= bd$cant_res == "El Carmen") +
    (`Flavio Alfaro`= bd$cant_res == "Flavio Alfaro") +
    (`Jipijapa`= bd$cant_res == "Jipijapa") +
    (`Junín`= bd$cant_res == "Junín") +
    (`Manta`= bd$cant_res == "Manta") +
    (`Montecristi`= bd$cant_res == "Montecristi") +
    (`Paján`= bd$cant_res == "Paján") +
    (`Pichincha`= bd$cant_res == "Pichincha") +
    (`Rocafuerte`= bd$cant_res == "Rocafuerte") +
    (`Santa Ana`= bd$cant_res == "Santa Ana") +
    (`Sucre`= bd$cant_res == "Sucre") +
    (`Tosagua`= bd$cant_res == "Tosagua") +
    (`24 De Mayo`= bd$cant_res == "24 De Mayo") +
    (`Pedernales`= bd$cant_res == "Pedernales") +
    (`Olmedo`= bd$cant_res == "Olmedo") +
    (`Puerto López`= bd$cant_res == "Puerto López") +
    (`Jama`= bd$cant_res == "Jama") +
    (`Jaramijó`= bd$cant_res == "Jaramijó") +
    (`San Vicente`= bd$cant_res == "San Vicente") +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") +
    (`Santa Elena`= bd$cant_res == "Santa Elena") +
    (`La Libertad`= bd$cant_res == "La Libertad") +
    (`Salinas`= bd$cant_res == "Salinas") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") +
    (`Morona`= bd$cant_res == "Morona") +
    (`Gualaquiza`= bd$cant_res == "Gualaquiza") +
    (`Limón Indanza`= bd$cant_res == "Limón Indanza") +
    (`Palora`= bd$cant_res == "Palora") +
    (`Santiago`= bd$cant_res == "Santiago") +
    (`Sucúa`= bd$cant_res == "Sucúa") +
    (`Huamboya`= bd$cant_res == "Huamboya") +
    (`San Juan Bosco`= bd$cant_res == "San Juan Bosco") +
    (`Taisha`= bd$cant_res == "Taisha") +
    (`Logroño`= bd$cant_res == "Logroño") +
    (`Pablo Sexto`= bd$cant_res == "Pablo Sexto") +
    (`Tiwintza`= bd$cant_res == "Tiwintza") +
    (`Napo`= bd$prov_res == "NAPO") +
    (`Tena`= bd$cant_res == "Tena") +
    (`Archidona`= bd$cant_res == "Archidona") +
    (`El Chaco`= bd$cant_res == "El Chaco") +
    (`Quijos`= bd$cant_res == "Quijos") +
    (`Carlos Julio Arrosemena Tola`= bd$cant_res == "Carlos Julio Arrosemena Tola") +
    (`Pastaza`= bd$prov_res == "PASTAZA") +
    (`Pastaza`= bd$cant_res == "Pastaza")+
    (`Mera`= bd$cant_res == "Mera")+
    (`Santa Clara`= bd$cant_res == "Santa Clara") +
    (`Arajuno`= bd$cant_res == "Arajuno") +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") +
    (`Zamora`= bd$cant_res == "Zamora") +
    (`Chinchipe`= bd$cant_res == "Chinchipe") +
    (`Nangaritza`= bd$cant_res == "Nangaritza") +
    (`Yacuambi`= bd$cant_res == "Yacuambi") +
    (`Yantzaza`= bd$cant_res == "Yantzaza") +
    (`El Pangui`= bd$cant_res == "El Pangui") +
    (`Centinela Del Cóndor`= bd$cant_res == "Centinela Del Cóndor") +
    (`Palanda`= bd$cant_res == "Palanda") +
    (`Paquisha`= bd$cant_res == "Paquisha") +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") +
    (`Lago Agrio`= bd$cant_res == "Lago Agrio") +
    (`Gonzalo Pizarro`= bd$cant_res == "Gonzalo Pizarro") +
    (`Putumayo`= bd$cant_res == "Putumayo") +
    (`Shushufindi`= bd$cant_res == "Shushufindi") +
    (`Sucumbios`= bd$cant_res == "Sucumbios") +
    (`Cascales`= bd$cant_res == "Cascales") +
    (`Cuyabeno`= bd$cant_res == "Cuyabeno") +
    (`Orellana`= bd$prov_res == "ORELLANA") +
    (`Orellana`= bd$cant_res == "Orellana") +
    (`Aguarico`= bd$cant_res == "Aguarico") +
    (`La Joya De Los Sachas`= bd$cant_res == "La Joya De Los Sachas") +
    (`Loreto`= bd$cant_res == "Loreto") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") +
    (`San Cristobal`= bd$cant_res == "San Cristobal") +
    (`Isabela`= bd$cant_res == "Isabela") +
    (`Santa Cruz`= bd$cant_res == "Santa Cruz") +
    (`Exterior:`= bd$reg_res == "Exterior:") ~
    (
      (`Total`= bd$t) * (sum) +
        (`Total`= bd$t) * (sum) * (`Hombre`= bd$sexo == "Hombre") +
        (`Total`= bd$t) * (sum) * (`Mujer`= bd$sexo == "Mujer") +
        ((`Total`= bd$t) & (`Con asistencia profesional`= bd$asis == "Con asistencia profesiona:")) +
        (`Con asistencia profesional`= bd$asis == "Con asistencia profesiona:") * (`Total`= bd$t) * (sum) * (`Médico/a`= bd$asis_por == "Médico/a") +
        (`Con asistencia profesional`= bd$asis == "Con asistencia profesiona:") * (`Total`= bd$t) * (sum) * (`Obstetriz`= bd$asis_por == "Obstetriz/Obstetra") +
        (`Con asistencia profesional`= bd$asis == "Con asistencia profesiona:") * (`Total`= bd$t) * (sum) * (`Enfermera/o`= bd$asis_por == "Enfermera/o") +
        (`Con asistencia profesional`= bd$asis == "Con asistencia profesiona:") * (`Total`= bd$t) * (sum) * (`Partero/a calificado/a`= bd$asis_por == "Partero/a calificado/a") +
        ((`Total`= bd$t) & (`Sin asistencia profesional`= bd$asis == "Sin asistencia profesiona:")) +
        (`Sin asistencia profesional`= bd$asis == "Sin asistencia profesiona:") * (`Total`= bd$t) * (sum) * (`Auxiliar de enfermería`= bd$asis_por == "Auxiliar de enfermería") +
        (`Sin asistencia profesional`= bd$asis == "Sin asistencia profesiona:") * (`Total`= bd$t) * (sum) * (`Partero/a no calificado/a`= bd$asis_por == "Partero/a no calificado/a") +
        (`Sin asistencia profesional`= bd$asis == "Sin asistencia profesiona:") * (`Total`= bd$t) * (sum) * (`Otro`= bd$asis_por == "Otro") +
        ((`Total`= bd$t) & (`Sin Informacion`= bd$asis == "Sin información:"))
    ),
  data = bd)

print(tabla3.1.3)

write.csv.tabular(tabla3.1.3, file = "Tabla 3.1.3.csv")

# Cuadro No. 3.1.4
# Nacidos Vivos, por Tipo de Atención, de Madre Residente y No Residente, según región, provincia y Cantonces de Nacimiento

# Crear la variable reg_nac para clasificar a las provincias en regiones del Ecuador

bd<- bd %>%
  mutate(reg_nac = if_else(anio_nac == 2024 & (prov_nac >= "01" & prov_nac <= "06"), 1, 0),
         reg_nac = if_else(anio_nac == 2024 & (prov_nac >= "10" & prov_nac <= "11"), 1, reg_nac),
         reg_nac = if_else(anio_nac == 2024 & (prov_nac >= "17" & prov_nac <= "18"), 1, reg_nac),
         reg_nac = if_else(anio_nac == 2024 & (prov_nac == "23"), 1, reg_nac),
         reg_nac = if_else(anio_nac == 2024 & (prov_nac >= "07" & prov_nac <= "09"), 2, reg_nac),
         reg_nac = if_else(anio_nac == 2024 & (prov_nac >= "12" & prov_nac <= "13"), 2, reg_nac),
         reg_nac = if_else(anio_nac == 2024 & (prov_nac == "24"), 2, reg_nac),
         reg_nac = if_else(anio_nac == 2024 & (prov_nac >= "14" & prov_nac <= "16"), 3, reg_nac),
         reg_nac = if_else(anio_nac == 2024 & (prov_nac == "19"), 3, reg_nac),
         reg_nac = if_else(anio_nac == 2024 & (prov_nac >= "21" & prov_nac <= "22"), 3, reg_nac),
         reg_nac = if_else(anio_nac == 2024 & (prov_nac == "20"), 4, reg_nac),
         reg_nac = if_else(anio_nac == 2024 & (prov_nac == "90"), 5, reg_nac),
         reg_nac = if_else(anio_nac == 2024 & (prov_nac == "88"), 6, reg_nac))

bd <- apply_labels(bd, reg_nac = "Regiones del Ecuador Nacidos")

as.numeric(bd$reg_nac)

# Asignar categorías de valor a la variable reg_nac

bd$reg_nac = factor(bd$reg_nac,
                    levels = c(1, 2,
                               3, 4,
                               5, 6),
                    labels = c("Región Sierra", "Región Costa",
                               "Región Amazónica", "Región Insular",
                               "Exterior:"),
                    ordered = FALSE)

# Provincia de nacimiento

bd$prov_nac = factor(bd$prov_nac,
                     levels = c("01", "02", "03", "04", "05", "06", "07", "08", "09",
                                "10", "11", "12", "13", "14", "15", "16", "17", "18",
                                "19", "20", "21", "22", "23", "24", "90"),
                     labels = c("AZUAY", "BOLÍVAR", "CAÑAR", "CARCHI",
                                "COTOPAXI", "CHIMBORAZO", "EL ORO",
                                "ESMERALDAS", "GUAYAS", "IMBABURA",
                                "LOJA", "LOS RÍOS", "MANABÍ", "MORONA SANTIAGO",
                                "NAPO", "PASTAZA", "PICHINCHA", "TUNGURAHUA",
                                "ZAMORA CHINCHIPE", "GALÁPAGOS", "SUCUMBÍOS",
                                "ORELLANA", "SANTO DOMINGO DE LOS TSÁCHILAS",
                                "SANTA ELENA", "ZONA NO DELIMITADA"),
                     ordered = FALSE)

# Asignacion de categorías a los cantones de nacimiento

bd$cant_nac = factor(bd$cant_nac,
                     levels = c("0101", "0102", "0103", "0104", "0105", "0106", "0107", "0108", "0109", "0110", "0111", "0112", "0113", "0114", "0115", "0201", "0202", "0203", "0204", "0205",
                                "0206", "0207", "0301", "0302", "0303", "0304", "0305", "0306", "0307", "0401", "0402", "0403", "0404", "0405", "0406", "0501", "0502", "0503", "0504",
                                "0505", "0506", "0507", "0601", "0602", "0603", "0604", "0605", "0606", "0607", "0608", "0609", "0610", "0701", "0702", "0703", "0704", "0705", "0706",
                                "0707", "0708", "0709", "0710", "0711", "0712", "0713", "0714", "0801", "0802", "0803", "0804", "0805", "0806", "0807", "0901", "0902", "0903", "0904",
                                "0905", "0906", "0907", "0908", "0909", "0910", "0911", "0912", "0913", "0914", "0915", "0916", "0917", "0918", "0919", "0920", "0921", "0922", "0923",
                                "0924", "0925", "0926", "0927", "0928", "1001", "1002", "1003", "1004", "1005", "1006", "1101", "1102", "1103", "1104", "1105", "1106", "1107", "1108",
                                "1109", "1110", "1111", "1112", "1113", "1114", "1115", "1116", "1201", "1202", "1203", "1204", "1205", "1206", "1207", "1208", "1209", "1210", "1211",
                                "1212", "1213", "1301", "1302", "1303", "1304", "1305", "1306", "1307", "1308", "1309", "1310", "1311", "1312", "1313", "1314", "1315", "1316", "1317",
                                "1318", "1319", "1320", "1321", "1322", "1401", "1402", "1403", "1404", "1405", "1406", "1407", "1408", "1409", "1410", "1411", "1412", "1501", "1502",
                                "1503", "1504", "1505", "1506", "1507", "1508", "1509", "1601", "1602", "1603", "1604", "1701", "1702", "1703", "1704", "1705", "1706", "1707", "1708",
                                "1709", "1801", "1802", "1803", "1804", "1805", "1806", "1807", "1808", "1809", "1901", "1902", "1903", "1904", "1905", "1906", "1907", "1908", "1909", 
                                "2001", "2002", "2003", "2101", "2102", "2103", "2104", "2105", "2106", "2107", "2201", "2202", "2203", "2204", "2301", "2302", "2401", "2402", "2403",
                                "8800", "9001", "9003", "9004"),
                     labels = c("Cuenca", "Girón", "Gualaceo", "Nabón", "Paute", "Pucará", "San Fernando", "Santa Isabel", "Sigsig", "Oña", "Chordeleg", "El Pan", "Sevilla de Oro", "Guachapala",
                                "Camilo Ponce Enríquez", "Guaranda", "Chillanes", "Chimbo", "Echeandía", "San Miguel", "Caluma", "Las Naves", "Azogues", "Biblián", "Cañar", "La Troncal", "El Tambo",
                                "Deleg", "Suscal", "Tulcán", "Bolívar", "Espejo", "Mira", "Montúfar", "San Pedro de Huaca", "Latacunga", "La Maná", "Pangua", "Pujilí", "Salcedo", "Saquisilí",
                                "Sigchos", "Riobamba", "Alausí", "Colta", "Chambo", "Chunchi", "Guamote", "Guano", "Pallatanga", "Penipe", "Cumandá", "Machala", "Arenillas", "Atahualpa", "Balsas",
                                "Chilla", "El Guabo", "Huaquillas", "Marcabelí", "Pasaje", "Piñas", "Portovelo", "Santa Rosa", "Zaruma", "Las Lajas", "Esmeraldas", "Eloy Alfaro", "Muisne", "Quinindé",
                                "San Lorenzo", "Atacames", "Rioverde", "Guayaquil", "Alfredo Baquerizo Moreno (Juján)", "Balao", "Balzar", "Colimes", "Daule", "Durán", "El Empalme", "El Triunfo", 
                                "Milagro", "Naranjal", "Naranjito", "Palestina", "Pedro Carbo", "Salinas", "Samborondón", "Santa Elena", "Santa Lucía", "Salitre (Urbina Jado)", "San Jacinto de Yaguachi",
                                "Playas", "Simón Bolívar", "Coronel Marcelino Maridueña", "Lomas de Sargentillo", "Nobol", "La Libertad", "General Antonio Elizalde (Bucay)", "Isidro Ayora", "Ibarra",
                                "Antonio Ante", "Cotacachi", "Otavalo", "Pimampiro", "San Miguel de Urcuquí", "Loja", "Calvas", "Catamayo", "Celica", "Chaguarpamba", "Espíndola", "Gonzanamí", "Macará",
                                "Paltas", "Puyango", "Saraguro", "Sozoranga", "Zapotillo", "Pindal", "Quilanga", "Olmedo", "Babahoyo", "Baba", "Montalvo", "Puebloviejo", "Quevedo", "Urdaneta", 
                                "Ventanas", "Vinces", "Palenque", "Buena Fe", "Valencia", "Mocache", "Quinsaloma", "Portoviejo", "Bolívar", "Chone", "El Carmen", "Flavio Alfaro", "Jipijapa", "Junin",
                                "Manta",  "Montecristi", "Paján", "Pichincha", "Rocafuerte", "Santa Ana", "Sucre", "Tosagua", "24 de Mayo", "Pedernales", "Olmedo", "Puerto López", "Jama", "Jaramijo", 
                                "San Vicente", "Morona", "Gualaquiza", "Limon Indanza", "Palora", "Santiago", "Sucua", "Huamboya", "San Juan Bosco", "Taisha", "Logroño", "Pablo Sexto", "Tiwintza",
                                "Tena", "Aguarico", "Archidona", "El Chaco", "La Joya de los Sachas", "Orellana", "Quijos", "Loreto", "Carlos Julio Arosemena Tola", "Pastaza", "Mera", "Santa Clara",
                                "Arajuno",  "Quito", "Cayambe", "Mejía", "Pedro Moncayo", "Rumiñahui", "Santo Domingo", "San Miguel de los Bancos", "Pedro Vicente Maldonado", "Puerto Quito", "Ambato",
                                "Baños de Agua Santa", "Cevallos", "Mocha", "Patate", "Quero", "San Pedro de Pelileo", "Santiago de Píllaro", "Tisaleo", "Zamora", "Chinchipe", "Nangaritza", "Yacuambí",
                                "Yantzaza (Yanzatza)", "El Pangui", "Centinela del Cóndor", "Palanda", "Paquisha", "San Cristóbal", "Isabela", "Santa Cruz", "Lago Agrio", "Gonzalo Pizarro", "Putumayo",
                                "Shushufindi", "Sucumbíos", "Cascales", "Cuyabeno", "Orellana", "Aguarico", "La Joya de los Sachas", "Loreto", "Santo Domingo", "La Concordia", "Santa Elena", "La Libertad",
                                "Salinas", "Exterior", "Las Golondrinas", "Manga del Cura", "El Piedrero"),
                     ordered = FALSE)

# Asignar categorías de valor a la variable residente

bd$residente = factor(bd$residente,
                    levels = c(1, 2),
                    labels = c("Residente", "No residente"),
                    ordered = FALSE)

# Tabular

tabla3.1.4 <- tabular(
  (`Región Sierra:`= bd$reg_nac == "Región Sierra:") +
    (`Azuay`= bd$prov_nac == "AZUAY") +
    (`Cuenca`= bd$cant_nac == "Cuenca") +
    (`Girón`= bd$cant_nac == "Girón") +
    (`Gualaceo`= bd$cant_nac == "Gualaceo") +
    (`Nabón`= bd$cant_nac == "Nabón") +
    (`Paute`= bd$cant_nac == "Paute") +
    (`Pucará`= bd$cant_nac == "Pucará") +
    (`San Fernando`= bd$cant_nac == "San Fernando") +
    (`Santa Isabel`= bd$cant_nac == "Santa Isabel") +
    (`Sigsig`= bd$cant_nac == "Sigsig") +
    (`Oña`= bd$cant_nac == "Oña") +
    (`Chordeleg`= bd$cant_nac == "Chordeleg") +
    (`El Pan`= bd$cant_nac == "El Pan") + 
    (`Sevilla De Oro`= bd$cant_nac == "Sevilla De Oro") +
    (`Guachapala`= bd$cant_nac == "Guachapala") +
    (`Camilo Ponce Enríquez`= bd$cant_nac == "Camilo Ponce Enríquez") +
    (`Bolívar`= bd$prov_nac == "BOLÍVAR") +
    (`Guaranda`= bd$cant_nac == "Guaranda") +
    (`Chillanes`= bd$cant_nac == "Chillanes") +
    (`Chimbo`= bd$cant_nac == "Chimbo") +
    (`Echeandia`= bd$cant_nac == "Echeandia") +
    (`San Miguel`= bd$cant_nac == "San Miguel") +
    (`Caluma`= bd$cant_nac== "Caluma") +
    (`Las Naves`= bd$cant_nac == "Las Naves") +
    (`Cañar`= bd$prov_nac == "CAÑAR") +
    (`Azogues`= bd$cant_nac == "Azogues") +
    (`Biblian`= bd$cant_nac == "Biblian") +
    (`Cañar`= bd$cant_nac == "Cañar") +
    (`La Troncal`= bd$cant_nac == "La Troncal") +
    (`El Tambo`= bd$cant_nac == "El Tambo") +
    (`Deleg`= bd$cant_nac == "Deleg") +
    (`Suscal`= bd$cant_nac == "Suscal") +
    (`Carchi`= bd$prov_nac == "CARCHI") +
    (`Tulcán`= bd$cant_nac == "Tulcán") +
    (`Bolívar`= bd$cant_nac == "Bolívar") * (`Carchi`= bd$prov_nac == "CARCHI") +
    (`Espejo`= bd$cant_nac == "Espejo") +
    (`Mira`= bd$cant_nac == "Mira") +
    (`Montúfar`= bd$cant_nac == "Montúfar") +
    (`San Pedro De Huaca`= bd$cant_nac == "San Pedro De Huaca") +
    (`Cotopaxi`= bd$prov_nac == "COTOPAXI") +
    (`Latacunga`= bd$cant_nac == "Latacunga") +
    (`La Maná`= bd$cant_nac == "La Maná") +
    (`Pangua`= bd$cant_nac == "Pangua") +
    (`Pujilí`= bd$cant_nac == "Pujilí") +
    (`Salcedo`= bd$cant_nac == "Salcedo") +
    (`Saquisilí`= bd$cant_nac == "Saquisilí") +
    (`Sigchos`= bd$cant_nac == "Sigchos") +
    (`Chimborazo`= bd$prov_nac == "CHIMBORAZO") +
    (`Riobamba`= bd$cant_nac == "Riobamba") +
    (`Alausí`= bd$cant_nac == "Alausí") +
    (`Colta`= bd$cant_nac == "Colta") +
    (`Chambo`= bd$cant_nac == "Chambo") +
    (`Chunchi`= bd$cant_nac == "Chunchi") +
    (`Guamote`= bd$cant_nac == "Guamote") +
    (`Guano`= bd$cant_nac == "Guano") +
    (`Pallatanga`= bd$cant_nac == "Pallatanga") +
    (`Penípe`= bd$cant_nac == "Penípe") +
    (`Cumandá`= bd$cant_nac == "Cumandá") +
    (`Imbabura`= bd$prov_nac == "IMBABURA") +
    (`Ibarra`= bd$cant_nac == "Ibarra") +
    (`Antonio Ante`= bd$cant_nac == "Antonio Ante") +
    (`Cotacahi`= bd$cant_nac == "Cotacahi") +
    (`Otavalo`= bd$cant_nac == "Otavalo") +
    (`Pimampiro`= bd$cant_nac == "Pimampiro") +
    (`San Miguel De Urcuqui`= bd$cant_nac == "San Miguel De Urcuqui") +
    (`Loja`= bd$prov_nac == "LOJA") +
    (`Loja`= bd$cant_nac == "Loja") +
    (`Calvas`= bd$cant_nac == "Calvas") +
    (`Catamayo`= bd$cant_nac == "Catamayo") +
    (`Célica`= bd$cant_nac == "Célica") +
    (`Chaguarpamba`= bd$cant_nac == "Chaguarpamba") +
    (`Espíndola`= bd$cant_nac == "Espíndola") +
    (`Gonzanamá`= bd$cant_nac == "Gonzanamá") +
    (`Macará`= bd$cant_nac == "Macará") +
    (`Paltas`= bd$cant_nac == "Paltas") +
    (`Puyango`= bd$cant_nac == "Puyango") +
    (`Saraguro`= bd$cant_nac == "Saraguro") +
    (`Sozoranga`= bd$cant_nac == "Sozoranga") +
    (`Zapotillo`= bd$cant_nac == "Zapotillo") +
    (`Pindal`= bd$cant_nac == "Pindal") +
    (`Quilanga`= bd$cant_nac == "Quilanga") +
    (`Olemdo`= bd$cant_nac == "Olemdo") +
    (`Pichincha`= bd$prov_nac == "PICHINCHA") +
    (`Quito`= bd$cant_nac == "Quito") +
    (`Cayambe`= bd$cant_nac == "Cayambe") +
    (`Mejía`= bd$cant_nac == "Mejía") +
    (`Pedro Moncayo`= bd$cant_nac == "Pedro Moncayo") +
    (`Rumiñahui`= bd$cant_nac == "Rumiñahui") +
    (`San Miguel De Los Bancos`= bd$cant_nac == "San Miguel De Los Bancos") +
    (`Pedro Vicente Maldonado`= bd$cant_nac == "Pedro Vicente Maldonado") +
    (`Puerto Quito`= bd$cant_nac == "Puerto Quito") +
    (`Tungurahua`= bd$prov_nac == "TUNGURAHUA") +
    (`Ambato`= bd$cant_nac == "Ambato") +
    (`Baños De Agua Santa`= bd$cant_nac == "Baños De Agua Santa") +
    (`Cevallos`= bd$cant_nac == "Cevallos") +
    (`Mocha`= bd$cant_nac == "Mocha") +
    (`Patate`= bd$cant_nac == "Patate") +
    (`Quero`= bd$cant_nac == "Quero") +
    (`San Pedro De Pelileo`= bd$cant_nac == "San Pedro De Pelileo") +
    (`Santiago De Pillaro`= bd$cant_nac == "Santiago De Pillaro") +
    (`Tisaleo`= bd$cant_nac == "Tisaleo") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_nac == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Santo Domingo`= bd$cant_nac == "Santo Domingo") +
    (`La Condordia`= bd$cant_nac == "La Condordia") +
    (`Región Costa:`= bd$reg_nac == "Región Costa:") +
    (`El Oro`= bd$prov_nac == "EL ORO") +
    (`Machala`= bd$cant_nac == "Machala") +
    (`Arenillas`= bd$cant_nac == "Arenillas") +
    (`Atahualpa`= bd$cant_nac == "Atahualpa") +
    (`Balsas`= bd$cant_nac == "Balsas") +
    (`Chilla`= bd$cant_nac == "Chilla") +
    (`El Guabo`= bd$cant_nac == "El Guabo") +
    (`Huaquillas`= bd$cant_nac == "Huaquillas") +
    (`Marcabelí`= bd$cant_nac == "Marcabelí") +
    (`Pasaje`= bd$cant_nac == "Pasaje") +
    (`Piñas`= bd$cant_nac == "Piñas") +
    (`Portovelo`= bd$cant_nac == "Portovelo") +
    (`Santa Rosa`= bd$cant_nac == "Santa Rosa") +
    (`Zaruma`= bd$cant_nac == "Zaruma") +
    (`Las Lajas`= bd$cant_nac == "Las Lajas") +
    (`Esmeraldas`= bd$prov_nac == "ESMERALDAS") +
    (`Esmeraldas`= bd$cant_nac == "Esmeraldas") +
    (`Eloy Alfaro`= bd$cant_nac == "Eloy Alfaro") +
    (`Muisne`= bd$cant_nac == "Muisne") +
    (`Quininde`= bd$cant_nac == "Quininde") +
    (`San Lorenzo`= bd$cant_nac == "San Lorenzo") +
    (`Atacames`= bd$cant_nac == "Atacames") +
    (`Ríoverde`= bd$cant_nac == "Ríoverde") +
    (`Guayas`= bd$prov_nac == "GUAYAS") +
    (`Guayaquil`= bd$cant_nac == "Guayaquil") +
    (`Alfredo Baquerizo Moreno`= bd$cant_nac == "Alfredo Baquerizo Moreno") +
    (`Balao`= bd$cant_nac == "Balao") +
    (`Balzar`= bd$cant_nac == "Balzar") +
    (`Colimes`= bd$cant_nac == "Colimes") +
    (`Daule`= bd$cant_nac == "Daule") +
    (`Durán`= bd$cant_nac == "Durán") +
    (`Empalme`= bd$cant_nac == "Empalme") +
    (`El Triunfo`= bd$cant_nac == "El Triunfo") +
    (`Milagro`= bd$cant_nac == "Milagro") +
    (`Naranjal`= bd$cant_nac == "Naranjal") +
    (`Naranjito`= bd$cant_nac == "Naranjito") +
    (`Palestina`= bd$cant_nac == "Palestina") +
    (`Pedro Carbo`= bd$cant_nac == "Pedro Carbo") +
    (`Samborondón`= bd$cant_nac == "Samborondón") +
    (`Santa Lucia`= bd$cant_nac == "Santa Lucia") +
    (`Salitre`= bd$cant_nac == "Salitre") +
    (`San Jacinto De Yaguachi`= bd$cant_nac == "San Jacinto De Yaguachi") +
    (`Playas`= bd$cant_nac == "Playas") +
    (`Simón Bolívar`= bd$cant_nac == "Simón Bolívar") +
    (`Crnel. Marcelino Maridueña`= bd$cant_nac == "Crnel. Marcelino Maridueña") +
    (`Lomas De Sargentillo`= bd$cant_nac == "Lomas De Sargentillo") +
    (`Nobol`= bd$cant_nac == "Nobol") +
    (`Gnral. Antonio Elizalde`= bd$cant_nac == "Gnral. Antonio Elizalde") +
    (`Isidro Ayora`= bd$cant_nac == "Isidro Ayora") +
    (`Los Ríos`= bd$prov_nac == "LOS RÍOS") +
    (`Babahoyo`= bd$cant_nac == "Babahoyo") +
    (`Baba`= bd$cant_nac == "Baba") +
    (`Montalvo`= bd$cant_nac == "Montalvo") +
    (`Puebloviejo`= bd$cant_nac == "Puebloviejo") +
    (`Quevedo`= bd$cant_nac == "Quevedo") +
    (`Urdaneta`= bd$cant_nac == "Urdaneta") +
    (`Ventanas`= bd$cant_nac == "Ventanas") +
    (`Vinces`= bd$cant_nac == "Vinces") +
    (`Palenque`= bd$cant_nac == "Palenque") +
    (`Buena Fé`= bd$cant_nac == "Buena Fé") +
    (`Valencia`= bd$cant_nac == "Valencia") +
    (`Mocache`= bd$cant_nac == "Mocache") +
    (`Quinsaloma`= bd$cant_nac == "Quinsaloma") +
    (`Manabí`= bd$prov_nac == "MANABÍ") +
    (`Portoviejo`= bd$cant_nac == "Portoviejo") +
    (`Bolívar`= bd$cant_nac == "Bolívar") * (`Manabí`= bd$prov_nac == "MANABÍ") +
    (`Chone`= bd$cant_nac == "Chone") +
    (`El Carmen`= bd$cant_nac == "El Carmen") +
    (`Flavio Alfaro`= bd$cant_nac == "Flavio Alfaro") +
    (`Jipijapa`= bd$cant_nac == "Jipijapa") +
    (`Junín`= bd$cant_nac == "Junín") +
    (`Manta`= bd$cant_nac == "Manta") +
    (`Montecristi`= bd$cant_nac == "Montecristi") +
    (`Paján`= bd$cant_nac == "Paján") +
    (`Pichincha`= bd$cant_nac == "Pichincha") +
    (`Rocafuerte`= bd$cant_nac == "Rocafuerte") +
    (`Santa Ana`= bd$cant_nac == "Santa Ana") +
    (`Sucre`= bd$cant_nac == "Sucre") +
    (`Tosagua`= bd$cant_nac == "Tosagua") +
    (`24 De Mayo`= bd$cant_nac == "24 De Mayo") +
    (`Pedernales`= bd$cant_nac == "Pedernales") +
    (`Olmedo`= bd$cant_nac == "Olmedo") +
    (`Puerto López`= bd$cant_nac == "Puerto López") +
    (`Jama`= bd$cant_nac == "Jama") +
    (`Jaramijó`= bd$cant_nac == "Jaramijó") +
    (`San Vicente`= bd$cant_nac == "San Vicente") +
    (`Santa Elena`= bd$prov_nac == "SANTA ELENA") +
    (`Santa Elena`= bd$cant_nac == "Santa Elena") +
    (`La Libertad`= bd$cant_nac == "La Libertad") +
    (`Salinas`= bd$cant_nac == "Salinas") +
    (`Región Amazónica:`= bd$reg_nac == "Región Amazónica:") +
    (`Morona Santiago`= bd$prov_nac == "MORONA SANTIAGO") +
    (`Morona`= bd$cant_nac == "Morona") +
    (`Gualaquiza`= bd$cant_nac == "Gualaquiza") +
    (`Limón Indanza`= bd$cant_nac == "Limón Indanza") +
    (`Palora`= bd$cant_nac == "Palora") +
    (`Santiago`= bd$cant_nac == "Santiago") +
    (`Sucúa`= bd$cant_nac == "Sucúa") +
    (`Huamboya`= bd$cant_nac == "Huamboya") +
    (`San Juan Bosco`= bd$cant_nac == "San Juan Bosco") +
    (`Taisha`= bd$cant_nac == "Taisha") +
    (`Logroño`= bd$cant_nac == "Logroño") +
    (`Pablo Sexto`= bd$cant_nac == "Pablo Sexto") +
    (`Tiwintza`= bd$cant_nac == "Tiwintza") +
    (`Napo`= bd$prov_nac == "NAPO") +
    (`Tena`= bd$cant_nac == "Tena") +
    (`Archidona`= bd$cant_nac == "Archidona") +
    (`El Chaco`= bd$cant_nac == "El Chaco") +
    (`Quijos`= bd$cant_nac == "Quijos") +
    (`Carlos Julio Arrosemena Tola`= bd$cant_nac == "Carlos Julio Arrosemena Tola") +
    (`Pastaza`= bd$prov_nac == "PASTAZA") +
    (`Pastaza`= bd$cant_nac == "Pastaza")+
    (`Mera`= bd$cant_nac == "Mera")+
    (`Santa Clara`= bd$cant_nac == "Santa Clara") +
    (`Arajuno`= bd$cant_nac == "Arajuno") +
    (`Zamora Chinchipe`= bd$prov_nac == "ZAMORA CHINCHIPE") +
    (`Zamora`= bd$cant_nac == "Zamora") +
    (`Chinchipe`= bd$cant_nac == "Chinchipe") +
    (`Nangaritza`= bd$cant_nac == "Nangaritza") +
    (`Yacuambi`= bd$cant_nac == "Yacuambi") +
    (`Yantzaza`= bd$cant_nac == "Yantzaza") +
    (`El Pangui`= bd$cant_nac == "El Pangui") +
    (`Centinela Del Cóndor`= bd$cant_nac == "Centinela Del Cóndor") +
    (`Palanda`= bd$cant_nac == "Palanda") +
    (`Paquisha`= bd$cant_nac == "Paquisha") +
    (`Sucumbíos`= bd$prov_nac == "SUCUMBÍOS") +
    (`Lago Agrio`= bd$cant_nac == "Lago Agrio") +
    (`Gonzalo Pizarro`= bd$cant_nac == "Gonzalo Pizarro") +
    (`Putumayo`= bd$cant_nac == "Putumayo") +
    (`Shushufindi`= bd$cant_nac == "Shushufindi") +
    (`Sucumbios`= bd$cant_nac == "Sucumbios") +
    (`Cascales`= bd$cant_nac == "Cascales") +
    (`Cuyabeno`= bd$cant_nac == "Cuyabeno") +
    (`Orellana`= bd$prov_nac == "ORELLANA") +
    (`Orellana`= bd$cant_nac == "Orellana") +
    (`Aguarico`= bd$cant_nac == "Aguarico") +
    (`La Joya De Los Sachas`= bd$cant_nac == "La Joya De Los Sachas") +
    (`Loreto`= bd$cant_nac == "Loreto") +
    (`Región Insular:`= bd$reg_nac == "Región Insular:") +
    (`Galápagos`= bd$prov_nac == "GALÁPAGOS") +
    (`San Cristobal`= bd$cant_nac == "San Cristobal") +
    (`Isabela`= bd$cant_nac == "Isabela") +
    (`Santa Cruz`= bd$cant_nac == "Santa Cruz") +
    (`Exterior:`= bd$reg_nac == "Exterior:") ~
    (
      (`Total`= bd$t) * (sum) +
        (`Total`= bd$t) * (sum) * (`Residente`= bd$residente == "Residente") +
        (`Total`= bd$t) * (sum) * (`No residente`= bd$residente == "No residente") +
        ((`Total`= bd$t) & (`Con asistencia profesional`= bd$asis == "Con asistencia profesiona:")) +
        (`Con asistencia profesional`= bd$asis == "Con asistencia profesiona:") * (`Total`= bd$t) * (sum) * (`Residente`= bd$residente == "Residente") +
        (`Con asistencia profesional`= bd$asis == "Con asistencia profesiona:") * (`Total`= bd$t) * (sum) * (`No residente`= bd$residente == "No residente") +
        ((`Total`= bd$t) & (`Sin asistencia profesional`= bd$asis == "Sin asistencia profesiona:")) +
        (`Sin asistencia profesional`= bd$asis == "Sin asistencia profesiona:") * (`Total`= bd$t) * (sum) * (`Residente`= bd$residente == "Residente") +
        (`Sin asistencia profesional`= bd$asis == "Sin asistencia profesiona:") * (`Total`= bd$t) * (sum) * (`No residente`= bd$residente == "No residente") +
        ((`Total`= bd$t) & (`Sin Informacion`= bd$asis == "Sin información:")) +
        (`Sin Informacion`= bd$asis == "Sin información:") * (`Total`= bd$t) * (sum) * (`Residente`= bd$residente == "Residente") +
        (`Sin Informacion`= bd$asis == "Sin información:") * (`Total`= bd$t) * (sum) * (`No residente`= bd$residente == "No residente") 
    ),
  data = bd)

print(tabla3.1.4)

write.csv.tabular(tabla3.1.4, file = "Tabla 3.1.4.csv")

# Cuadro No. 3.1.5 
# Nacidos Vivos, por Número de Hijos tenidos por la Madre, según región y provincia de Residencia Habitual de la madre
# Crear la variable hvivos para clasificar por numero e hijos vivos

bd<- bd %>%
  mutate(hvivos = if_else(anio_nac == 2024 & (hij_viv == 1), 1, 0),
         hvivos = if_else(anio_nac == 2024 & (hij_viv == 2), 2, hvivos),
         hvivos = if_else(anio_nac == 2024 & (hij_viv == 3), 3, hvivos),
         hvivos = if_else(anio_nac == 2024 & (hij_viv == 4), 4, hvivos),
         hvivos = if_else(anio_nac == 2024 & (hij_viv == 5), 5, hvivos),
         hvivos = if_else(anio_nac == 2024 & (hij_viv == 6), 6, hvivos),
         hvivos = if_else(anio_nac == 2024 & (hij_viv == 7), 7, hvivos),
         hvivos = if_else(anio_nac == 2024 & (hij_viv == 8), 8, hvivos),
         hvivos = if_else(anio_nac == 2024 & (hij_viv == 9), 9, hvivos),
         hvivos = if_else(anio_nac == 2024 & (hij_viv >= 10), 10, hvivos))
         
bd <- apply_labels(bd, hvivos = "Hijos vivos")

as.numeric(bd$hvivos)

# Asignar etiquetas a la variable numero de hijos

bd$hvivos = factor(bd$hvivos,
                     levels = c(1, 2, 3, 4, 5,
                                6, 7, 8, 9, 10),
                     labels = c("1", "2", "3", "4", "5",
                                "6", "7", "8", "9", "10 y mas"),
                     ordered = FALSE)

# Tabulado

tabla3.1.5 <- tabular(
  (`Región Sierra:`= bd$reg_res == "Región Sierra:") +
    (`Azuay`= bd$prov_res == "AZUAY") +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") +
    (`Cañar`= bd$prov_res == "CAÑAR") +
    (`Carchi`= bd$prov_res == "CARCHI") +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") +
    (`Imbabura`= bd$prov_res == "IMBABURA") +
    (`Loja`= bd$prov_res == "LOJA") +
    (`Pichincha`= bd$prov_res == "PICHINCHA") +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") +
    (`El Oro`= bd$prov_res == "EL ORO") +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS") +
    (`Guayas`= bd$prov_res == "GUAYAS") +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") +
    (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") +
    (`Napo`= bd$prov_res == "NAPO") +
    (`Pastaza`= bd$prov_res == "PASTAZA") +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") +
    (`Orellana`= bd$prov_res == "ORELLANA") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") +
    (`Exterior:`= bd$reg_res == "Exterior:") ~
    (
      (`Total`= bd$t) * (sum) +
        (`Hijos`= bd$t) * (sum) * (`1`= bd$hvivos == "1") +
        (`Hijos`= bd$t) * (sum) * (`2`= bd$hvivos == "2") +
        (`Hijos`= bd$t) * (sum) * (`3`= bd$hvivos == "3") +
        (`Hijos`= bd$t) * (sum) * (`4`= bd$hvivos == "4") +
        (`Hijos`= bd$t) * (sum) * (`5`= bd$hvivos == "5") +
        (`Hijos`= bd$t) * (sum) * (`6`= bd$hvivos == "6") +
        (`Hijos`= bd$t) * (sum) * (`7`= bd$hvivos == "7") +
        (`Hijos`= bd$t) * (sum) * (`8`= bd$hvivos == "8") +
        (`Hijos`= bd$t) * (sum) * (`9`= bd$hvivos == "9") +
        (`Hijos`= bd$t) * (sum) * (`10 y mas`= bd$hvivos == "10 y mas")
    ),
  data = bd)

print(tabla3.1.5)

write.csv.tabular(tabla3.1.5, file = "Tabla 3.1.5.csv")

# Cuadro No. 3.1.6
# Nacidos Vivos, por Número de Hijos tenidos por la Madre, según región de Residencia Habitual y Grupos de Edad de la misma

# Crear la variable edadm para clasificar por edad de la madre

bd <- bd %>%
  mutate(edadm = if_else(anio_nac == 2024 & (edad_mad >= "10" & edad_mad <= "14"), 1, 0),
         edadm = if_else(anio_nac == 2024 & (edad_mad >= "15" & edad_mad <= "19"), 2, edadm),
         edadm = if_else(anio_nac == 2024 & (edad_mad >= "20" & edad_mad <= "24"), 3, edadm),
         edadm = if_else(anio_nac == 2024 & (edad_mad >= "25" & edad_mad <= "29"), 4, edadm),
         edadm = if_else(anio_nac == 2024 & (edad_mad >= "30" & edad_mad <= "34"), 5, edadm),
         edadm = if_else(anio_nac == 2024 & (edad_mad >= "35" & edad_mad <= "39"), 6, edadm),
         edadm = if_else(anio_nac == 2024 & (edad_mad >= "40" & edad_mad <= "44"), 7, edadm),
         edadm = if_else(anio_nac == 2024 & (edad_mad >= "45" & edad_mad <= "49"), 8, edadm),
         edadm = if_else(anio_nac == 2024 & (edad_mad >= "50") & (edad_mad != "99"), 9, edadm),
         edadm = if_else(anio_nac == 2024 & (edad_mad == "99"), 10, edadm))

bd <- apply_labels(bd, edadm = "Edad de la Madre")

as.numeric(bd$edadm)

# Asignar categorías a la edad de la madre a la variable edadm

bd$edadm = factor(bd$edadm,
                      levels = c(1, 2, 3, 4,
                                 5, 6, 7, 8,
                                 9, 10),
                      labels = c("Menores a 15 años:", "15 - 19 años:", "20 - 24 años:", "25 - 29 años:",
                                 "30 - 34 años:", "35 - 39 años:", "40 - 44 años:", "45 - 49 años:",
                                 "Mayores a 50 años:", "Sin información:"),
                      ordered = FALSE)

# Tabulado

tabla3.1.6 <- tabular(
  (`Menores a 15 años:`= bd$edadm == "Menores a 15 años:") +
    (`15 - 19 años:`= bd$edadm == "15 - 19 años:") +
    (`20 - 24 años:`= bd$edadm == "20 - 24 años:") +
    (`25 - 29 años:`= bd$edadm == "25 - 29 años:") +
    (`30 - 34 años:`= bd$edadm == "30 - 34 años:") +
    (`35 - 39 años:`= bd$edadm == "35 - 39 años:") +
    (`40 - 44 años:`= bd$edadm == "40 - 44 años:") +
    (`45 - 49 años:`= bd$edadm == "45 - 49 años:") +
    (`Mayores a 50 años:`= bd$edadm == "Mayores a 50 años:") +
    (`Sin información:`= bd$edadm == "Sin información:") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Menores a 15 años:`= bd$edadm == "Menores a 15 años:") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`15 - 19 años:`= bd$edadm == "15 - 19 años:") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`20 - 24 años:`= bd$edadm == "20 - 24 años:") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`25 - 29 años:`= bd$edadm == "25 - 29 años:") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`30 - 34 años:`= bd$edadm == "30 - 34 años:") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`35 - 39 años:`= bd$edadm == "35 - 39 años:") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`40 - 44 años:`= bd$edadm == "40 - 44 años:") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`45 - 49 años:`= bd$edadm == "45 - 49 años:") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Mayores a 50 años:`= bd$edadm == "Mayores a 50 años:") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Sin información:`= bd$edadm == "Sin información:") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Menores a 15 años:`= bd$edadm == "Menores a 15 años:") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`15 - 19 años:`= bd$edadm == "15 - 19 años:") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`20 - 24 años:`= bd$edadm == "20 - 24 años:") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`25 - 29 años:`= bd$edadm == "25 - 29 años:") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`30 - 34 años:`= bd$edadm == "30 - 34 años:") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`35 - 39 años:`= bd$edadm == "35 - 39 años:") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`40 - 44 años:`= bd$edadm == "40 - 44 años:") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`45 - 49 años:`= bd$edadm == "45 - 49 años:") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Mayores a 50 años:`= bd$edadm == "Mayores a 50 años:") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Sin información:`= bd$edadm == "Sin información:") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Menores a 15 años:`= bd$edadm == "Menores a 15 años:") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`15 - 19 años:`= bd$edadm == "15 - 19 años:") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`20 - 24 años:`= bd$edadm == "20 - 24 años:") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`25 - 29 años:`= bd$edadm == "25 - 29 años:") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`30 - 34 años:`= bd$edadm == "30 - 34 años:") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`35 - 39 años:`= bd$edadm == "35 - 39 años:") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`40 - 44 años:`= bd$edadm == "40 - 44 años:") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`45 - 49 años:`= bd$edadm == "45 - 49 años:") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Mayores a 50 años:`= bd$edadm == "Mayores a 50 años:") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Sin información:`= bd$edadm == "Sin información:") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Menores a 15 años:`= bd$edadm == "Menores a 15 años:") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`15 - 19 años:`= bd$edadm == "15 - 19 años:") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`20 - 24 años:`= bd$edadm == "20 - 24 años:") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`25 - 29 años:`= bd$edadm == "25 - 29 años:") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`30 - 34 años:`= bd$edadm == "30 - 34 años:") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`35 - 39 años:`= bd$edadm == "35 - 39 años:") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`40 - 44 años:`= bd$edadm == "40 - 44 años:") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`45 - 49 años:`= bd$edadm == "45 - 49 años:") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Mayores a 50 años:`= bd$edadm == "Mayores a 50 años:") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Sin información:`= bd$edadm == "Sin información:") +
    (`Exterior:`= bd$reg_res == "Exterior:") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`25 - 29 años:`= bd$edadm == "25 - 29 años:") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`30 - 34 años:`= bd$edadm == "30 - 34 años:") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`35 - 39 años:`= bd$edadm == "35 - 39 años:") ~ 
    (
      (`Total`= bd$t) * (sum) +
        (`Hijos`= bd$t) * (sum) * (`1`= bd$hvivos == "1") +
        (`Hijos`= bd$t) * (sum) * (`2`= bd$hvivos == "2") +
        (`Hijos`= bd$t) * (sum) * (`3`= bd$hvivos == "3") +
        (`Hijos`= bd$t) * (sum) * (`4`= bd$hvivos == "4") +
        (`Hijos`= bd$t) * (sum) * (`5`= bd$hvivos == "5") +
        (`Hijos`= bd$t) * (sum) * (`6`= bd$hvivos == "6") +
        (`Hijos`= bd$t) * (sum) * (`7`= bd$hvivos == "7") +
        (`Hijos`= bd$t) * (sum) * (`8`= bd$hvivos == "8") +
        (`Hijos`= bd$t) * (sum) * (`9`= bd$hvivos == "9") +
        (`Hijos`= bd$t) * (sum) * (`10 y mas`= bd$hvivos == "10 y mas")
    ),
  data = bd)

print(tabla3.1.6)

write.csv.tabular(tabla3.1.6, file = "Tabla 3.1.6.csv")

# Cuadro No. 3.1.7
# Nacidos vivos en el año (t), por grupos de edad de la madre y sexo del nacido vivo, según región, provincia y área de residencia habitual de la madre

# Tabulados

tabla3.1.7A <- tabular(
  (`Región Sierra:`= bd$reg_res == "Región Sierra:") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Urbano`= bd$area_res == "Urbano") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Rural`= bd$area_res == "Rural") +
    (`Azuay`= bd$prov_res == "AZUAY") +
    (`Azuay`= bd$prov_res == "AZUAY") * (`Area`= bd$area_res) +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") * (`Area`= bd$area_res) +
    (`Cañar`= bd$prov_res == "CAÑAR") +
    (`Cañar`= bd$prov_res == "CAÑAR") * (`Area`= bd$area_res) +
    (`Carchi`= bd$prov_res == "CARCHI") +
    (`Carchi`= bd$prov_res == "CARCHI") * (`Area`= bd$area_res) +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") * (`Area`= bd$area_res) +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") * (`Area`= bd$area_res) +
    (`Imbabura`= bd$prov_res == "IMBABURA") +
    (`Imbabura`= bd$prov_res == "IMBABURA") * (`Area`= bd$area_res) +
    (`Loja`= bd$prov_res == "LOJA") +
    (`Loja`= bd$prov_res == "LOJA") * (`Area`= bd$area_res) +
    (`Pichincha`= bd$prov_res == "PICHINCHA") +
    (`Pichincha`= bd$prov_res == "PICHINCHA") * (`Area`= bd$area_res) +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") * (`Area`= bd$area_res) +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") * (`Area`= bd$area_res) +
    (`Región Costa:`= bd$reg_res == "Región Costa:") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Urbano`= bd$area_res == "Urbano") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Rural`= bd$area_res == "Rural") +
    (`El Oro`= bd$prov_res == "EL ORO") +
    (`El Oro`= bd$prov_res == "EL ORO") * (`Area`= bd$area_res) +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS" ) +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS" ) * (`Area`= bd$area_res) +
    (`Guayas`= bd$prov_res == "GUAYAS") +
    (`Guayas`= bd$prov_res == "GUAYAS") * (`Area`= bd$area_res) +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") * (`Area`= bd$area_res) +
    (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Manabí`= bd$prov_res == "MANABÍ") * (`Area`= bd$area_res) +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") * (`Area`= bd$area_res) +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Urbano`= bd$area_res == "Urbano") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Rural`= bd$area_res == "Rural") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") * (`Area`= bd$area_res) +
    (`Napo`= bd$prov_res == "NAPO") +
    (`Napo`= bd$prov_res == "NAPO") * (`Area`= bd$area_res) +
    (`Pastaza`= bd$prov_res == "PASTAZA") +
    (`Pastaza`= bd$prov_res == "PASTAZA") * (`Area`= bd$area_res) +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") * (`Area`= bd$area_res) +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") * (`Area`= bd$area_res) +
    (`Orellana`= bd$prov_res == "ORELLANA") +
    (`Orellana`= bd$prov_res == "ORELLANA") * (`Area`= bd$area_res) +
    (`Región Insular:`= bd$reg_res == "Región Insular:") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Urbano`= bd$area_res == "Urbano") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Rural`= bd$area_res == "Rural") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") * (`Area`= bd$area_res) +
    (`Exterior:`= bd$reg_res == "Exterior:") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`Urbano`= bd$area_res == "Urbano") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`Rural`= bd$area_res == "Rural") ~ 
    (
      (`Total`= bd$t) * (sum) +
        (`Total`= bd$t) * (sum) * (`Hombre`= bd$sexo == "Hombre") +
        (`Total`= bd$t) * (sum) * (`Mujer`= bd$sexo == "Mujer") +
        ((`Total`= bd$t) & (`Menores a 15 años:`= bd$edadm == "Menores a 15 años:")) +
        (`Menores a 15 años:`= bd$edadm == "Menores a 15 años:") * (`Total`= bd$t) * (sum) * (`Hombre`= bd$sexo == "Hombre") +
        (`Menores a 15 años:`= bd$edadm == "Menores a 15 años:") * (`Total`= bd$t) * (sum) * (`Mujer`= bd$sexo == "Mujer") +
        ((`Total`= bd$t) & (`15 - 19 años:`= bd$edadm == "15 - 19 años:")) +
        (`15 - 19 años:`= bd$edadm == "15 - 19 años:") * (`Total`= bd$t) * (sum) * (`Hombre`= bd$sexo == "Hombre") +
        (`15 - 19 años:`= bd$edadm == "15 - 19 años:") * (`Total`= bd$t) * (sum) * (`Mujer`= bd$sexo == "Mujer") +
        ((`Total`= bd$t) & (`20 - 24 años:`= bd$edadm == "20 - 24 años:")) +
        (`20 - 24 años:`= bd$edadm == "20 - 24 años:") * (`Total`= bd$t) * (sum) * (`Hombre`= bd$sexo == "Hombre") +
        (`20 - 24 años:`= bd$edadm == "20 - 24 años:") * (`Total`= bd$t) * (sum) * (`Mujer`= bd$sexo == "Mujer") +
        ((`Total`= bd$t) & (`25 - 29 años:`= bd$edadm == "25 - 29 años:")) +
        (`25 - 29 años:`= bd$edadm == "25 - 29 años:") * (`Total`= bd$t) * (sum) * (`Hombre`= bd$sexo == "Hombre") +
        (`25 - 29 años:`= bd$edadm == "25 - 29 años:") * (`Total`= bd$t) * (sum) * (`Mujer`= bd$sexo == "Mujer")
    ),
  data = bd)

print(tabla3.1.7A)

write.csv.tabular(tabla3.1.7A, file = "Tabla 3.1.7A.csv")

tabla3.1.7B <- tabular(
  (`Región Sierra:`= bd$reg_res == "Región Sierra:") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Urbano`= bd$area_res == "Urbano") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Rural`= bd$area_res == "Rural") +
    (`Azuay`= bd$prov_res == "AZUAY") +
    (`Azuay`= bd$prov_res == "AZUAY") * (`Area`= bd$area_res) +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") * (`Area`= bd$area_res) +
    (`Cañar`= bd$prov_res == "CAÑAR") +
    (`Cañar`= bd$prov_res == "CAÑAR") * (`Area`= bd$area_res) +
    (`Carchi`= bd$prov_res == "CARCHI") +
    (`Carchi`= bd$prov_res == "CARCHI") * (`Area`= bd$area_res) +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") * (`Area`= bd$area_res) +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") * (`Area`= bd$area_res) +
    (`Imbabura`= bd$prov_res == "IMBABURA") +
    (`Imbabura`= bd$prov_res == "IMBABURA") * (`Area`= bd$area_res) +
    (`Loja`= bd$prov_res == "LOJA") +
    (`Loja`= bd$prov_res == "LOJA") * (`Area`= bd$area_res) +
    (`Pichincha`= bd$prov_res == "PICHINCHA") +
    (`Pichincha`= bd$prov_res == "PICHINCHA") * (`Area`= bd$area_res) +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") * (`Area`= bd$area_res) +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") * (`Area`= bd$area_res) +
    (`Región Costa:`= bd$reg_res == "Región Costa:") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Urbano`= bd$area_res == "Urbano") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Rural`= bd$area_res == "Rural") +
    (`El Oro`= bd$prov_res == "EL ORO") +
    (`El Oro`= bd$prov_res == "EL ORO") * (`Area`= bd$area_res) +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS" ) +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS" ) * (`Area`= bd$area_res) +
    (`Guayas`= bd$prov_res == "GUAYAS") +
    (`Guayas`= bd$prov_res == "GUAYAS") * (`Area`= bd$area_res) +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") * (`Area`= bd$area_res) +
    (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Manabí`= bd$prov_res == "MANABÍ") * (`Area`= bd$area_res) +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") * (`Area`= bd$area_res) +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Urbano`= bd$area_res == "Urbano") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Rural`= bd$area_res == "Rural") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") * (`Area`= bd$area_res) +
    (`Napo`= bd$prov_res == "NAPO") +
    (`Napo`= bd$prov_res == "NAPO") * (`Area`= bd$area_res) +
    (`Pastaza`= bd$prov_res == "PASTAZA") +
    (`Pastaza`= bd$prov_res == "PASTAZA") * (`Area`= bd$area_res) +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") * (`Area`= bd$area_res) +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") * (`Area`= bd$area_res) +
    (`Orellana`= bd$prov_res == "ORELLANA") +
    (`Orellana`= bd$prov_res == "ORELLANA") * (`Area`= bd$area_res) +
    (`Región Insular:`= bd$reg_res == "Región Insular:") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Urbano`= bd$area_res == "Urbano") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Rural`= bd$area_res == "Rural") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") * (`Area`= bd$area_res) +
    (`Exterior:`= bd$reg_res == "Exterior:") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`Urbano`= bd$area_res == "Urbano") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`Rural`= bd$area_res == "Rural") ~ 
    (
      (`Total`= bd$t) * (sum) +
        ((`Total`= bd$t) & (`30 - 34 años:`= bd$edadm == "30 - 34 años:")) +
        (`30 - 34 años:`= bd$edadm == "30 - 34 años:") * (`Total`= bd$t) * (sum) * (`Hombre`= bd$sexo == "Hombre") +
        (`30 - 34 años:`= bd$edadm == "30 - 34 años:") * (`Total`= bd$t) * (sum) * (`Mujer`= bd$sexo == "Mujer") +
        ((`Total`= bd$t) & (`35 - 39 años:`= bd$edadm == "35 - 39 años:")) +
        (`35 - 39 años:`= bd$edadm == "35 - 39 años:") * (`Total`= bd$t) * (sum) * (`Hombre`= bd$sexo == "Hombre") +
        (`35 - 39 años:`= bd$edadm == "35 - 39 años:") * (`Total`= bd$t) * (sum) * (`Mujer`= bd$sexo == "Mujer") +
        ((`Total`= bd$t) & (`40 - 44 años:`= bd$edadm == "40 - 44 años:")) +
        (`40 - 44 años:`= bd$edadm == "40 - 44 años:") * (`Total`= bd$t) * (sum) * (`Hombre`= bd$sexo == "Hombre") +
        (`40 - 44 años:`= bd$edadm == "40 - 44 años:") * (`Total`= bd$t) * (sum) * (`Mujer`= bd$sexo == "Mujer") +
        ((`Total`= bd$t) & (`45 - 49 años:`= bd$edadm == "45 - 49 años:")) +
        (`45 - 49 años:`= bd$edadm == "45 - 49 años:") * (`Total`= bd$t) * (sum) * (`Hombre`= bd$sexo == "Hombre") +
        (`45 - 49 años:`= bd$edadm == "45 - 49 años:") * (`Total`= bd$t) * (sum) * (`Mujer`= bd$sexo == "Mujer") +
        ((`Total`= bd$t) & (`Mayores a 50 años:`= bd$edadm == "Mayores a 50 años:")) +
        (`Mayores a 50 años:`= bd$edadm == "Mayores a 50 años:") * (`Total`= bd$t) * (sum) * (`Hombre`= bd$sexo == "Hombre") +
        (`Mayores a 50 años:`= bd$edadm == "Mayores a 50 años:") * (`Total`= bd$t) * (sum) * (`Mujer`= bd$sexo == "Mujer") +
        ((`Total`= bd$t) & (`Sin información:`= bd$edadm == "Sin información:")) +
        (`Sin información:`= bd$edadm == "Sin información:") * (`Total`= bd$t) * (sum) * (`Hombre`= bd$sexo == "Hombre") +
        (`Sin información:`= bd$edadm == "Sin información:") * (`Total`= bd$t) * (sum) * (`Mujer`= bd$sexo == "Mujer")
    ),
  data = bd)

print(tabla3.1.7B)

write.csv.tabular(tabla3.1.7B, file = "Tabla 3.1.7B.csv")

# Cuadro No. 3.1.8
# Nacidos vivos en el año (t), por producto del embarazo, según región y provincia de residencia habitual de la madre ------------------

# Tabulado

tabla3.1.8 <- tabular(
  (`Región Sierra:`= bd$reg_res == "Región Sierra:") +
    (`Azuay`= bd$prov_res == "AZUAY") +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") +
    (`Cañar`= bd$prov_res == "CAÑAR") +
    (`Carchi`= bd$prov_res == "CARCHI") +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") +
    (`Imbabura`= bd$prov_res == "IMBABURA") +
    (`Loja`= bd$prov_res == "LOJA") +
    (`Pichincha`= bd$prov_res == "PICHINCHA") +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") +
    (`El Oro`= bd$prov_res == "EL ORO") +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS") +
    (`Guayas`= bd$prov_res == "GUAYAS") +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") +
    (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") +
    (`Napo`= bd$prov_res == "NAPO") +
    (`Pastaza`= bd$prov_res == "PASTAZA") +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") +
    (`Orellana`= bd$prov_res == "ORELLANA") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") +
    (`Exterior:`= bd$reg_res == "Exterior:") ~ 
    (
      (`Total`= bd$t) * (sum) +
        (`Simple`= bd$t) * (sum) * (`1`= bd$p_emb == 1) +
        (`Doble`= bd$t) * (sum) * (`2`= bd$p_emb == 2) +
        (`Triple`= bd$t) * (sum) * (`3`= bd$p_emb == 3) +
        (`Cuádruple ó más`= bd$t) * (sum) * (`4`= bd$p_emb == 4) +
        (`Sin información`= bd$t) * (sum) * (`99`= bd$p_emb == 99)
    ),
  data = bd)

print(tabla3.1.8)

write.csv.tabular(tabla3.1.8, file = "Tabla 3.1.8.csv")

# Cuadro No. 3.1.9
# Nacidos vivos en el año (t), por mes de ocurrencia, según provincia de residencia habitual de la madre y sexo del nacido vivo

# Tabulado

tabla3.1.9 <- tabular(
  (`Región Sierra:`= bd$reg_res == "Región Sierra:") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Hombre`= bd$sexo == "Hombre") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Mujer`= bd$sexo == "Mujer") +
    (`Azuay`= bd$prov_res == "AZUAY") +
    (`Azuay`= bd$prov_res == "AZUAY") * (`Sexo`= bd$sexo) +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") * (`Sexo`= bd$sexo) +
    (`Cañar`= bd$prov_res == "CAÑAR") +
    (`Cañar`= bd$prov_res == "CAÑAR") * (`Sexo`= bd$sexo) +
    (`Carchi`= bd$prov_res == "CARCHI") +
    (`Carchi`= bd$prov_res == "CARCHI") * (`Sexo`= bd$sexo) +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") * (`Sexo`= bd$sexo) +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") * (`Sexo`= bd$sexo) +
    (`Imbabura`= bd$prov_res == "IMBABURA") +
    (`Imbabura`= bd$prov_res == "IMBABURA") * (`Sexo`= bd$sexo) +
    (`Loja`= bd$prov_res == "LOJA") +
    (`Loja`= bd$prov_res == "LOJA") * (`Sexo`= bd$sexo) +
    (`Pichincha`= bd$prov_res == "PICHINCHA") +
    (`Pichincha`= bd$prov_res == "PICHINCHA") * (`Sexo`= bd$sexo) +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") * (`Sexo`= bd$sexo) +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") * (`Sexo`= bd$sexo) +
    (`Región Costa:`= bd$reg_res == "Región Costa:") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Hombre`= bd$sexo == "Hombre") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Mujer`= bd$sexo == "Mujer") +
    (`El Oro`= bd$prov_res == "EL ORO") +
    (`El Oro`= bd$prov_res == "EL ORO") * (`Sexo`= bd$sexo) +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS" ) +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS" ) * (`Sexo`= bd$sexo) +
    (`Guayas`= bd$prov_res == "GUAYAS") +
    (`Guayas`= bd$prov_res == "GUAYAS") * (`Sexo`= bd$sexo) +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") * (`Sexo`= bd$sexo) +
    (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Manabí`= bd$prov_res == "MANABÍ") * (`Sexo`= bd$sexo) +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") * (`Sexo`= bd$sexo) +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Hombre`= bd$sexo == "Hombre") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Mujer`= bd$sexo == "Mujer") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") * (`Sexo`= bd$sexo) +
    (`Napo`= bd$prov_res == "NAPO") +
    (`Napo`= bd$prov_res == "NAPO") * (`Sexo`= bd$sexo) +
    (`Pastaza`= bd$prov_res == "PASTAZA") +
    (`Pastaza`= bd$prov_res == "PASTAZA") * (`Sexo`= bd$sexo) +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") * (`Sexo`= bd$sexo) +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") * (`Sexo`= bd$sexo) +
    (`Orellana`= bd$prov_res == "ORELLANA") +
    (`Orellana`= bd$prov_res == "ORELLANA") * (`Sexo`= bd$sexo) +
    (`Región Insular:`= bd$reg_res == "Región Insular:") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Hombre`= bd$sexo == "Hombre") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Mujer`= bd$sexo == "Mujer") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") * (`Sexo`= bd$sexo) +
    (`Exterior:`= bd$reg_res == "Exterior:") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`Hombre`= bd$sexo == "Hombre") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`Mujer`= bd$sexo == "Mujer") ~  
    (
      (`Total`= bd$t) * (sum) +
        (`Enero`= bd$t) * (sum) * (`1`= bd$mes_nac == 1) +
        (`Febrero`= bd$t) * (sum) * (`2`= bd$mes_nac == 2) +
        (`Marzo`= bd$t) * (sum) * (`3`= bd$mes_nac == 3) +
        (`Abril`= bd$t) * (sum) * (`4`= bd$mes_nac == 4) +
        (`Mayo`= bd$t) * (sum) * (`5`= bd$mes_nac == 5) +
        (`Junio`= bd$t) * (sum) * (`6`= bd$mes_nac == 6) +
        (`Julio`= bd$t) * (sum) * (`7`= bd$mes_nac == 7) +
        (`Agosto`= bd$t) * (sum) * (`8`= bd$mes_nac == 8) +
        (`Septiembre`= bd$t) * (sum) * (`9`= bd$mes_nac == 9) +
        (`Octubre`= bd$t) * (sum) * (`10`= bd$mes_nac == 10) +
        (`Noviembre`= bd$t) * (sum) * (`11`= bd$mes_nac == 11) +
        (`Diciembre`= bd$t) * (sum) * (`12`= bd$mes_nac == 12)
    ),
  data = bd)

print(tabla3.1.9)
      
write.csv.tabular(tabla3.1.9, file = "Tabla 3.1.9.csv")

# Cuadro No. 3.1.10
# Nacidos vivos en el año (t), por nivel de instrucción de la madre, según provincia de residencia habitual de la madre y tipo de asistencia

# Tabulado

tabla3.1.10 <- tabular(
  (`Región Sierra:`= bd$reg_res == "Región Sierra:") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Con asistencia profesional`= bd$asis == "Con asistencia profesiona:") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Sin asistencia profesional`= bd$asis == "Sin asistencia profesiona:") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Sin informacion`= bd$asis == "Sin información:") +
    (`Azuay`= bd$prov_res == "AZUAY") +
    (`Azuay`= bd$prov_res == "AZUAY") * (`Asistencia`= bd$asis) +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") * (`Asis`= bd$asis) +
    (`Cañar`= bd$prov_res == "CAÑAR") +
    (`Cañar`= bd$prov_res == "CAÑAR") * (`Asis`= bd$asis) +
    (`Carchi`= bd$prov_res == "CARCHI") +
    (`Carchi`= bd$prov_res == "CARCHI") * (`Asis`= bd$asis) +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") * (`Asis`= bd$asis) +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") * (`Asis`= bd$asis) +
    (`Imbabura`= bd$prov_res == "IMBABURA") +
    (`Imbabura`= bd$prov_res == "IMBABURA") * (`Asis`= bd$asis) +
    (`Loja`= bd$prov_res == "LOJA") +
    (`Loja`= bd$prov_res == "LOJA") * (`Asis`= bd$asis) +
    (`Pichincha`= bd$prov_res == "PICHINCHA") +
    (`Pichincha`= bd$prov_res == "PICHINCHA") * (`Asis`= bd$asis) +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") * (`Asis`= bd$asis) +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") * (`Asis`= bd$asis) +
    (`Región Costa:`= bd$reg_res == "Región Costa:") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Con asistencia profesional`= bd$asis == "Con asistencia profesiona:") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Sin asistencia profesional`= bd$asis == "Sin asistencia profesiona:") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Sin informacion`= bd$asis == "Sin información:") +
    (`El Oro`= bd$prov_res == "EL ORO") +
    (`El Oro`= bd$prov_res == "EL ORO") * (`Asis`= bd$asis) +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS" ) +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS" ) * (`Asis`= bd$asis) +
    (`Guayas`= bd$prov_res == "GUAYAS") +
    (`Guayas`= bd$prov_res == "GUAYAS") * (`Asis`= bd$asis) +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") * (`Asis`= bd$asis) +
    (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Manabí`= bd$prov_res == "MANABÍ") * (`Asis`= bd$asis) +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") * (`Asis`= bd$asis) +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Con asistencia profesional`= bd$asis == "Con asistencia profesiona:") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Sin asistencia profesional`= bd$asis == "Sin asistencia profesiona:") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Sin informacion`= bd$asis == "Sin información:") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") * (`Asis`= bd$asis) +
    (`Napo`= bd$prov_res == "NAPO") +
    (`Napo`= bd$prov_res == "NAPO") * (`Asis`= bd$asis) +
    (`Pastaza`= bd$prov_res == "PASTAZA") +
    (`Pastaza`= bd$prov_res == "PASTAZA") * (`Asis`= bd$asis) +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") * (`Asis`= bd$asis) +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") * (`Asis`= bd$asis) +
    (`Orellana`= bd$prov_res == "ORELLANA") +
    (`Orellana`= bd$prov_res == "ORELLANA") * (`Asis`= bd$asis) +
    (`Región Insular:`= bd$reg_res == "Región Insular:") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Con asistencia profesional`= bd$asis == "Con asistencia profesiona:") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Sin asistencia profesional`= bd$asis == "Sin asistencia profesiona:") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Sin informacion`= bd$asis == "Sin información:") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") * (`Asis`= bd$asis) +
    (`Exterior:`= bd$reg_res == "Exterior:") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`Con asistencia profesional`= bd$asis == "Con asistencia profesiona:") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`Sin asistencia profesional`= bd$asis == "Sin asistencia profesiona:") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`Sin informacion`= bd$asis == "Sin información:") ~  
    (
      (`Total`= bd$t) * (sum) +
        (`Ninguno`= bd$t) * (sum) * (`0`= bd$niv_inst == "Ninguno") +
        (`Centro de alfabetización`= bd$t) * (sum) * (`1`= bd$niv_inst == "Centro de alfabetización") +
        (`Primaria`= bd$t) * (sum) * (`2`= bd$niv_inst == "Primaria") +
        (`Secundaria`= bd$t) * (sum) * (`3`= bd$niv_inst == "Secundaria") +
        (`Educación básica`= bd$t) * (sum) * (`4`= bd$niv_inst == "Educación Básica") +
        (`Educación media/bachillerato`= bd$t) * (sum) * (`5`= bd$niv_inst == "Educación media/Bachillerato") +
        (`Superior no universitario`= bd$t) * (sum) * (`6`= bd$niv_inst == "Superior no universitaria") +
        (`Superior universitario`= bd$t) * (sum) * (`7`= bd$niv_inst ==  "Superior universitaria") +
        (`Posgrado`= bd$t) * (sum) * (`8`= bd$niv_inst == "Postgrado") +
        (`Sin Informacion`= bd$t) * (sum) * (`9`= bd$niv_inst == "Sin información")
    ),
  data = bd)

print(tabla3.1.10)

write.csv.tabular(tabla3.1.10, file = "Tabla 3.1.10.csv")

# Cuadro No. 3.1.11
# Nacidos vivos en el año (t), por número de hijos que tuvo la madre, según región de residencia habitual y nivel de instrucción

# Tabulado

tabla3.1.11 <- tabular(
  (`Región Sierra:`= bd$reg_res == "Región Sierra:") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Ninguno`= bd$niv_inst == "Ninguno") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Centro de alfabetización`= bd$niv_inst == "Centro de alfabetización") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Primaria`= bd$niv_inst == "Primaria") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Educación Básica`= bd$niv_inst == "Educación Básica") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Secundaria`= bd$niv_inst == "Secundaria") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Educación media/Bachillerato`= bd$niv_inst == "Educación media/Bachillerato") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Superior no universitaria`= bd$niv_inst == "Superior no universitaria") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Superior universitaria`= bd$niv_inst == "Superior universitaria") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Postgrado`= bd$niv_inst == "Postgrado") +
    (`Región Sierra:`= bd$reg_res == "Región Sierra:") * (`Sin información`= bd$niv_inst == "Sin información") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Ninguno`= bd$niv_inst == "Ninguno") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Centro de alfabetización`= bd$niv_inst == "Centro de alfabetización") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Primaria`= bd$niv_inst == "Primaria") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Educación Básica`= bd$niv_inst == "Educación Básica") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Secundaria`= bd$niv_inst == "Secundaria") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Educación media/Bachillerato`= bd$niv_inst == "Educación media/Bachillerato") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Superior no universitaria`= bd$niv_inst == "Superior no universitaria") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Superior universitaria`= bd$niv_inst == "Superior universitaria") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Postgrado`= bd$niv_inst == "Postgrado") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") * (`Sin información`= bd$niv_inst == "Sin información") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Ninguno`= bd$niv_inst == "Ninguno") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Centro de alfabetización`= bd$niv_inst == "Centro de alfabetización") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Primaria`= bd$niv_inst == "Primaria") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Educación Básica`= bd$niv_inst == "Educación Básica") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Secundaria`= bd$niv_inst == "Secundaria") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Educación media/Bachillerato`= bd$niv_inst == "Educación media/Bachillerato") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Superior no universitaria`= bd$niv_inst == "Superior no universitaria") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Superior universitaria`= bd$niv_inst == "Superior universitaria") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Postgrado`= bd$niv_inst == "Postgrado") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") * (`Sin información`= bd$niv_inst == "Sin información") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Ninguno`= bd$niv_inst == "Ninguno") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Centro de alfabetización`= bd$niv_inst == "Centro de alfabetización") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Primaria`= bd$niv_inst == "Primaria") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Educación Básica`= bd$niv_inst == "Educación Básica") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Secundaria`= bd$niv_inst == "Secundaria") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Educación media/Bachillerato`= bd$niv_inst == "Educación media/Bachillerato") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Superior no universitaria`= bd$niv_inst == "Superior no universitaria") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Superior universitaria`= bd$niv_inst == "Superior universitaria") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Postgrado`= bd$niv_inst == "Postgrado") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") * (`Sin información`= bd$niv_inst == "Sin información") +
    (`Exterior:`= bd$reg_res == "Exterior:") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`Educación Básica`= bd$niv_inst == "Educación Básica") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`Secundaria`= bd$niv_inst == "Secundaria") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`Educación media/Bachillerato`= bd$niv_inst == "Educación media/Bachillerato") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`Sin información`= bd$niv_inst == "Sin información") ~  
    (
      (`Total`= bd$t) * (sum) +
        (`Hijos`= bd$t) * (sum) * (`1`= bd$hvivos == "1") +
        (`Hijos`= bd$t) * (sum) * (`2`= bd$hvivos == "2") +
        (`Hijos`= bd$t) * (sum) * (`3`= bd$hvivos == "3") +
        (`Hijos`= bd$t) * (sum) * (`4`= bd$hvivos == "4") +
        (`Hijos`= bd$t) * (sum) * (`5`= bd$hvivos == "5") +
        (`Hijos`= bd$t) * (sum) * (`6`= bd$hvivos == "6") +
        (`Hijos`= bd$t) * (sum) * (`7`= bd$hvivos == "7") +
        (`Hijos`= bd$t) * (sum) * (`8`= bd$hvivos == "8") +
        (`Hijos`= bd$t) * (sum) * (`9`= bd$hvivos == "9") +
        (`Hijos`= bd$t) * (sum) * (`10 y mas`= bd$hvivos == "10 y mas")
    ),
  data = bd)

print(tabla3.1.11)

write.csv.tabular(tabla3.1.11, file = "Tabla 3.1.11.csv")

# Cuadro No. 3.1.12
# Nacidos vivos en el año (t), por autoidentificación étnica de la madre, según región y provincia de residencia habitual

# Tabulado

tabla3.1.12 <- tabular(
  (`Provincias`= bd$prov_res) ~  
    (
      (`Total`= bd$t) * (sum) +
        (`Indígena`= bd$t) * (sum) * (`1`= bd$etnia == 1) +
        (`Afro-ecuatoriana`= bd$t) * (sum) * (`2`= bd$etnia == 2) +
        (`Negra`= bd$t) * (sum) * (`3`= bd$etnia == 3) +
        (`Mulata`= bd$t) * (sum) * (`4`= bd$etnia == 4) +
        (`Montubia`= bd$t) * (sum) * (`5`= bd$etnia == 5) +
        (`Mestiza`= bd$t) * (sum) * (`6`= bd$etnia == 6) +
        (`Blanca`= bd$t) * (sum) * (`7`= bd$etnia == 7) +
        (`Otra`= bd$t) * (sum) * (`8`= bd$etnia == 8) +
        (`Sin información`= bd$t) * (sum) * (`9`= bd$etnia == 9)
    ),
  data = bd)

print(tabla3.1.12)

write.csv.tabular(tabla3.1.12, file = "Tabla 3.1.12.csv")

# Cuadro No. 3.1.13
# Nacidos vivos en el año (t), por estado civil de la madre, según región y provincia de residencia habitual de la madre ------------------

# Tabulado

tabla3.1.13 <- tabular(
  (`Región Sierra:`= bd$reg_res == "Región Sierra:") +
    (`Azuay`= bd$prov_res == "AZUAY") +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") +
    (`Cañar`= bd$prov_res == "CAÑAR") +
    (`Carchi`= bd$prov_res == "CARCHI") +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") +
    (`Imbabura`= bd$prov_res == "IMBABURA") +
    (`Loja`= bd$prov_res == "LOJA") +
    (`Pichincha`= bd$prov_res == "PICHINCHA") +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") +
    (`El Oro`= bd$prov_res == "EL ORO") +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS") +
    (`Guayas`= bd$prov_res == "GUAYAS") +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") +
    (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") +
    (`Napo`= bd$prov_res == "NAPO") +
    (`Pastaza`= bd$prov_res == "PASTAZA") +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") +
    (`Orellana`= bd$prov_res == "ORELLANA") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") +
    (`Exterior:`= bd$reg_res == "Exterior:") ~  
    (
      (`Total`= bd$t) * (sum) +
        (`Unión libre`= bd$t) * (sum) * (`1`= bd$est_civil == 1) +
        (`Soltera`= bd$t) * (sum) * (`2`= bd$est_civil == 2) +
        (`Casada`= bd$t) * (sum) * (`3`= bd$est_civil == 3) +
        (`Divorciada`= bd$t) * (sum) * (`4`= bd$est_civil == 4) +
        (`Separada`= bd$t) * (sum) * (`5`= bd$est_civil == 5) +
        (`Viuda`= bd$t) * (sum) * (`6`= bd$est_civil == 6) +
        (`Unión de hecho`= bd$t) * (sum) * (`7`= bd$est_civil == 7) +
        (`Sin información`= bd$t) * (sum) * (`9`= bd$est_civil == 9)
    ),
  data = bd)

print(tabla3.1.13)

write.csv.tabular(tabla3.1.13, file = "Tabla 3.1.13.csv")

# Cuadro No. 3.1.14
# Nacidos vivos en el año (t), por provincia de nacimiento y sexo del nacido vivo
# Tabulado

tabla3.1.14 <- tabular(
  (`Provincias`= bd$prov_nac) ~  
    (
      (`Total`= bd$t) * (sum) +
        (`Hombre`= bd$t) * (sum) * (`1`= bd$sexo == "Hombre") +
        (`Mujwe`= bd$t) * (sum) * (`2`= bd$sexo == "Mujer")
    ),
  data = bd)

print(tabla3.1.14)

write.csv.tabular(tabla3.1.14, file = "Tabla 3.1.14.csv")

# Cuadro No. 3.1.15
# Nacidos vivos en el año (t), por provincia de nacimiento y provincia de residencia habitual de la madre ---------------------------------

# Tabulado

tabla3.1.15 <- tabular(
  (`Provincias`= bd$prov_nac) ~  
    (
      (`Total`= bd$t) * (sum) +
        (`Provincias`= bd$t) * (sum) * (`1`= bd$prov_res)
    ),
  data = bd)

print(tabla3.1.15)

write.csv.tabular(tabla3.1.15, file = "Tabla 3.1.15.csv")

# Cuadro No. 3.1.16
# Nacidos vivos en el año (t), por provincia de nacimiento y mes de nacimiento

# Tabulado

tabla3.1.16 <- tabular(
  (`Provincias`= bd$prov_nac) ~  
    (
      (`Total`= bd$t) * (sum) +
        (`Enero`= bd$t) * (sum) * (`1`= bd$mes_nac == 1) +
        (`Febrero`= bd$t) * (sum) * (`2`= bd$mes_nac == 2) +
        (`Marzo`= bd$t) * (sum) * (`3`= bd$mes_nac == 3) +
        (`Abril`= bd$t) * (sum) * (`4`= bd$mes_nac == 4) +
        (`Mayo`= bd$t) * (sum) * (`5`= bd$mes_nac == 5) +
        (`Junio`= bd$t) * (sum) * (`6`= bd$mes_nac == 6) +
        (`Julio`= bd$t) * (sum) * (`7`= bd$mes_nac == 7) +
        (`Agosto`= bd$t) * (sum) * (`8`= bd$mes_nac == 8) +
        (`Septiembre`= bd$t) * (sum) * (`9`= bd$mes_nac == 9) +
        (`Octubre`= bd$t) * (sum) * (`10`= bd$mes_nac == 10) +
        (`Noviembre`= bd$t) * (sum) * (`11`= bd$mes_nac == 11) +
        (`Diciembre`= bd$t) * (sum) * (`12`= bd$mes_nac == 12)
    ),
  data = bd)

print(tabla3.1.16)

write.csv.tabular(tabla3.1.16, file = "Tabla 3.1.16.csv")

# Cuadro No. 3.1.17
# Nacidos vivos en el año (t), por provincia de residencia habitual, grupos de edad y nivel de instrucción de la madre

# Tabulado

tabla3.1.17 <- tabular(
  (`Rango de edad`= bd$edadm) +
    (`Azuay`= bd$prov_res == "AZUAY") +
    (`Azuay`= bd$prov_res == "AZUAY") * (`Edadm`= bd$edadm) +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") * (`Edadm`= bd$edadm) +
    (`Cañar`= bd$prov_res == "CAÑAR") +
    (`Cañar`= bd$prov_res == "CAÑAR") * (`Edadm`= bd$edadm) +
    (`Carchi`= bd$prov_res == "CARCHI") +
    (`Carchi`= bd$prov_res == "CARCHI") * (`Edadm`= bd$edadm) +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") * (`Edadm`= bd$edadm) +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") * (`Edadm`= bd$edadm) +
    (`Imbabura`= bd$prov_res == "IMBABURA") +
    (`Imbabura`= bd$prov_res == "IMBABURA") * (`Edadm`= bd$edadm) +
    (`Loja`= bd$prov_res == "LOJA") +
    (`Loja`= bd$prov_res == "LOJA") * (`Edadm`= bd$edadm) +
    (`Pichincha`= bd$prov_res == "PICHINCHA") +
    (`Pichincha`= bd$prov_res == "PICHINCHA") * (`Edadm`= bd$edadm) +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") * (`Edadm`= bd$edadm) +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") * (`Edadm`= bd$edadm) +
    (`El Oro`= bd$prov_res == "EL ORO") +
    (`El Oro`= bd$prov_res == "EL ORO") * (`Edadm`= bd$edadm) +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS" ) +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS" ) * (`Edadm`= bd$edadm) +
    (`Guayas`= bd$prov_res == "GUAYAS") +
    (`Guayas`= bd$prov_res == "GUAYAS") * (`Edadm`= bd$edadm) +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") * (`Edadm`= bd$edadm) +
    (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Manabí`= bd$prov_res == "MANABÍ") * (`Edadm`= bd$edadm) +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") * (`Edadm`= bd$edadm) +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") * (`Edadm`= bd$edadm) +
    (`Napo`= bd$prov_res == "NAPO") +
    (`Napo`= bd$prov_res == "NAPO") * (`Edadm`= bd$edadm) +
    (`Pastaza`= bd$prov_res == "PASTAZA") +
    (`Pastaza`= bd$prov_res == "PASTAZA") * (`Edadm`= bd$edadm) +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") * (`Edadm`= bd$edadm) +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") * (`Edadm`= bd$edadm) +
    (`Orellana`= bd$prov_res == "ORELLANA") +
    (`Orellana`= bd$prov_res == "ORELLANA") * (`Edadm`= bd$edadm) +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") * (`Edadm`= bd$edadm) +
    (`Exterior:`= bd$reg_res == "Exterior:") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`25 - 29 años:`= bd$edadm == "25 - 29 años:") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`30 - 34 años:`= bd$edadm == "30 - 34 años:") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`35 - 39 años:`= bd$edadm == "35 - 39 años:") ~  
    (
      (`Total`= bd$t) * (sum) +
        (`Ninguno`= bd$t) * (sum) * (`0`= bd$niv_inst == "Ninguno") +
        (`Centro de alfabetización`= bd$t) * (sum) * (`1`= bd$niv_inst == "Centro de alfabetización") +
        (`Primaria`= bd$t) * (sum) * (`2`= bd$niv_inst == "Primaria") +
        (`Secundaria`= bd$t) * (sum) * (`3`= bd$niv_inst == "Secundaria") +
        (`Educación básica`= bd$t) * (sum) * (`4`= bd$niv_inst == "Educación Básica") +
        (`Educación media/bachillerato`= bd$t) * (sum) * (`5`= bd$niv_inst == "Educación media/Bachillerato") +
        (`Superior no universitario`= bd$t) * (sum) * (`6`= bd$niv_inst == "Superior no universitaria") +
        (`Superior universitario`= bd$t) * (sum) * (`7`= bd$niv_inst ==  "Superior universitaria") +
        (`Posgrado`= bd$t) * (sum) * (`8`= bd$niv_inst == "Postgrado") +
        (`Sin Informacion`= bd$t) * (sum) * (`9`= bd$niv_inst == "Sin información")
    ),
  data = bd)

print(tabla3.1.17)

write.csv.tabular(tabla3.1.17, file = "Tabla 3.1.17.csv")

# Cuadro No. 3.1.18
# Nacidos vivos en el año (t), por provincia de residencia habitual, grupos de edad y sexo del nacido vivo

# Tabulado

tabla3.1.18 <- tabular(
  (`Rango de edad`= bd$edadm) +
    (`Azuay`= bd$prov_res == "AZUAY") +
    (`Azuay`= bd$prov_res == "AZUAY") * (`Edadm`= bd$edadm) +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") * (`Edadm`= bd$edadm) +
    (`Cañar`= bd$prov_res == "CAÑAR") +
    (`Cañar`= bd$prov_res == "CAÑAR") * (`Edadm`= bd$edadm) +
    (`Carchi`= bd$prov_res == "CARCHI") +
    (`Carchi`= bd$prov_res == "CARCHI") * (`Edadm`= bd$edadm) +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") * (`Edadm`= bd$edadm) +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") * (`Edadm`= bd$edadm) +
    (`Imbabura`= bd$prov_res == "IMBABURA") +
    (`Imbabura`= bd$prov_res == "IMBABURA") * (`Edadm`= bd$edadm) +
    (`Loja`= bd$prov_res == "LOJA") +
    (`Loja`= bd$prov_res == "LOJA") * (`Edadm`= bd$edadm) +
    (`Pichincha`= bd$prov_res == "PICHINCHA") +
    (`Pichincha`= bd$prov_res == "PICHINCHA") * (`Edadm`= bd$edadm) +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") * (`Edadm`= bd$edadm) +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") * (`Edadm`= bd$edadm) +
    (`El Oro`= bd$prov_res == "EL ORO") +
    (`El Oro`= bd$prov_res == "EL ORO") * (`Edadm`= bd$edadm) +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS" ) +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS" ) * (`Edadm`= bd$edadm) +
    (`Guayas`= bd$prov_res == "GUAYAS") +
    (`Guayas`= bd$prov_res == "GUAYAS") * (`Edadm`= bd$edadm) +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") * (`Edadm`= bd$edadm) +
    (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Manabí`= bd$prov_res == "MANABÍ") * (`Edadm`= bd$edadm) +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") * (`Edadm`= bd$edadm) +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") * (`Edadm`= bd$edadm) +
    (`Napo`= bd$prov_res == "NAPO") +
    (`Napo`= bd$prov_res == "NAPO") * (`Edadm`= bd$edadm) +
    (`Pastaza`= bd$prov_res == "PASTAZA") +
    (`Pastaza`= bd$prov_res == "PASTAZA") * (`Edadm`= bd$edadm) +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") * (`Edadm`= bd$edadm) +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") * (`Edadm`= bd$edadm) +
    (`Orellana`= bd$prov_res == "ORELLANA") +
    (`Orellana`= bd$prov_res == "ORELLANA") * (`Edadm`= bd$edadm) +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") * (`Edadm`= bd$edadm) +
    (`Exterior:`= bd$reg_res == "Exterior:") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`25 - 29 años:`= bd$edadm == "25 - 29 años:") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`30 - 34 años:`= bd$edadm == "30 - 34 años:") +
    (`Exterior:`= bd$reg_res == "Exterior:") * (`35 - 39 años:`= bd$edadm == "35 - 39 años:") ~  
    (
      (`Total`= bd$t) * (sum) +
        (`Hombre`= bd$t) * (sum) * (`1`= bd$sexo == "Hombre") +
        (`Mujer`= bd$t) * (sum) * (`2`= bd$sexo == "Mujer")
    ),
  data = bd)

print(tabla3.1.18)

write.csv.tabular(tabla3.1.18, file = "Tabla 3.1.18.csv")

# Cuadro No. 3.1.19
# Nacidos vivos en el año (t), por provincia de nacimiento, lugar de ocurrencia y persona que asistió durante el parto
# Asignar etiquetas a la variable lugar_ocur

bd$lugar_ocur = factor(bd$lugar_ocur,
                   levels = c(1, 
                              2, 
                              3, 
                              4, 
                              5,
                              6, 
                              7, 
                              9),
                   labels = c("Establecimiento del Ministerio de Salud", 
                              "Establecimiento del IESS", 
                              "Establecimiento de la Junta de Beneficencia", 
                              "Otro Establecimiento Público", 
                              "Hospital, Clínica o Consultorio Privado",
                              "Casa", 
                              "Otro", 
                              "Sin información"),
                   ordered = FALSE)

# Tabulado

tabla3.1.19 <- tabular(
  (`Lugar`= bd$lugar_ocur) +
    (`Azuay`= bd$prov_nac == "AZUAY") +
    (`Azuay`= bd$prov_nac == "AZUAY") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Bolívar`= bd$prov_nac == "BOLÍVAR") +
    (`Bolívar`= bd$prov_nac == "BOLÍVAR") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Cañar`= bd$prov_nac == "CAÑAR") +
    (`Cañar`= bd$prov_nac == "CAÑAR") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Carchi`= bd$prov_nac == "CARCHI") +
    (`Carchi`= bd$prov_nac == "CARCHI") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Cotopaxi`= bd$prov_nac == "COTOPAXI") +
    (`Cotopaxi`= bd$prov_nac == "COTOPAXI") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Chimborazo`= bd$prov_nac == "CHIMBORAZO") +
    (`Chimborazo`= bd$prov_nac == "CHIMBORAZO") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Imbabura`= bd$prov_nac == "IMBABURA") +
    (`Imbabura`= bd$prov_nac == "IMBABURA") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Loja`= bd$prov_nac == "LOJA") +
    (`Loja`= bd$prov_nac == "LOJA") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Pichincha`= bd$prov_nac == "PICHINCHA") +
    (`Pichincha`= bd$prov_nac == "PICHINCHA") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Tungurahua`= bd$prov_nac == "TUNGURAHUA") +
    (`Tungurahua`= bd$prov_nac == "TUNGURAHUA") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Santo Domingo de los Tsáchilas`= bd$prov_nac == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_nac == "SANTO DOMINGO DE LOS TSÁCHILAS") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`El Oro`= bd$prov_nac == "EL ORO") +
    (`El Oro`= bd$prov_nac == "EL ORO") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Esmeraldas`= bd$prov_nac == "ESMERALDAS" ) +
    (`Esmeraldas`= bd$prov_nac == "ESMERALDAS" ) * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Guayas`= bd$prov_nac == "GUAYAS") +
    (`Guayas`= bd$prov_nac == "GUAYAS") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Los Ríos`= bd$prov_nac == "LOS RÍOS") +
    (`Los Ríos`= bd$prov_nac == "LOS RÍOS") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Manabí`= bd$prov_nac == "MANABÍ") +
    (`Manabí`= bd$prov_nac == "MANABÍ") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Santa Elena`= bd$prov_nac == "SANTA ELENA") +
    (`Santa Elena`= bd$prov_nac == "SANTA ELENA") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Morona Santiago`= bd$prov_nac == "MORONA SANTIAGO") +
    (`Morona Santiago`= bd$prov_nac == "MORONA SANTIAGO") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Napo`= bd$prov_nac == "NAPO") +
    (`Napo`= bd$prov_nac == "NAPO") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Pastaza`= bd$prov_nac == "PASTAZA") +
    (`Pastaza`= bd$prov_nac == "PASTAZA") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Zamora Chinchipe`= bd$prov_nac == "ZAMORA CHINCHIPE") +
    (`Zamora Chinchipe`= bd$prov_nac == "ZAMORA CHINCHIPE") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Sucumbíos`= bd$prov_nac == "SUCUMBÍOS") +
    (`Sucumbíos`= bd$prov_nac == "SUCUMBÍOS") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Orellana`= bd$prov_nac == "ORELLANA") +
    (`Orellana`= bd$prov_nac == "ORELLANA") * (`Lugar_ocur`= bd$lugar_ocur) +
    (`Galápagos`= bd$prov_nac == "GALÁPAGOS") +
    (`Galápagos`= bd$prov_nac == "GALÁPAGOS") * (`Lugar_ocur`= bd$lugar_ocur) ~
    (
      (`Total`= bd$t) * (sum) +
        (`Asistido por`= bd$t) * (sum) * (`1`= bd$asis_por) 
    ),
  data = bd)

print(tabla3.1.19)

write.csv.tabular(tabla3.1.19, file = "Tabla 3.1.19.csv")

# Cuadro No. 3.1.20
# Nacidos vivos en el año (t), por lugar de residencia habitual de la madre, semanas de gestación y peso del nacido vivo (en gramos) ----------------------

# Crear la variable semg para clasificar por semana de gestación

bd <- bd %>%
  mutate(semg = if_else(anio_nac == 2024 & (sem_gest >= 21 & sem_gest <= 23), 1, 0),
         semg = if_else(anio_nac == 2024 & (sem_gest >= 24 & sem_gest <= 26), 2, semg),
         semg = if_else(anio_nac == 2024 & (sem_gest >= 27 & sem_gest <= 29), 3, semg),
         semg = if_else(anio_nac == 2024 & (sem_gest >= 30 & sem_gest <= 32), 4, semg),
         semg = if_else(anio_nac == 2024 & (sem_gest >= 33 & sem_gest <= 35), 5, semg),
         semg = if_else(anio_nac == 2024 & (sem_gest >= 36 & sem_gest <= 38), 6, semg),
         semg = if_else(anio_nac == 2024 & (sem_gest >= 39 & sem_gest <= 41), 7, semg),
         semg = if_else(anio_nac == 2024 & (sem_gest == 42), 8, semg),
         semg = if_else(anio_nac == 2024 & (sem_gest == 99), 9, semg))

  bd <- apply_labels(bd, semg = "Semana de gestacion")

as.numeric(bd$semg)

# Asignar categorías a la variable semg

bd$semg = factor(bd$semg,
                  levels = c(1, 2, 3, 4,
                             5, 6, 7, 8,
                             9),
                  labels = c("De 21 a 23 semanas", "De 24 a 26 semanas", "De 27 a 29 semanas", "De 30 a 32 semanas",
                             "De 33 a 35 semanas", "De 36 a 38 semanas", "De 39 a 41 semanas", "De 42 semanas",
                             "Sin información"),
                  ordered = FALSE)

# Crear la variable pesogrupo para clasificar por peso del nacido

bd <- bd %>%
  mutate(pesogrupo = if_else(anio_nac == 2024 & (peso >= 500 & peso <= 999), 1, 0),
         pesogrupo = if_else(anio_nac == 2024 & (peso >= 1000 & peso <= 1499), 2, pesogrupo),
         pesogrupo = if_else(anio_nac == 2024 & (peso >= 1500 & peso <= 1999), 3, pesogrupo),
         pesogrupo = if_else(anio_nac == 2024 & (peso >= 2000 & peso <= 2499), 4, pesogrupo),
         pesogrupo = if_else(anio_nac == 2024 & (peso >= 2500 & peso <= 2999), 5, pesogrupo),
         pesogrupo = if_else(anio_nac == 2024 & (peso >= 3000 & peso <= 3499), 6, pesogrupo),
         pesogrupo = if_else(anio_nac == 2024 & (peso >= 3500 & peso <= 3999), 7, pesogrupo),
         pesogrupo = if_else(anio_nac == 2024 & (peso >= 4000 & peso <= 4499), 8, pesogrupo),
         pesogrupo = if_else(anio_nac == 2024 & (peso >= 4500 & peso <= 4999), 9, pesogrupo),
         pesogrupo = if_else(anio_nac == 2024 & (peso >= 5000 & peso <= 5500), 10, pesogrupo),
         pesogrupo = if_else(anio_nac == 2024 & (peso == 99), 11, pesogrupo))

bd <- apply_labels(bd, pesogrupo = "Peso")

as.numeric(bd$pesogrupo)

# Asignar categorías a la variable pesogrupo

bd$pesogrupo = factor(bd$pesogrupo,
                 levels = c(1, 2, 3, 4,
                            5, 6, 7, 8,
                            9, 10, 11),
                 labels = c("De 500 g a 999 g", "De 1000 g a 1499 g", "De 1500 g a 1999 g", "De 2000 g a 2499 g",
                            "De 2500 g a 2999 g", "De 3000 g a 3499 g", "De 3500 g a 3999 g", "De 4000 g a 4499 g",
                            "De 4500 g a 4999 g", "De 5000 g a 5500 g", "Sin información"),
                 ordered = FALSE)

# Tabulado

tabla3.1.20 <- tabular(
  (`Semanas`= bd$semg) +
    (`Azuay`= bd$prov_res == "AZUAY") +
    (`Azuay`= bd$prov_res == "AZUAY") * (`Semg`= bd$semg) +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") * (`Semg`= bd$semg) +
    (`Cañar`= bd$prov_res == "CAÑAR") +
    (`Cañar`= bd$prov_res == "CAÑAR") * (`Semg`= bd$semg) +
    (`Carchi`= bd$prov_res == "CARCHI") +
    (`Carchi`= bd$prov_res == "CARCHI") * (`Semg`= bd$semg) +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") * (`Semg`= bd$semg) +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") * (`Semg`= bd$semg) +
    (`Imbabura`= bd$prov_res == "IMBABURA") +
    (`Imbabura`= bd$prov_res == "IMBABURA") * (`Semg`= bd$semg) +
    (`Loja`= bd$prov_res == "LOJA") +
    (`Loja`= bd$prov_res == "LOJA") * (`Semg`= bd$semg) +
    (`Pichincha`= bd$prov_res == "PICHINCHA") +
    (`Pichincha`= bd$prov_res == "PICHINCHA") * (`Semg`= bd$semg) +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") * (`Semg`= bd$semg) +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") * (`Semg`= bd$semg) +
    (`El Oro`= bd$prov_res == "EL ORO") +
    (`El Oro`= bd$prov_res == "EL ORO") * (`Semg`= bd$semg) +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS" ) +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS" ) * (`Semg`= bd$semg) +
    (`Guayas`= bd$prov_res == "GUAYAS") +
    (`Guayas`= bd$prov_res == "GUAYAS") * (`Semg`= bd$semg) +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") * (`Semg`= bd$semg) +
    (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Manabí`= bd$prov_res == "MANABÍ") * (`Semg`= bd$semg) +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") * (`Semg`= bd$semg) +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") * (`Semg`= bd$semg) +
    (`Napo`= bd$prov_res == "NAPO") +
    (`Napo`= bd$prov_res == "NAPO") * (`Semg`= bd$semg) +
    (`Pastaza`= bd$prov_res == "PASTAZA") +
    (`Pastaza`= bd$prov_res == "PASTAZA") * (`Semg`= bd$semg) +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") * (`Semg`= bd$semg) +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") * (`Semg`= bd$semg) +
    (`Orellana`= bd$prov_res == "ORELLANA") +
    (`Orellana`= bd$prov_res == "ORELLANA") * (`Semg`= bd$semg) +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") * (`Semg`= bd$semg) ~
    (
      (`Total`= bd$t) * (sum) +
        (`Peso`= bd$t) * (sum) * (`1`= bd$pesogrupo) 
    ),
  data = bd)

print(tabla3.1.20)

write.csv.tabular(tabla3.1.20, file = "Tabla 3.1.20.csv")

# Cuadro No. 3.1.21
# Promedio de controles prenatales de nacidos vivos en el año (t), por lugar de residencia habitual de la madre y frupo de edad -----------------

# Tabulado

tabla3.1.21 <- tabular(
  (`Provincias`= bd$prov_res) ~  
    (
      (`Total`= bd$con_pren) * (mean) +
        (`Edad`= bd$con_pren) * (mean) * (`1`= bd$edadm) 
    ),
  data = bd)

print(tabla3.1.21)

write.csv.tabular(tabla3.1.21, file = "Tabla 3.1.21.csv")

# Cuadro No. 3.1.22
# Nacidos vivos en el año (t), por bajo peso al nacer y lugar de residencia habitual de la madre -------------------------------------

# Creamos la variable t1 para determinar el Total de la variable peso < 2500g 

bd <- bd %>% mutate(t1 = if_else(anio_nac == 2024 & (peso >= 500 & peso <= 2499), 1, 0))

bd <- apply_labels(bd, t1="Total peso")

as.numeric(bd$t1)

# Tabulado

tabla3.1.22 <- tabular(
  (`Región Sierra:`= bd$reg_res == "Región Sierra:") +
    (`Azuay`= bd$prov_res == "AZUAY") +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") +
    (`Cañar`= bd$prov_res == "CAÑAR") +
    (`Carchi`= bd$prov_res == "CARCHI") +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") +
    (`Imbabura`= bd$prov_res == "IMBABURA") +
    (`Loja`= bd$prov_res == "LOJA") +
    (`Pichincha`= bd$prov_res == "PICHINCHA") +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Región Costa:`= bd$reg_res == "Región Costa:") +
    (`El Oro`= bd$prov_res == "EL ORO") +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS") +
    (`Guayas`= bd$prov_res == "GUAYAS") +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") +
    (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") +
    (`Región Amazónica:`= bd$reg_res == "Región Amazónica:") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") +
    (`Napo`= bd$prov_res == "NAPO") +
    (`Pastaza`= bd$prov_res == "PASTAZA") +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") +
    (`Orellana`= bd$prov_res == "ORELLANA") +
    (`Región Insular:`= bd$reg_res == "Región Insular:") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") +
    (`Exterior:`= bd$reg_res == "Exterior:") ~ 
    (
      (`Total < 2500 g`= bd$t1) * (sum) +
        (`Menor a 999 g`= bd$t) * (sum) * (`1`= bd$pesogrupo == "De 500 g a 999 g") +
        (`De 1000 g a 1499 g`= bd$t) * (sum) * (`2`= bd$pesogrupo == "De 1000 g a 1499 g") +
        (`De 1500 g a 1999 g`= bd$t) * (sum) * (`3`= bd$pesogrupo == "De 1500 g a 1999 g") +
        (`De 2000 g a 2499 g`= bd$t) * (sum) * (`4`= bd$pesogrupo == "De 2000 g a 2499 g")
    ),
  data = bd)

print(tabla3.1.22)

write.csv.tabular(tabla3.1.22, file = "Tabla 3.1.22.csv")

# Cuadro No. 3.1.23
# Nacidos vivos en el año (t),  por provincia y cantón de residencia según etnia de la madre

# Tabulado

tabla3.1.23 <- tabular(
  (`Región Sierra:`= bd$reg_nac == "Región Sierra:") +
    (`Azuay`= bd$prov_res == "AZUAY") +
    (`Cuenca`= bd$cant_res == "Cuenca") +
    (`Girón`= bd$cant_res == "Girón") +
    (`Gualaceo`= bd$cant_res == "Gualaceo") +
    (`Nabón`= bd$cant_res == "Nabón") +
    (`Paute`= bd$cant_res == "Paute") +
    (`Pucará`= bd$cant_res == "Pucará") +
    (`San Fernando`= bd$cant_res == "San Fernando") +
    (`Santa Isabel`= bd$cant_res == "Santa Isabel") +
    (`Sigsig`= bd$cant_res == "Sigsig") +
    (`Oña`= bd$cant_res == "Oña") +
    (`Chordeleg`= bd$cant_res == "Chordeleg") +
    (`El Pan`= bd$cant_res == "El Pan") + 
    (`Sevilla De Oro`= bd$cant_res == "Sevilla De Oro") +
    (`Guachapala`= bd$cant_res == "Guachapala") +
    (`Camilo Ponce Enríquez`= bd$cant_res == "Camilo Ponce Enríquez") +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") +
    (`Guaranda`= bd$cant_res == "Guaranda") +
    (`Chillanes`= bd$cant_res == "Chillanes") +
    (`Chimbo`= bd$cant_res == "Chimbo") +
    (`Echeandia`= bd$cant_res == "Echeandia") +
    (`San Miguel`= bd$cant_res == "San Miguel") +
    (`Caluma`= bd$cant_res== "Caluma") +
    (`Las Naves`= bd$cant_res == "Las Naves") +
    (`Cañar`= bd$prov_res == "CAÑAR") +
    (`Azogues`= bd$cant_res == "Azogues") +
    (`Biblian`= bd$cant_res == "Biblian") +
    (`Cañar`= bd$cant_res == "Cañar") +
    (`La Troncal`= bd$cant_res == "La Troncal") +
    (`El Tambo`= bd$cant_res == "El Tambo") +
    (`Deleg`= bd$cant_res == "Deleg") +
    (`Suscal`= bd$cant_res == "Suscal") +
    (`Carchi`= bd$prov_res == "CARCHI") +
    (`Tulcán`= bd$cant_res == "Tulcán") +
    (`Bolívar`= bd$cant_res == "Bolívar") * (`Carchi`= bd$prov_res == "CARCHI") +
    (`Espejo`= bd$cant_res == "Espejo") +
    (`Mira`= bd$cant_res == "Mira") +
    (`Montúfar`= bd$cant_res == "Montúfar") +
    (`San Pedro De Huaca`= bd$cant_res == "San Pedro De Huaca") +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") +
    (`Latacunga`= bd$cant_res == "Latacunga") +
    (`La Maná`= bd$cant_res == "La Maná") +
    (`Pangua`= bd$cant_res == "Pangua") +
    (`Pujilí`= bd$cant_res == "Pujilí") +
    (`Salcedo`= bd$cant_res == "Salcedo") +
    (`Saquisilí`= bd$cant_res == "Saquisilí") +
    (`Sigchos`= bd$cant_res == "Sigchos") +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") +
    (`Riobamba`= bd$cant_res == "Riobamba") +
    (`Alausí`= bd$cant_res == "Alausí") +
    (`Colta`= bd$cant_res == "Colta") +
    (`Chambo`= bd$cant_res == "Chambo") +
    (`Chunchi`= bd$cant_res == "Chunchi") +
    (`Guamote`= bd$cant_res == "Guamote") +
    (`Guano`= bd$cant_res == "Guano") +
    (`Pallatanga`= bd$cant_res == "Pallatanga") +
    (`Penípe`= bd$cant_res == "Penípe") +
    (`Cumandá`= bd$cant_res == "Cumandá") +
    (`Imbabura`= bd$prov_res == "IMBABURA") +
    (`Ibarra`= bd$cant_res == "Ibarra") +
    (`Antonio Ante`= bd$cant_res == "Antonio Ante") +
    (`Cotacahi`= bd$cant_res == "Cotacahi") +
    (`Otavalo`= bd$cant_res == "Otavalo") +
    (`Pimampiro`= bd$cant_res == "Pimampiro") +
    (`San Miguel De Urcuqui`= bd$cant_res == "San Miguel De Urcuqui") +
    (`Loja`= bd$prov_res == "LOJA") +
    (`Loja`= bd$cant_res == "Loja") +
    (`Calvas`= bd$cant_res == "Calvas") +
    (`Catamayo`= bd$cant_res == "Catamayo") +
    (`Célica`= bd$cant_res == "Célica") +
    (`Chaguarpamba`= bd$cant_res == "Chaguarpamba") +
    (`Espíndola`= bd$cant_res == "Espíndola") +
    (`Gonzanamá`= bd$cant_res == "Gonzanamá") +
    (`Macará`= bd$cant_res == "Macará") +
    (`Paltas`= bd$cant_res == "Paltas") +
    (`Puyango`= bd$cant_res == "Puyango") +
    (`Saraguro`= bd$cant_res == "Saraguro") +
    (`Sozoranga`= bd$cant_res == "Sozoranga") +
    (`Zapotillo`= bd$cant_res == "Zapotillo") +
    (`Pindal`= bd$cant_res == "Pindal") +
    (`Quilanga`= bd$cant_res == "Quilanga") +
    (`Olemdo`= bd$cant_res == "Olemdo") +
    (`Pichincha`= bd$prov_res == "PICHINCHA") +
    (`Quito`= bd$cant_res == "Quito") +
    (`Cayambe`= bd$cant_res == "Cayambe") +
    (`Mejía`= bd$cant_res == "Mejía") +
    (`Pedro Moncayo`= bd$cant_res == "Pedro Moncayo") +
    (`Rumiñahui`= bd$cant_res == "Rumiñahui") +
    (`San Miguel De Los Bancos`= bd$cant_res == "San Miguel De Los Bancos") +
    (`Pedro Vicente Maldonado`= bd$cant_res == "Pedro Vicente Maldonado") +
    (`Puerto Quito`= bd$cant_res == "Puerto Quito") +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") +
    (`Ambato`= bd$cant_res == "Ambato") +
    (`Baños De Agua Santa`= bd$cant_res == "Baños De Agua Santa") +
    (`Cevallos`= bd$cant_res == "Cevallos") +
    (`Mocha`= bd$cant_res == "Mocha") +
    (`Patate`= bd$cant_res == "Patate") +
    (`Quero`= bd$cant_res == "Quero") +
    (`San Pedro De Pelileo`= bd$cant_res == "San Pedro De Pelileo") +
    (`Santiago De Pillaro`= bd$cant_res == "Santiago De Pillaro") +
    (`Tisaleo`= bd$cant_res == "Tisaleo") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Santo Domingo`= bd$cant_res == "Santo Domingo") +
    (`La Condordia`= bd$cant_res == "La Condordia") +
    (`Región Costa:`= bd$reg_nac == "Región Costa:") +
    (`El Oro`= bd$prov_res == "EL ORO") +
    (`Machala`= bd$cant_res == "Machala") +
    (`Arenillas`= bd$cant_res == "Arenillas") +
    (`Atahualpa`= bd$cant_res == "Atahualpa") +
    (`Balsas`= bd$cant_res == "Balsas") +
    (`Chilla`= bd$cant_res == "Chilla") +
    (`El Guabo`= bd$cant_res == "El Guabo") +
    (`Huaquillas`= bd$cant_res == "Huaquillas") +
    (`Marcabelí`= bd$cant_res == "Marcabelí") +
    (`Pasaje`= bd$cant_res == "Pasaje") +
    (`Piñas`= bd$cant_res == "Piñas") +
    (`Portovelo`= bd$cant_res == "Portovelo") +
    (`Santa Rosa`= bd$cant_res == "Santa Rosa") +
    (`Zaruma`= bd$cant_res == "Zaruma") +
    (`Las Lajas`= bd$cant_res == "Las Lajas") +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS") +
    (`Esmeraldas`= bd$cant_res == "Esmeraldas") +
    (`Eloy Alfaro`= bd$cant_res == "Eloy Alfaro") +
    (`Muisne`= bd$cant_res == "Muisne") +
    (`Quininde`= bd$cant_res == "Quininde") +
    (`San Lorenzo`= bd$cant_res == "San Lorenzo") +
    (`Atacames`= bd$cant_res == "Atacames") +
    (`Ríoverde`= bd$cant_res == "Ríoverde") +
    (`Guayas`= bd$prov_res == "GUAYAS") +
    (`Guayaquil`= bd$cant_res == "Guayaquil") +
    (`Alfredo Baquerizo Moreno`= bd$cant_res == "Alfredo Baquerizo Moreno") +
    (`Balao`= bd$cant_res == "Balao") +
    (`Balzar`= bd$cant_res == "Balzar") +
    (`Colimes`= bd$cant_res == "Colimes") +
    (`Daule`= bd$cant_res == "Daule") +
    (`Durán`= bd$cant_res == "Durán") +
    (`Empalme`= bd$cant_res == "Empalme") +
    (`El Triunfo`= bd$cant_res == "El Triunfo") +
    (`Milagro`= bd$cant_res == "Milagro") +
    (`Naranjal`= bd$cant_res == "Naranjal") +
    (`Naranjito`= bd$cant_res == "Naranjito") +
    (`Palestina`= bd$cant_res == "Palestina") +
    (`Pedro Carbo`= bd$cant_res == "Pedro Carbo") +
    (`Samborondón`= bd$cant_res == "Samborondón") +
    (`Santa Lucia`= bd$cant_res == "Santa Lucia") +
    (`Salitre`= bd$cant_res == "Salitre") +
    (`San Jacinto De Yaguachi`= bd$cant_res == "San Jacinto De Yaguachi") +
    (`Playas`= bd$cant_res == "Playas") +
    (`Simón Bolívar`= bd$cant_res == "Simón Bolívar") +
    (`Crnel. Marcelino Maridueña`= bd$cant_res == "Crnel. Marcelino Maridueña") +
    (`Lomas De Sargentillo`= bd$cant_res == "Lomas De Sargentillo") +
    (`Nobol`= bd$cant_res == "Nobol") +
    (`Gnral. Antonio Elizalde`= bd$cant_res == "Gnral. Antonio Elizalde") +
    (`Isidro Ayora`= bd$cant_res == "Isidro Ayora") +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") +
    (`Babahoyo`= bd$cant_res == "Babahoyo") +
    (`Baba`= bd$cant_res == "Baba") +
    (`Montalvo`= bd$cant_res == "Montalvo") +
    (`Puebloviejo`= bd$cant_res == "Puebloviejo") +
    (`Quevedo`= bd$cant_res == "Quevedo") +
    (`Urdaneta`= bd$cant_res == "Urdaneta") +
    (`Ventanas`= bd$cant_res == "Ventanas") +
    (`Vinces`= bd$cant_res == "Vinces") +
    (`Palenque`= bd$cant_res == "Palenque") +
    (`Buena Fé`= bd$cant_res == "Buena Fé") +
    (`Valencia`= bd$cant_res == "Valencia") +
    (`Mocache`= bd$cant_res == "Mocache") +
    (`Quinsaloma`= bd$cant_res == "Quinsaloma") +
    (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Portoviejo`= bd$cant_res == "Portoviejo") +
    (`Bolívar`= bd$cant_res == "Bolívar") * (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Chone`= bd$cant_res == "Chone") +
    (`El Carmen`= bd$cant_res == "El Carmen") +
    (`Flavio Alfaro`= bd$cant_res == "Flavio Alfaro") +
    (`Jipijapa`= bd$cant_res == "Jipijapa") +
    (`Junín`= bd$cant_res == "Junín") +
    (`Manta`= bd$cant_res == "Manta") +
    (`Montecristi`= bd$cant_res == "Montecristi") +
    (`Paján`= bd$cant_res == "Paján") +
    (`Pichincha`= bd$cant_res == "Pichincha") +
    (`Rocafuerte`= bd$cant_res == "Rocafuerte") +
    (`Santa Ana`= bd$cant_res == "Santa Ana") +
    (`Sucre`= bd$cant_res == "Sucre") +
    (`Tosagua`= bd$cant_res == "Tosagua") +
    (`24 De Mayo`= bd$cant_res == "24 De Mayo") +
    (`Pedernales`= bd$cant_res == "Pedernales") +
    (`Olmedo`= bd$cant_res == "Olmedo") +
    (`Puerto López`= bd$cant_res == "Puerto López") +
    (`Jama`= bd$cant_res == "Jama") +
    (`Jaramijó`= bd$cant_res == "Jaramijó") +
    (`San Vicente`= bd$cant_res == "San Vicente") +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") +
    (`Santa Elena`= bd$cant_res == "Santa Elena") +
    (`La Libertad`= bd$cant_res == "La Libertad") +
    (`Salinas`= bd$cant_res == "Salinas") +
    (`Región Amazónica:`= bd$reg_nac == "Región Amazónica:") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") +
    (`Morona`= bd$cant_res == "Morona") +
    (`Gualaquiza`= bd$cant_res == "Gualaquiza") +
    (`Limón Indanza`= bd$cant_res == "Limón Indanza") +
    (`Palora`= bd$cant_res == "Palora") +
    (`Santiago`= bd$cant_res == "Santiago") +
    (`Sucúa`= bd$cant_res == "Sucúa") +
    (`Huamboya`= bd$cant_res == "Huamboya") +
    (`San Juan Bosco`= bd$cant_res == "San Juan Bosco") +
    (`Taisha`= bd$cant_res == "Taisha") +
    (`Logroño`= bd$cant_res == "Logroño") +
    (`Pablo Sexto`= bd$cant_res == "Pablo Sexto") +
    (`Tiwintza`= bd$cant_res == "Tiwintza") +
    (`Napo`= bd$prov_res == "NAPO") +
    (`Tena`= bd$cant_res == "Tena") +
    (`Archidona`= bd$cant_res == "Archidona") +
    (`El Chaco`= bd$cant_res == "El Chaco") +
    (`Quijos`= bd$cant_res == "Quijos") +
    (`Carlos Julio Arrosemena Tola`= bd$cant_res == "Carlos Julio Arrosemena Tola") +
    (`Pastaza`= bd$prov_res == "PASTAZA") +
    (`Pastaza`= bd$cant_res == "Pastaza")+
    (`Mera`= bd$cant_res == "Mera")+
    (`Santa Clara`= bd$cant_res == "Santa Clara") +
    (`Arajuno`= bd$cant_res == "Arajuno") +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") +
    (`Zamora`= bd$cant_res == "Zamora") +
    (`Chinchipe`= bd$cant_res == "Chinchipe") +
    (`Nangaritza`= bd$cant_res == "Nangaritza") +
    (`Yacuambi`= bd$cant_res == "Yacuambi") +
    (`Yantzaza`= bd$cant_res == "Yantzaza") +
    (`El Pangui`= bd$cant_res == "El Pangui") +
    (`Centinela Del Cóndor`= bd$cant_res == "Centinela Del Cóndor") +
    (`Palanda`= bd$cant_res == "Palanda") +
    (`Paquisha`= bd$cant_res == "Paquisha") +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") +
    (`Lago Agrio`= bd$cant_res == "Lago Agrio") +
    (`Gonzalo Pizarro`= bd$cant_res == "Gonzalo Pizarro") +
    (`Putumayo`= bd$cant_res == "Putumayo") +
    (`Shushufindi`= bd$cant_res == "Shushufindi") +
    (`Sucumbios`= bd$cant_res == "Sucumbios") +
    (`Cascales`= bd$cant_res == "Cascales") +
    (`Cuyabeno`= bd$cant_res == "Cuyabeno") +
    (`Orellana`= bd$prov_res == "ORELLANA") +
    (`Orellana`= bd$cant_res == "Orellana") +
    (`Aguarico`= bd$cant_res == "Aguarico") +
    (`La Joya De Los Sachas`= bd$cant_res == "La Joya De Los Sachas") +
    (`Loreto`= bd$cant_res == "Loreto") +
    (`Región Insular:`= bd$reg_nac == "Región Insular:") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") +
    (`San Cristobal`= bd$cant_res == "San Cristobal") +
    (`Isabela`= bd$cant_res == "Isabela") +
    (`Santa Cruz`= bd$cant_res == "Santa Cruz") +
    (`Exterior:`= bd$reg_nac == "Exterior:") ~
    (
      (`Total`= bd$t) * (sum) +
        (`Indígena`= bd$t) * (sum) * (`1`= bd$etnia == 1) +
        (`Afro-ecuatoriana`= bd$t) * (sum) * (`2`= bd$etnia == 2) +
        (`Negra`= bd$t) * (sum) * (`3`= bd$etnia == 3) +
        (`Mulata`= bd$t) * (sum) * (`4`= bd$etnia == 4) +
        (`Montubia`= bd$t) * (sum) * (`5`= bd$etnia == 5) +
        (`Mestiza`= bd$t) * (sum) * (`6`= bd$etnia == 6) +
        (`Blanca`= bd$t) * (sum) * (`7`= bd$etnia == 7) +
        (`Otra`= bd$t) * (sum) * (`8`= bd$etnia == 8) +
        (`Sin información`= bd$t) * (sum) * (`9`= bd$etnia == 9)
    ),
  data = bd)

print(tabla3.1.23)

write.csv.tabular(tabla3.1.23, file = "Tabla 3.1.23.csv")

# Cuadro No. 3.1.24
# Nacidos vivos en el año (t), por provincia y cantón de residencia según estado civil y/o conyugal de la madre

# Tabulado

tabla3.1.24 <- tabular(
  (`Región Sierra:`= bd$reg_nac == "Región Sierra:") +
    (`Azuay`= bd$prov_res == "AZUAY") +
    (`Cuenca`= bd$cant_res == "Cuenca") +
    (`Girón`= bd$cant_res == "Girón") +
    (`Gualaceo`= bd$cant_res == "Gualaceo") +
    (`Nabón`= bd$cant_res == "Nabón") +
    (`Paute`= bd$cant_res == "Paute") +
    (`Pucará`= bd$cant_res == "Pucará") +
    (`San Fernando`= bd$cant_res == "San Fernando") +
    (`Santa Isabel`= bd$cant_res == "Santa Isabel") +
    (`Sigsig`= bd$cant_res == "Sigsig") +
    (`Oña`= bd$cant_res == "Oña") +
    (`Chordeleg`= bd$cant_res == "Chordeleg") +
    (`El Pan`= bd$cant_res == "El Pan") + 
    (`Sevilla De Oro`= bd$cant_res == "Sevilla De Oro") +
    (`Guachapala`= bd$cant_res == "Guachapala") +
    (`Camilo Ponce Enríquez`= bd$cant_res == "Camilo Ponce Enríquez") +
    (`Bolívar`= bd$prov_res == "BOLÍVAR") +
    (`Guaranda`= bd$cant_res == "Guaranda") +
    (`Chillanes`= bd$cant_res == "Chillanes") +
    (`Chimbo`= bd$cant_res == "Chimbo") +
    (`Echeandia`= bd$cant_res == "Echeandia") +
    (`San Miguel`= bd$cant_res == "San Miguel") +
    (`Caluma`= bd$cant_res== "Caluma") +
    (`Las Naves`= bd$cant_res == "Las Naves") +
    (`Cañar`= bd$prov_res == "CAÑAR") +
    (`Azogues`= bd$cant_res == "Azogues") +
    (`Biblian`= bd$cant_res == "Biblian") +
    (`Cañar`= bd$cant_res == "Cañar") +
    (`La Troncal`= bd$cant_res == "La Troncal") +
    (`El Tambo`= bd$cant_res == "El Tambo") +
    (`Deleg`= bd$cant_res == "Deleg") +
    (`Suscal`= bd$cant_res == "Suscal") +
    (`Carchi`= bd$prov_res == "CARCHI") +
    (`Tulcán`= bd$cant_res == "Tulcán") +
    (`Bolívar`= bd$cant_res == "Bolívar") * (`Carchi`= bd$prov_res == "CARCHI") +
    (`Espejo`= bd$cant_res == "Espejo") +
    (`Mira`= bd$cant_res == "Mira") +
    (`Montúfar`= bd$cant_res == "Montúfar") +
    (`San Pedro De Huaca`= bd$cant_res == "San Pedro De Huaca") +
    (`Cotopaxi`= bd$prov_res == "COTOPAXI") +
    (`Latacunga`= bd$cant_res == "Latacunga") +
    (`La Maná`= bd$cant_res == "La Maná") +
    (`Pangua`= bd$cant_res == "Pangua") +
    (`Pujilí`= bd$cant_res == "Pujilí") +
    (`Salcedo`= bd$cant_res == "Salcedo") +
    (`Saquisilí`= bd$cant_res == "Saquisilí") +
    (`Sigchos`= bd$cant_res == "Sigchos") +
    (`Chimborazo`= bd$prov_res == "CHIMBORAZO") +
    (`Riobamba`= bd$cant_res == "Riobamba") +
    (`Alausí`= bd$cant_res == "Alausí") +
    (`Colta`= bd$cant_res == "Colta") +
    (`Chambo`= bd$cant_res == "Chambo") +
    (`Chunchi`= bd$cant_res == "Chunchi") +
    (`Guamote`= bd$cant_res == "Guamote") +
    (`Guano`= bd$cant_res == "Guano") +
    (`Pallatanga`= bd$cant_res == "Pallatanga") +
    (`Penípe`= bd$cant_res == "Penípe") +
    (`Cumandá`= bd$cant_res == "Cumandá") +
    (`Imbabura`= bd$prov_res == "IMBABURA") +
    (`Ibarra`= bd$cant_res == "Ibarra") +
    (`Antonio Ante`= bd$cant_res == "Antonio Ante") +
    (`Cotacahi`= bd$cant_res == "Cotacahi") +
    (`Otavalo`= bd$cant_res == "Otavalo") +
    (`Pimampiro`= bd$cant_res == "Pimampiro") +
    (`San Miguel De Urcuqui`= bd$cant_res == "San Miguel De Urcuqui") +
    (`Loja`= bd$prov_res == "LOJA") +
    (`Loja`= bd$cant_res == "Loja") +
    (`Calvas`= bd$cant_res == "Calvas") +
    (`Catamayo`= bd$cant_res == "Catamayo") +
    (`Célica`= bd$cant_res == "Célica") +
    (`Chaguarpamba`= bd$cant_res == "Chaguarpamba") +
    (`Espíndola`= bd$cant_res == "Espíndola") +
    (`Gonzanamá`= bd$cant_res == "Gonzanamá") +
    (`Macará`= bd$cant_res == "Macará") +
    (`Paltas`= bd$cant_res == "Paltas") +
    (`Puyango`= bd$cant_res == "Puyango") +
    (`Saraguro`= bd$cant_res == "Saraguro") +
    (`Sozoranga`= bd$cant_res == "Sozoranga") +
    (`Zapotillo`= bd$cant_res == "Zapotillo") +
    (`Pindal`= bd$cant_res == "Pindal") +
    (`Quilanga`= bd$cant_res == "Quilanga") +
    (`Olemdo`= bd$cant_res == "Olemdo") +
    (`Pichincha`= bd$prov_res == "PICHINCHA") +
    (`Quito`= bd$cant_res == "Quito") +
    (`Cayambe`= bd$cant_res == "Cayambe") +
    (`Mejía`= bd$cant_res == "Mejía") +
    (`Pedro Moncayo`= bd$cant_res == "Pedro Moncayo") +
    (`Rumiñahui`= bd$cant_res == "Rumiñahui") +
    (`San Miguel De Los Bancos`= bd$cant_res == "San Miguel De Los Bancos") +
    (`Pedro Vicente Maldonado`= bd$cant_res == "Pedro Vicente Maldonado") +
    (`Puerto Quito`= bd$cant_res == "Puerto Quito") +
    (`Tungurahua`= bd$prov_res == "TUNGURAHUA") +
    (`Ambato`= bd$cant_res == "Ambato") +
    (`Baños De Agua Santa`= bd$cant_res == "Baños De Agua Santa") +
    (`Cevallos`= bd$cant_res == "Cevallos") +
    (`Mocha`= bd$cant_res == "Mocha") +
    (`Patate`= bd$cant_res == "Patate") +
    (`Quero`= bd$cant_res == "Quero") +
    (`San Pedro De Pelileo`= bd$cant_res == "San Pedro De Pelileo") +
    (`Santiago De Pillaro`= bd$cant_res == "Santiago De Pillaro") +
    (`Tisaleo`= bd$cant_res == "Tisaleo") +
    (`Santo Domingo de los Tsáchilas`= bd$prov_res == "SANTO DOMINGO DE LOS TSÁCHILAS") +
    (`Santo Domingo`= bd$cant_res == "Santo Domingo") +
    (`La Condordia`= bd$cant_res == "La Condordia") +
    (`Región Costa:`= bd$reg_nac == "Región Costa:") +
    (`El Oro`= bd$prov_res == "EL ORO") +
    (`Machala`= bd$cant_res == "Machala") +
    (`Arenillas`= bd$cant_res == "Arenillas") +
    (`Atahualpa`= bd$cant_res == "Atahualpa") +
    (`Balsas`= bd$cant_res == "Balsas") +
    (`Chilla`= bd$cant_res == "Chilla") +
    (`El Guabo`= bd$cant_res == "El Guabo") +
    (`Huaquillas`= bd$cant_res == "Huaquillas") +
    (`Marcabelí`= bd$cant_res == "Marcabelí") +
    (`Pasaje`= bd$cant_res == "Pasaje") +
    (`Piñas`= bd$cant_res == "Piñas") +
    (`Portovelo`= bd$cant_res == "Portovelo") +
    (`Santa Rosa`= bd$cant_res == "Santa Rosa") +
    (`Zaruma`= bd$cant_res == "Zaruma") +
    (`Las Lajas`= bd$cant_res == "Las Lajas") +
    (`Esmeraldas`= bd$prov_res == "ESMERALDAS") +
    (`Esmeraldas`= bd$cant_res == "Esmeraldas") +
    (`Eloy Alfaro`= bd$cant_res == "Eloy Alfaro") +
    (`Muisne`= bd$cant_res == "Muisne") +
    (`Quininde`= bd$cant_res == "Quininde") +
    (`San Lorenzo`= bd$cant_res == "San Lorenzo") +
    (`Atacames`= bd$cant_res == "Atacames") +
    (`Ríoverde`= bd$cant_res == "Ríoverde") +
    (`Guayas`= bd$prov_res == "GUAYAS") +
    (`Guayaquil`= bd$cant_res == "Guayaquil") +
    (`Alfredo Baquerizo Moreno`= bd$cant_res == "Alfredo Baquerizo Moreno") +
    (`Balao`= bd$cant_res == "Balao") +
    (`Balzar`= bd$cant_res == "Balzar") +
    (`Colimes`= bd$cant_res == "Colimes") +
    (`Daule`= bd$cant_res == "Daule") +
    (`Durán`= bd$cant_res == "Durán") +
    (`Empalme`= bd$cant_res == "Empalme") +
    (`El Triunfo`= bd$cant_res == "El Triunfo") +
    (`Milagro`= bd$cant_res == "Milagro") +
    (`Naranjal`= bd$cant_res == "Naranjal") +
    (`Naranjito`= bd$cant_res == "Naranjito") +
    (`Palestina`= bd$cant_res == "Palestina") +
    (`Pedro Carbo`= bd$cant_res == "Pedro Carbo") +
    (`Samborondón`= bd$cant_res == "Samborondón") +
    (`Santa Lucia`= bd$cant_res == "Santa Lucia") +
    (`Salitre`= bd$cant_res == "Salitre") +
    (`San Jacinto De Yaguachi`= bd$cant_res == "San Jacinto De Yaguachi") +
    (`Playas`= bd$cant_res == "Playas") +
    (`Simón Bolívar`= bd$cant_res == "Simón Bolívar") +
    (`Crnel. Marcelino Maridueña`= bd$cant_res == "Crnel. Marcelino Maridueña") +
    (`Lomas De Sargentillo`= bd$cant_res == "Lomas De Sargentillo") +
    (`Nobol`= bd$cant_res == "Nobol") +
    (`Gnral. Antonio Elizalde`= bd$cant_res == "Gnral. Antonio Elizalde") +
    (`Isidro Ayora`= bd$cant_res == "Isidro Ayora") +
    (`Los Ríos`= bd$prov_res == "LOS RÍOS") +
    (`Babahoyo`= bd$cant_res == "Babahoyo") +
    (`Baba`= bd$cant_res == "Baba") +
    (`Montalvo`= bd$cant_res == "Montalvo") +
    (`Puebloviejo`= bd$cant_res == "Puebloviejo") +
    (`Quevedo`= bd$cant_res == "Quevedo") +
    (`Urdaneta`= bd$cant_res == "Urdaneta") +
    (`Ventanas`= bd$cant_res == "Ventanas") +
    (`Vinces`= bd$cant_res == "Vinces") +
    (`Palenque`= bd$cant_res == "Palenque") +
    (`Buena Fé`= bd$cant_res == "Buena Fé") +
    (`Valencia`= bd$cant_res == "Valencia") +
    (`Mocache`= bd$cant_res == "Mocache") +
    (`Quinsaloma`= bd$cant_res == "Quinsaloma") +
    (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Portoviejo`= bd$cant_res == "Portoviejo") +
    (`Bolívar`= bd$cant_res == "Bolívar") * (`Manabí`= bd$prov_res == "MANABÍ") +
    (`Chone`= bd$cant_res == "Chone") +
    (`El Carmen`= bd$cant_res == "El Carmen") +
    (`Flavio Alfaro`= bd$cant_res == "Flavio Alfaro") +
    (`Jipijapa`= bd$cant_res == "Jipijapa") +
    (`Junín`= bd$cant_res == "Junín") +
    (`Manta`= bd$cant_res == "Manta") +
    (`Montecristi`= bd$cant_res == "Montecristi") +
    (`Paján`= bd$cant_res == "Paján") +
    (`Pichincha`= bd$cant_res == "Pichincha") +
    (`Rocafuerte`= bd$cant_res == "Rocafuerte") +
    (`Santa Ana`= bd$cant_res == "Santa Ana") +
    (`Sucre`= bd$cant_res == "Sucre") +
    (`Tosagua`= bd$cant_res == "Tosagua") +
    (`24 De Mayo`= bd$cant_res == "24 De Mayo") +
    (`Pedernales`= bd$cant_res == "Pedernales") +
    (`Olmedo`= bd$cant_res == "Olmedo") +
    (`Puerto López`= bd$cant_res == "Puerto López") +
    (`Jama`= bd$cant_res == "Jama") +
    (`Jaramijó`= bd$cant_res == "Jaramijó") +
    (`San Vicente`= bd$cant_res == "San Vicente") +
    (`Santa Elena`= bd$prov_res == "SANTA ELENA") +
    (`Santa Elena`= bd$cant_res == "Santa Elena") +
    (`La Libertad`= bd$cant_res == "La Libertad") +
    (`Salinas`= bd$cant_res == "Salinas") +
    (`Región Amazónica:`= bd$reg_nac == "Región Amazónica:") +
    (`Morona Santiago`= bd$prov_res == "MORONA SANTIAGO") +
    (`Morona`= bd$cant_res == "Morona") +
    (`Gualaquiza`= bd$cant_res == "Gualaquiza") +
    (`Limón Indanza`= bd$cant_res == "Limón Indanza") +
    (`Palora`= bd$cant_res == "Palora") +
    (`Santiago`= bd$cant_res == "Santiago") +
    (`Sucúa`= bd$cant_res == "Sucúa") +
    (`Huamboya`= bd$cant_res == "Huamboya") +
    (`San Juan Bosco`= bd$cant_res == "San Juan Bosco") +
    (`Taisha`= bd$cant_res == "Taisha") +
    (`Logroño`= bd$cant_res == "Logroño") +
    (`Pablo Sexto`= bd$cant_res == "Pablo Sexto") +
    (`Tiwintza`= bd$cant_res == "Tiwintza") +
    (`Napo`= bd$prov_res == "NAPO") +
    (`Tena`= bd$cant_res == "Tena") +
    (`Archidona`= bd$cant_res == "Archidona") +
    (`El Chaco`= bd$cant_res == "El Chaco") +
    (`Quijos`= bd$cant_res == "Quijos") +
    (`Carlos Julio Arrosemena Tola`= bd$cant_res == "Carlos Julio Arrosemena Tola") +
    (`Pastaza`= bd$prov_res == "PASTAZA") +
    (`Pastaza`= bd$cant_res == "Pastaza")+
    (`Mera`= bd$cant_res == "Mera")+
    (`Santa Clara`= bd$cant_res == "Santa Clara") +
    (`Arajuno`= bd$cant_res == "Arajuno") +
    (`Zamora Chinchipe`= bd$prov_res == "ZAMORA CHINCHIPE") +
    (`Zamora`= bd$cant_res == "Zamora") +
    (`Chinchipe`= bd$cant_res == "Chinchipe") +
    (`Nangaritza`= bd$cant_res == "Nangaritza") +
    (`Yacuambi`= bd$cant_res == "Yacuambi") +
    (`Yantzaza`= bd$cant_res == "Yantzaza") +
    (`El Pangui`= bd$cant_res == "El Pangui") +
    (`Centinela Del Cóndor`= bd$cant_res == "Centinela Del Cóndor") +
    (`Palanda`= bd$cant_res == "Palanda") +
    (`Paquisha`= bd$cant_res == "Paquisha") +
    (`Sucumbíos`= bd$prov_res == "SUCUMBÍOS") +
    (`Lago Agrio`= bd$cant_res == "Lago Agrio") +
    (`Gonzalo Pizarro`= bd$cant_res == "Gonzalo Pizarro") +
    (`Putumayo`= bd$cant_res == "Putumayo") +
    (`Shushufindi`= bd$cant_res == "Shushufindi") +
    (`Sucumbios`= bd$cant_res == "Sucumbios") +
    (`Cascales`= bd$cant_res == "Cascales") +
    (`Cuyabeno`= bd$cant_res == "Cuyabeno") +
    (`Orellana`= bd$prov_res == "ORELLANA") +
    (`Orellana`= bd$cant_res == "Orellana") +
    (`Aguarico`= bd$cant_res == "Aguarico") +
    (`La Joya De Los Sachas`= bd$cant_res == "La Joya De Los Sachas") +
    (`Loreto`= bd$cant_res == "Loreto") +
    (`Región Insular:`= bd$reg_nac == "Región Insular:") +
    (`Galápagos`= bd$prov_res == "GALÁPAGOS") +
    (`San Cristobal`= bd$cant_res == "San Cristobal") +
    (`Isabela`= bd$cant_res == "Isabela") +
    (`Santa Cruz`= bd$cant_res == "Santa Cruz") +
    (`Exterior:`= bd$reg_nac == "Exterior:") ~
    (
      (`Total`= bd$t) * (sum) +
        (`Unión libre`= bd$t) * (sum) * (`1`= bd$est_civil == 1) +
        (`Soltera`= bd$t) * (sum) * (`2`= bd$est_civil == 2) +
        (`Casada`= bd$t) * (sum) * (`3`= bd$est_civil == 3) +
        (`Divorciada`= bd$t) * (sum) * (`4`= bd$est_civil == 4) +
        (`Separada`= bd$t) * (sum) * (`5`= bd$est_civil == 5) +
        (`Viuda`= bd$t) * (sum) * (`6`= bd$est_civil == 6) +
        (`Unión de hecho`= bd$t) * (sum) * (`7`= bd$est_civil == 7) +
        (`Sin información`= bd$t) * (sum) * (`9`= bd$est_civil == 9)
    ),
  data = bd)

print(tabla3.1.24)

write.csv.tabular(tabla3.1.24, file = "Tabla 3.1.24.csv")